class DomainName
  ETLD_DATA_DATE = '2013-06-06T23:00:56Z'

  ETLD_DATA = {
    "ac" => 0,
    "com.ac" => 0,
    "edu.ac" => 0,
    "gov.ac" => 0,
    "net.ac" => 0,
    "mil.ac" => 0,
    "org.ac" => 0,
    "ad" => 0,
    "nom.ad" => 0,
    "ae" => 0,
    "co.ae" => 0,
    "net.ae" => 0,
    "org.ae" => 0,
    "sch.ae" => 0,
    "ac.ae" => 0,
    "gov.ae" => 0,
    "mil.ae" => 0,
    "aero" => 0,
    "accident-investigation.aero" => 0,
    "accident-prevention.aero" => 0,
    "aerobatic.aero" => 0,
    "aeroclub.aero" => 0,
    "aerodrome.aero" => 0,
    "agents.aero" => 0,
    "aircraft.aero" => 0,
    "airline.aero" => 0,
    "airport.aero" => 0,
    "air-surveillance.aero" => 0,
    "airtraffic.aero" => 0,
    "air-traffic-control.aero" => 0,
    "ambulance.aero" => 0,
    "amusement.aero" => 0,
    "association.aero" => 0,
    "author.aero" => 0,
    "ballooning.aero" => 0,
    "broker.aero" => 0,
    "caa.aero" => 0,
    "cargo.aero" => 0,
    "catering.aero" => 0,
    "certification.aero" => 0,
    "championship.aero" => 0,
    "charter.aero" => 0,
    "civilaviation.aero" => 0,
    "club.aero" => 0,
    "conference.aero" => 0,
    "consultant.aero" => 0,
    "consulting.aero" => 0,
    "control.aero" => 0,
    "council.aero" => 0,
    "crew.aero" => 0,
    "design.aero" => 0,
    "dgca.aero" => 0,
    "educator.aero" => 0,
    "emergency.aero" => 0,
    "engine.aero" => 0,
    "engineer.aero" => 0,
    "entertainment.aero" => 0,
    "equipment.aero" => 0,
    "exchange.aero" => 0,
    "express.aero" => 0,
    "federation.aero" => 0,
    "flight.aero" => 0,
    "freight.aero" => 0,
    "fuel.aero" => 0,
    "gliding.aero" => 0,
    "government.aero" => 0,
    "groundhandling.aero" => 0,
    "group.aero" => 0,
    "hanggliding.aero" => 0,
    "homebuilt.aero" => 0,
    "insurance.aero" => 0,
    "journal.aero" => 0,
    "journalist.aero" => 0,
    "leasing.aero" => 0,
    "logistics.aero" => 0,
    "magazine.aero" => 0,
    "maintenance.aero" => 0,
    "marketplace.aero" => 0,
    "media.aero" => 0,
    "microlight.aero" => 0,
    "modelling.aero" => 0,
    "navigation.aero" => 0,
    "parachuting.aero" => 0,
    "paragliding.aero" => 0,
    "passenger-association.aero" => 0,
    "pilot.aero" => 0,
    "press.aero" => 0,
    "production.aero" => 0,
    "recreation.aero" => 0,
    "repbody.aero" => 0,
    "res.aero" => 0,
    "research.aero" => 0,
    "rotorcraft.aero" => 0,
    "safety.aero" => 0,
    "scientist.aero" => 0,
    "services.aero" => 0,
    "show.aero" => 0,
    "skydiving.aero" => 0,
    "software.aero" => 0,
    "student.aero" => 0,
    "taxi.aero" => 0,
    "trader.aero" => 0,
    "trading.aero" => 0,
    "trainer.aero" => 0,
    "union.aero" => 0,
    "workinggroup.aero" => 0,
    "works.aero" => 0,
    "af" => 0,
    "gov.af" => 0,
    "com.af" => 0,
    "org.af" => 0,
    "net.af" => 0,
    "edu.af" => 0,
    "ag" => 0,
    "com.ag" => 0,
    "org.ag" => 0,
    "net.ag" => 0,
    "co.ag" => 0,
    "nom.ag" => 0,
    "ai" => 0,
    "off.ai" => 0,
    "com.ai" => 0,
    "net.ai" => 0,
    "org.ai" => 0,
    "al" => 0,
    "com.al" => 0,
    "edu.al" => 0,
    "gov.al" => 0,
    "mil.al" => 0,
    "net.al" => 0,
    "org.al" => 0,
    "am" => 0,
    "an" => 0,
    "com.an" => 0,
    "net.an" => 0,
    "org.an" => 0,
    "edu.an" => 0,
    "ao" => 0,
    "ed.ao" => 0,
    "gv.ao" => 0,
    "og.ao" => 0,
    "co.ao" => 0,
    "pb.ao" => 0,
    "it.ao" => 0,
    "aq" => 0,
    "ar" => -1,
    "congresodelalengua3.ar" => 1,
    "educ.ar" => 1,
    "gobiernoelectronico.ar" => 1,
    "mecon.ar" => 1,
    "nacion.ar" => 1,
    "nic.ar" => 1,
    "promocion.ar" => 1,
    "retina.ar" => 1,
    "uba.ar" => 1,
    "arpa" => 1,
    "e164.arpa" => 0,
    "in-addr.arpa" => 0,
    "ip6.arpa" => 0,
    "iris.arpa" => 0,
    "uri.arpa" => 0,
    "urn.arpa" => 0,
    "as" => 0,
    "gov.as" => 0,
    "asia" => 0,
    "at" => 0,
    "ac.at" => 0,
    "co.at" => 0,
    "gv.at" => 0,
    "or.at" => 0,
    "au" => 1,
    "com.au" => 0,
    "net.au" => 0,
    "org.au" => 0,
    "edu.au" => 0,
    "gov.au" => 0,
    "asn.au" => 0,
    "id.au" => 0,
    "info.au" => 0,
    "conf.au" => 0,
    "oz.au" => 0,
    "act.au" => 0,
    "nsw.au" => 0,
    "nt.au" => 0,
    "qld.au" => 0,
    "sa.au" => 0,
    "tas.au" => 0,
    "vic.au" => 0,
    "wa.au" => 0,
    "act.edu.au" => 0,
    "nsw.edu.au" => 0,
    "nt.edu.au" => 0,
    "qld.edu.au" => 0,
    "sa.edu.au" => 0,
    "tas.edu.au" => 0,
    "vic.edu.au" => 0,
    "wa.edu.au" => 0,
    "act.gov.au" => 0,
    "nt.gov.au" => 0,
    "qld.gov.au" => 0,
    "sa.gov.au" => 0,
    "tas.gov.au" => 0,
    "vic.gov.au" => 0,
    "wa.gov.au" => 0,
    "aw" => 0,
    "com.aw" => 0,
    "ax" => 0,
    "az" => 0,
    "com.az" => 0,
    "net.az" => 0,
    "int.az" => 0,
    "gov.az" => 0,
    "org.az" => 0,
    "edu.az" => 0,
    "info.az" => 0,
    "pp.az" => 0,
    "mil.az" => 0,
    "name.az" => 0,
    "pro.az" => 0,
    "biz.az" => 0,
    "ba" => 0,
    "org.ba" => 0,
    "net.ba" => 0,
    "edu.ba" => 0,
    "gov.ba" => 0,
    "mil.ba" => 0,
    "unsa.ba" => 0,
    "unbi.ba" => 0,
    "co.ba" => 0,
    "com.ba" => 0,
    "rs.ba" => 0,
    "bb" => 0,
    "biz.bb" => 0,
    "com.bb" => 0,
    "edu.bb" => 0,
    "gov.bb" => 0,
    "info.bb" => 0,
    "net.bb" => 0,
    "org.bb" => 0,
    "store.bb" => 0,
    "bd" => -1,
    "be" => 0,
    "ac.be" => 0,
    "bf" => 0,
    "gov.bf" => 0,
    "bg" => 0,
    "a.bg" => 0,
    "b.bg" => 0,
    "c.bg" => 0,
    "d.bg" => 0,
    "e.bg" => 0,
    "f.bg" => 0,
    "g.bg" => 0,
    "h.bg" => 0,
    "i.bg" => 0,
    "j.bg" => 0,
    "k.bg" => 0,
    "l.bg" => 0,
    "m.bg" => 0,
    "n.bg" => 0,
    "o.bg" => 0,
    "p.bg" => 0,
    "q.bg" => 0,
    "r.bg" => 0,
    "s.bg" => 0,
    "t.bg" => 0,
    "u.bg" => 0,
    "v.bg" => 0,
    "w.bg" => 0,
    "x.bg" => 0,
    "y.bg" => 0,
    "z.bg" => 0,
    "0.bg" => 0,
    "1.bg" => 0,
    "2.bg" => 0,
    "3.bg" => 0,
    "4.bg" => 0,
    "5.bg" => 0,
    "6.bg" => 0,
    "7.bg" => 0,
    "8.bg" => 0,
    "9.bg" => 0,
    "bh" => 0,
    "com.bh" => 0,
    "edu.bh" => 0,
    "net.bh" => 0,
    "org.bh" => 0,
    "gov.bh" => 0,
    "bi" => 0,
    "co.bi" => 0,
    "com.bi" => 0,
    "edu.bi" => 0,
    "or.bi" => 0,
    "org.bi" => 0,
    "biz" => 0,
    "bj" => 0,
    "asso.bj" => 0,
    "barreau.bj" => 0,
    "gouv.bj" => 0,
    "bm" => 0,
    "com.bm" => 0,
    "edu.bm" => 0,
    "gov.bm" => 0,
    "net.bm" => 0,
    "org.bm" => 0,
    "bn" => -1,
    "bo" => 0,
    "com.bo" => 0,
    "edu.bo" => 0,
    "gov.bo" => 0,
    "gob.bo" => 0,
    "int.bo" => 0,
    "org.bo" => 0,
    "net.bo" => 0,
    "mil.bo" => 0,
    "tv.bo" => 0,
    "br" => 0,
    "adm.br" => 0,
    "adv.br" => 0,
    "agr.br" => 0,
    "am.br" => 0,
    "arq.br" => 0,
    "art.br" => 0,
    "ato.br" => 0,
    "b.br" => 0,
    "bio.br" => 0,
    "blog.br" => 0,
    "bmd.br" => 0,
    "cim.br" => 0,
    "cng.br" => 0,
    "cnt.br" => 0,
    "com.br" => 0,
    "coop.br" => 0,
    "ecn.br" => 0,
    "eco.br" => 0,
    "edu.br" => 0,
    "emp.br" => 0,
    "eng.br" => 0,
    "esp.br" => 0,
    "etc.br" => 0,
    "eti.br" => 0,
    "far.br" => 0,
    "flog.br" => 0,
    "fm.br" => 0,
    "fnd.br" => 0,
    "fot.br" => 0,
    "fst.br" => 0,
    "g12.br" => 0,
    "ggf.br" => 0,
    "gov.br" => 0,
    "imb.br" => 0,
    "ind.br" => 0,
    "inf.br" => 0,
    "jor.br" => 0,
    "jus.br" => 0,
    "leg.br" => 0,
    "lel.br" => 0,
    "mat.br" => 0,
    "med.br" => 0,
    "mil.br" => 0,
    "mus.br" => 0,
    "net.br" => 0,
    "nom.br" => 0,
    "not.br" => 0,
    "ntr.br" => 0,
    "odo.br" => 0,
    "org.br" => 0,
    "ppg.br" => 0,
    "pro.br" => 0,
    "psc.br" => 0,
    "psi.br" => 0,
    "qsl.br" => 0,
    "radio.br" => 0,
    "rec.br" => 0,
    "slg.br" => 0,
    "srv.br" => 0,
    "taxi.br" => 0,
    "teo.br" => 0,
    "tmp.br" => 0,
    "trd.br" => 0,
    "tur.br" => 0,
    "tv.br" => 0,
    "vet.br" => 0,
    "vlog.br" => 0,
    "wiki.br" => 0,
    "zlg.br" => 0,
    "bs" => 0,
    "com.bs" => 0,
    "net.bs" => 0,
    "org.bs" => 0,
    "edu.bs" => 0,
    "gov.bs" => 0,
    "bt" => 0,
    "com.bt" => 0,
    "edu.bt" => 0,
    "gov.bt" => 0,
    "net.bt" => 0,
    "org.bt" => 0,
    "bw" => 0,
    "co.bw" => 0,
    "org.bw" => 0,
    "by" => 0,
    "gov.by" => 0,
    "mil.by" => 0,
    "com.by" => 0,
    "of.by" => 0,
    "bz" => 0,
    "com.bz" => 0,
    "net.bz" => 0,
    "org.bz" => 0,
    "edu.bz" => 0,
    "gov.bz" => 0,
    "ca" => 0,
    "ab.ca" => 0,
    "bc.ca" => 0,
    "mb.ca" => 0,
    "nb.ca" => 0,
    "nf.ca" => 0,
    "nl.ca" => 0,
    "ns.ca" => 0,
    "nt.ca" => 0,
    "nu.ca" => 0,
    "on.ca" => 0,
    "pe.ca" => 0,
    "qc.ca" => 0,
    "sk.ca" => 0,
    "yk.ca" => 0,
    "gc.ca" => 0,
    "cat" => 0,
    "cc" => 0,
    "cd" => 0,
    "gov.cd" => 0,
    "cf" => 0,
    "cg" => 0,
    "ch" => 0,
    "ci" => 0,
    "org.ci" => 0,
    "or.ci" => 0,
    "com.ci" => 0,
    "co.ci" => 0,
    "edu.ci" => 0,
    "ed.ci" => 0,
    "ac.ci" => 0,
    "net.ci" => 0,
    "go.ci" => 0,
    "asso.ci" => 0,
    "xn--aroport-bya.ci" => 0,
    "int.ci" => 0,
    "presse.ci" => 0,
    "md.ci" => 0,
    "gouv.ci" => 0,
    "ck" => -1,
    "www.ck" => 1,
    "cl" => 0,
    "gov.cl" => 0,
    "gob.cl" => 0,
    "co.cl" => 0,
    "mil.cl" => 0,
    "cm" => 0,
    "gov.cm" => 0,
    "cn" => 0,
    "ac.cn" => 0,
    "com.cn" => 0,
    "edu.cn" => 0,
    "gov.cn" => 0,
    "net.cn" => 0,
    "org.cn" => 0,
    "mil.cn" => 0,
    "xn--55qx5d.cn" => 0,
    "xn--io0a7i.cn" => 0,
    "xn--od0alg.cn" => 0,
    "ah.cn" => 0,
    "bj.cn" => 0,
    "cq.cn" => 0,
    "fj.cn" => 0,
    "gd.cn" => 0,
    "gs.cn" => 0,
    "gz.cn" => 0,
    "gx.cn" => 0,
    "ha.cn" => 0,
    "hb.cn" => 0,
    "he.cn" => 0,
    "hi.cn" => 0,
    "hl.cn" => 0,
    "hn.cn" => 0,
    "jl.cn" => 0,
    "js.cn" => 0,
    "jx.cn" => 0,
    "ln.cn" => 0,
    "nm.cn" => 0,
    "nx.cn" => 0,
    "qh.cn" => 0,
    "sc.cn" => 0,
    "sd.cn" => 0,
    "sh.cn" => 0,
    "sn.cn" => 0,
    "sx.cn" => 0,
    "tj.cn" => 0,
    "xj.cn" => 0,
    "xz.cn" => 0,
    "yn.cn" => 0,
    "zj.cn" => 0,
    "hk.cn" => 0,
    "mo.cn" => 0,
    "tw.cn" => 0,
    "co" => 0,
    "arts.co" => 0,
    "com.co" => 0,
    "edu.co" => 0,
    "firm.co" => 0,
    "gov.co" => 0,
    "info.co" => 0,
    "int.co" => 0,
    "mil.co" => 0,
    "net.co" => 0,
    "nom.co" => 0,
    "org.co" => 0,
    "rec.co" => 0,
    "web.co" => 0,
    "com" => 0,
    "coop" => 0,
    "cr" => 0,
    "ac.cr" => 0,
    "co.cr" => 0,
    "ed.cr" => 0,
    "fi.cr" => 0,
    "go.cr" => 0,
    "or.cr" => 0,
    "sa.cr" => 0,
    "cu" => 0,
    "com.cu" => 0,
    "edu.cu" => 0,
    "org.cu" => 0,
    "net.cu" => 0,
    "gov.cu" => 0,
    "inf.cu" => 0,
    "cv" => 0,
    "cw" => 0,
    "com.cw" => 0,
    "edu.cw" => 0,
    "net.cw" => 0,
    "org.cw" => 0,
    "cx" => 0,
    "gov.cx" => 0,
    "cy" => -1,
    "cz" => 0,
    "de" => 0,
    "dj" => 0,
    "dk" => 0,
    "dm" => 0,
    "com.dm" => 0,
    "net.dm" => 0,
    "org.dm" => 0,
    "edu.dm" => 0,
    "gov.dm" => 0,
    "do" => 0,
    "art.do" => 0,
    "com.do" => 0,
    "edu.do" => 0,
    "gob.do" => 0,
    "gov.do" => 0,
    "mil.do" => 0,
    "net.do" => 0,
    "org.do" => 0,
    "sld.do" => 0,
    "web.do" => 0,
    "dz" => 0,
    "com.dz" => 0,
    "org.dz" => 0,
    "net.dz" => 0,
    "gov.dz" => 0,
    "edu.dz" => 0,
    "asso.dz" => 0,
    "pol.dz" => 0,
    "art.dz" => 0,
    "ec" => 0,
    "com.ec" => 0,
    "info.ec" => 0,
    "net.ec" => 0,
    "fin.ec" => 0,
    "k12.ec" => 0,
    "med.ec" => 0,
    "pro.ec" => 0,
    "org.ec" => 0,
    "edu.ec" => 0,
    "gov.ec" => 0,
    "gob.ec" => 0,
    "mil.ec" => 0,
    "edu" => 0,
    "ee" => 0,
    "edu.ee" => 0,
    "gov.ee" => 0,
    "riik.ee" => 0,
    "lib.ee" => 0,
    "med.ee" => 0,
    "com.ee" => 0,
    "pri.ee" => 0,
    "aip.ee" => 0,
    "org.ee" => 0,
    "fie.ee" => 0,
    "eg" => 0,
    "com.eg" => 0,
    "edu.eg" => 0,
    "eun.eg" => 0,
    "gov.eg" => 0,
    "mil.eg" => 0,
    "name.eg" => 0,
    "net.eg" => 0,
    "org.eg" => 0,
    "sci.eg" => 0,
    "er" => -1,
    "es" => 0,
    "com.es" => 0,
    "nom.es" => 0,
    "org.es" => 0,
    "gob.es" => 0,
    "edu.es" => 0,
    "et" => -1,
    "eu" => 0,
    "fi" => 0,
    "aland.fi" => 0,
    "fj" => -1,
    "fk" => -1,
    "fm" => 0,
    "fo" => 0,
    "fr" => 0,
    "com.fr" => 0,
    "asso.fr" => 0,
    "nom.fr" => 0,
    "prd.fr" => 0,
    "presse.fr" => 0,
    "tm.fr" => 0,
    "aeroport.fr" => 0,
    "assedic.fr" => 0,
    "avocat.fr" => 0,
    "avoues.fr" => 0,
    "cci.fr" => 0,
    "chambagri.fr" => 0,
    "chirurgiens-dentistes.fr" => 0,
    "experts-comptables.fr" => 0,
    "geometre-expert.fr" => 0,
    "gouv.fr" => 0,
    "greta.fr" => 0,
    "huissier-justice.fr" => 0,
    "medecin.fr" => 0,
    "notaires.fr" => 0,
    "pharmacien.fr" => 0,
    "port.fr" => 0,
    "veterinaire.fr" => 0,
    "ga" => 0,
    "gd" => 0,
    "ge" => 0,
    "com.ge" => 0,
    "edu.ge" => 0,
    "gov.ge" => 0,
    "org.ge" => 0,
    "mil.ge" => 0,
    "net.ge" => 0,
    "pvt.ge" => 0,
    "gf" => 0,
    "gg" => 0,
    "co.gg" => 0,
    "org.gg" => 0,
    "net.gg" => 0,
    "sch.gg" => 0,
    "gov.gg" => 0,
    "gh" => 0,
    "com.gh" => 0,
    "edu.gh" => 0,
    "gov.gh" => 0,
    "org.gh" => 0,
    "mil.gh" => 0,
    "gi" => 0,
    "com.gi" => 0,
    "ltd.gi" => 0,
    "gov.gi" => 0,
    "mod.gi" => 0,
    "edu.gi" => 0,
    "org.gi" => 0,
    "gl" => 0,
    "gm" => 0,
    "gn" => 1,
    "ac.gn" => 0,
    "com.gn" => 0,
    "edu.gn" => 0,
    "gov.gn" => 0,
    "org.gn" => 0,
    "net.gn" => 0,
    "gov" => 0,
    "gp" => 0,
    "com.gp" => 0,
    "net.gp" => 0,
    "mobi.gp" => 0,
    "edu.gp" => 0,
    "org.gp" => 0,
    "asso.gp" => 0,
    "gq" => 0,
    "gr" => 0,
    "com.gr" => 0,
    "edu.gr" => 0,
    "net.gr" => 0,
    "org.gr" => 0,
    "gov.gr" => 0,
    "gs" => 0,
    "gt" => 0,
    "com.gt" => 0,
    "edu.gt" => 0,
    "gob.gt" => 0,
    "ind.gt" => 0,
    "mil.gt" => 0,
    "net.gt" => 0,
    "org.gt" => 0,
    "gu" => -1,
    "gw" => 0,
    "gy" => 0,
    "co.gy" => 0,
    "com.gy" => 0,
    "net.gy" => 0,
    "hk" => 0,
    "com.hk" => 0,
    "edu.hk" => 0,
    "gov.hk" => 0,
    "idv.hk" => 0,
    "net.hk" => 0,
    "org.hk" => 0,
    "xn--55qx5d.hk" => 0,
    "xn--wcvs22d.hk" => 0,
    "xn--lcvr32d.hk" => 0,
    "xn--mxtq1m.hk" => 0,
    "xn--gmqw5a.hk" => 0,
    "xn--ciqpn.hk" => 0,
    "xn--gmq050i.hk" => 0,
    "xn--zf0avx.hk" => 0,
    "xn--io0a7i.hk" => 0,
    "xn--mk0axi.hk" => 0,
    "xn--od0alg.hk" => 0,
    "xn--od0aq3b.hk" => 0,
    "xn--tn0ag.hk" => 0,
    "xn--uc0atv.hk" => 0,
    "xn--uc0ay4a.hk" => 0,
    "hm" => 0,
    "hn" => 0,
    "com.hn" => 0,
    "edu.hn" => 0,
    "org.hn" => 0,
    "net.hn" => 0,
    "mil.hn" => 0,
    "gob.hn" => 0,
    "hr" => 0,
    "iz.hr" => 0,
    "from.hr" => 0,
    "name.hr" => 0,
    "com.hr" => 0,
    "ht" => 0,
    "com.ht" => 0,
    "shop.ht" => 0,
    "firm.ht" => 0,
    "info.ht" => 0,
    "adult.ht" => 0,
    "net.ht" => 0,
    "pro.ht" => 0,
    "org.ht" => 0,
    "med.ht" => 0,
    "art.ht" => 0,
    "coop.ht" => 0,
    "pol.ht" => 0,
    "asso.ht" => 0,
    "edu.ht" => 0,
    "rel.ht" => 0,
    "gouv.ht" => 0,
    "perso.ht" => 0,
    "hu" => 0,
    "co.hu" => 0,
    "info.hu" => 0,
    "org.hu" => 0,
    "priv.hu" => 0,
    "sport.hu" => 0,
    "tm.hu" => 0,
    "2000.hu" => 0,
    "agrar.hu" => 0,
    "bolt.hu" => 0,
    "casino.hu" => 0,
    "city.hu" => 0,
    "erotica.hu" => 0,
    "erotika.hu" => 0,
    "film.hu" => 0,
    "forum.hu" => 0,
    "games.hu" => 0,
    "hotel.hu" => 0,
    "ingatlan.hu" => 0,
    "jogasz.hu" => 0,
    "konyvelo.hu" => 0,
    "lakas.hu" => 0,
    "media.hu" => 0,
    "news.hu" => 0,
    "reklam.hu" => 0,
    "sex.hu" => 0,
    "shop.hu" => 0,
    "suli.hu" => 0,
    "szex.hu" => 0,
    "tozsde.hu" => 0,
    "utazas.hu" => 0,
    "video.hu" => 0,
    "id" => 0,
    "ac.id" => 0,
    "biz.id" => 0,
    "co.id" => 0,
    "go.id" => 0,
    "mil.id" => 0,
    "my.id" => 0,
    "net.id" => 0,
    "or.id" => 0,
    "sch.id" => 0,
    "web.id" => 0,
    "ie" => 0,
    "gov.ie" => 0,
    "il" => -1,
    "im" => 0,
    "co.im" => 0,
    "ltd.co.im" => 0,
    "plc.co.im" => 0,
    "net.im" => 0,
    "gov.im" => 0,
    "org.im" => 0,
    "nic.im" => 0,
    "ac.im" => 0,
    "in" => 0,
    "co.in" => 0,
    "firm.in" => 0,
    "net.in" => 0,
    "org.in" => 0,
    "gen.in" => 0,
    "ind.in" => 0,
    "nic.in" => 0,
    "ac.in" => 0,
    "edu.in" => 0,
    "res.in" => 0,
    "gov.in" => 0,
    "mil.in" => 0,
    "info" => 0,
    "int" => 0,
    "eu.int" => 0,
    "io" => 0,
    "com.io" => 0,
    "iq" => 0,
    "gov.iq" => 0,
    "edu.iq" => 0,
    "mil.iq" => 0,
    "com.iq" => 0,
    "org.iq" => 0,
    "net.iq" => 0,
    "ir" => 0,
    "ac.ir" => 0,
    "co.ir" => 0,
    "gov.ir" => 0,
    "id.ir" => 0,
    "net.ir" => 0,
    "org.ir" => 0,
    "sch.ir" => 0,
    "xn--mgba3a4f16a.ir" => 0,
    "xn--mgba3a4fra.ir" => 0,
    "is" => 0,
    "net.is" => 0,
    "com.is" => 0,
    "edu.is" => 0,
    "gov.is" => 0,
    "org.is" => 0,
    "int.is" => 0,
    "it" => 0,
    "gov.it" => 0,
    "edu.it" => 0,
    "agrigento.it" => 0,
    "ag.it" => 0,
    "alessandria.it" => 0,
    "al.it" => 0,
    "ancona.it" => 0,
    "an.it" => 0,
    "aosta.it" => 0,
    "aoste.it" => 0,
    "ao.it" => 0,
    "arezzo.it" => 0,
    "ar.it" => 0,
    "ascoli-piceno.it" => 0,
    "ascolipiceno.it" => 0,
    "ap.it" => 0,
    "asti.it" => 0,
    "at.it" => 0,
    "avellino.it" => 0,
    "av.it" => 0,
    "bari.it" => 0,
    "ba.it" => 0,
    "andria-barletta-trani.it" => 0,
    "andriabarlettatrani.it" => 0,
    "trani-barletta-andria.it" => 0,
    "tranibarlettaandria.it" => 0,
    "barletta-trani-andria.it" => 0,
    "barlettatraniandria.it" => 0,
    "andria-trani-barletta.it" => 0,
    "andriatranibarletta.it" => 0,
    "trani-andria-barletta.it" => 0,
    "traniandriabarletta.it" => 0,
    "bt.it" => 0,
    "belluno.it" => 0,
    "bl.it" => 0,
    "benevento.it" => 0,
    "bn.it" => 0,
    "bergamo.it" => 0,
    "bg.it" => 0,
    "biella.it" => 0,
    "bi.it" => 0,
    "bologna.it" => 0,
    "bo.it" => 0,
    "bolzano.it" => 0,
    "bozen.it" => 0,
    "balsan.it" => 0,
    "alto-adige.it" => 0,
    "altoadige.it" => 0,
    "suedtirol.it" => 0,
    "bz.it" => 0,
    "brescia.it" => 0,
    "bs.it" => 0,
    "brindisi.it" => 0,
    "br.it" => 0,
    "cagliari.it" => 0,
    "ca.it" => 0,
    "caltanissetta.it" => 0,
    "cl.it" => 0,
    "campobasso.it" => 0,
    "cb.it" => 0,
    "carboniaiglesias.it" => 0,
    "carbonia-iglesias.it" => 0,
    "iglesias-carbonia.it" => 0,
    "iglesiascarbonia.it" => 0,
    "ci.it" => 0,
    "caserta.it" => 0,
    "ce.it" => 0,
    "catania.it" => 0,
    "ct.it" => 0,
    "catanzaro.it" => 0,
    "cz.it" => 0,
    "chieti.it" => 0,
    "ch.it" => 0,
    "como.it" => 0,
    "co.it" => 0,
    "cosenza.it" => 0,
    "cs.it" => 0,
    "cremona.it" => 0,
    "cr.it" => 0,
    "crotone.it" => 0,
    "kr.it" => 0,
    "cuneo.it" => 0,
    "cn.it" => 0,
    "dell-ogliastra.it" => 0,
    "dellogliastra.it" => 0,
    "ogliastra.it" => 0,
    "og.it" => 0,
    "enna.it" => 0,
    "en.it" => 0,
    "ferrara.it" => 0,
    "fe.it" => 0,
    "fermo.it" => 0,
    "fm.it" => 0,
    "firenze.it" => 0,
    "florence.it" => 0,
    "fi.it" => 0,
    "foggia.it" => 0,
    "fg.it" => 0,
    "forli-cesena.it" => 0,
    "forlicesena.it" => 0,
    "cesena-forli.it" => 0,
    "cesenaforli.it" => 0,
    "fc.it" => 0,
    "frosinone.it" => 0,
    "fr.it" => 0,
    "genova.it" => 0,
    "genoa.it" => 0,
    "ge.it" => 0,
    "gorizia.it" => 0,
    "go.it" => 0,
    "grosseto.it" => 0,
    "gr.it" => 0,
    "imperia.it" => 0,
    "im.it" => 0,
    "isernia.it" => 0,
    "is.it" => 0,
    "laquila.it" => 0,
    "aquila.it" => 0,
    "aq.it" => 0,
    "la-spezia.it" => 0,
    "laspezia.it" => 0,
    "sp.it" => 0,
    "latina.it" => 0,
    "lt.it" => 0,
    "lecce.it" => 0,
    "le.it" => 0,
    "lecco.it" => 0,
    "lc.it" => 0,
    "livorno.it" => 0,
    "li.it" => 0,
    "lodi.it" => 0,
    "lo.it" => 0,
    "lucca.it" => 0,
    "lu.it" => 0,
    "macerata.it" => 0,
    "mc.it" => 0,
    "mantova.it" => 0,
    "mn.it" => 0,
    "massa-carrara.it" => 0,
    "massacarrara.it" => 0,
    "carrara-massa.it" => 0,
    "carraramassa.it" => 0,
    "ms.it" => 0,
    "matera.it" => 0,
    "mt.it" => 0,
    "medio-campidano.it" => 0,
    "mediocampidano.it" => 0,
    "campidano-medio.it" => 0,
    "campidanomedio.it" => 0,
    "vs.it" => 0,
    "messina.it" => 0,
    "me.it" => 0,
    "milano.it" => 0,
    "milan.it" => 0,
    "mi.it" => 0,
    "modena.it" => 0,
    "mo.it" => 0,
    "monza.it" => 0,
    "monza-brianza.it" => 0,
    "monzabrianza.it" => 0,
    "monzaebrianza.it" => 0,
    "monzaedellabrianza.it" => 0,
    "monza-e-della-brianza.it" => 0,
    "mb.it" => 0,
    "napoli.it" => 0,
    "naples.it" => 0,
    "na.it" => 0,
    "novara.it" => 0,
    "no.it" => 0,
    "nuoro.it" => 0,
    "nu.it" => 0,
    "oristano.it" => 0,
    "or.it" => 0,
    "padova.it" => 0,
    "padua.it" => 0,
    "pd.it" => 0,
    "palermo.it" => 0,
    "pa.it" => 0,
    "parma.it" => 0,
    "pr.it" => 0,
    "pavia.it" => 0,
    "pv.it" => 0,
    "perugia.it" => 0,
    "pg.it" => 0,
    "pescara.it" => 0,
    "pe.it" => 0,
    "pesaro-urbino.it" => 0,
    "pesarourbino.it" => 0,
    "urbino-pesaro.it" => 0,
    "urbinopesaro.it" => 0,
    "pu.it" => 0,
    "piacenza.it" => 0,
    "pc.it" => 0,
    "pisa.it" => 0,
    "pi.it" => 0,
    "pistoia.it" => 0,
    "pt.it" => 0,
    "pordenone.it" => 0,
    "pn.it" => 0,
    "potenza.it" => 0,
    "pz.it" => 0,
    "prato.it" => 0,
    "po.it" => 0,
    "ragusa.it" => 0,
    "rg.it" => 0,
    "ravenna.it" => 0,
    "ra.it" => 0,
    "reggio-calabria.it" => 0,
    "reggiocalabria.it" => 0,
    "rc.it" => 0,
    "reggio-emilia.it" => 0,
    "reggioemilia.it" => 0,
    "re.it" => 0,
    "rieti.it" => 0,
    "ri.it" => 0,
    "rimini.it" => 0,
    "rn.it" => 0,
    "roma.it" => 0,
    "rome.it" => 0,
    "rm.it" => 0,
    "rovigo.it" => 0,
    "ro.it" => 0,
    "salerno.it" => 0,
    "sa.it" => 0,
    "sassari.it" => 0,
    "ss.it" => 0,
    "savona.it" => 0,
    "sv.it" => 0,
    "siena.it" => 0,
    "si.it" => 0,
    "siracusa.it" => 0,
    "sr.it" => 0,
    "sondrio.it" => 0,
    "so.it" => 0,
    "taranto.it" => 0,
    "ta.it" => 0,
    "tempio-olbia.it" => 0,
    "tempioolbia.it" => 0,
    "olbia-tempio.it" => 0,
    "olbiatempio.it" => 0,
    "ot.it" => 0,
    "teramo.it" => 0,
    "te.it" => 0,
    "terni.it" => 0,
    "tr.it" => 0,
    "torino.it" => 0,
    "turin.it" => 0,
    "to.it" => 0,
    "trapani.it" => 0,
    "tp.it" => 0,
    "trento.it" => 0,
    "trentino.it" => 0,
    "tn.it" => 0,
    "treviso.it" => 0,
    "tv.it" => 0,
    "trieste.it" => 0,
    "ts.it" => 0,
    "udine.it" => 0,
    "ud.it" => 0,
    "varese.it" => 0,
    "va.it" => 0,
    "venezia.it" => 0,
    "venice.it" => 0,
    "ve.it" => 0,
    "verbania.it" => 0,
    "vb.it" => 0,
    "vercelli.it" => 0,
    "vc.it" => 0,
    "verona.it" => 0,
    "vr.it" => 0,
    "vibo-valentia.it" => 0,
    "vibovalentia.it" => 0,
    "vv.it" => 0,
    "vicenza.it" => 0,
    "vi.it" => 0,
    "viterbo.it" => 0,
    "vt.it" => 0,
    "je" => 0,
    "co.je" => 0,
    "org.je" => 0,
    "net.je" => 0,
    "sch.je" => 0,
    "gov.je" => 0,
    "jm" => -1,
    "jo" => 0,
    "com.jo" => 0,
    "org.jo" => 0,
    "net.jo" => 0,
    "edu.jo" => 0,
    "sch.jo" => 0,
    "gov.jo" => 0,
    "mil.jo" => 0,
    "name.jo" => 0,
    "jobs" => 0,
    "jp" => 0,
    "ac.jp" => 0,
    "ad.jp" => 0,
    "co.jp" => 0,
    "ed.jp" => 0,
    "go.jp" => 0,
    "gr.jp" => 0,
    "lg.jp" => 0,
    "ne.jp" => 0,
    "or.jp" => 0,
    "aichi.jp" => 0,
    "akita.jp" => 0,
    "aomori.jp" => 0,
    "chiba.jp" => 0,
    "ehime.jp" => 0,
    "fukui.jp" => 0,
    "fukuoka.jp" => 0,
    "fukushima.jp" => 0,
    "gifu.jp" => 0,
    "gunma.jp" => 0,
    "hiroshima.jp" => 0,
    "hokkaido.jp" => 0,
    "hyogo.jp" => 0,
    "ibaraki.jp" => 0,
    "ishikawa.jp" => 0,
    "iwate.jp" => 0,
    "kagawa.jp" => 0,
    "kagoshima.jp" => 0,
    "kanagawa.jp" => 0,
    "kochi.jp" => 0,
    "kumamoto.jp" => 0,
    "kyoto.jp" => 0,
    "mie.jp" => 0,
    "miyagi.jp" => 0,
    "miyazaki.jp" => 0,
    "nagano.jp" => 0,
    "nagasaki.jp" => 0,
    "nara.jp" => 0,
    "niigata.jp" => 0,
    "oita.jp" => 0,
    "okayama.jp" => 0,
    "okinawa.jp" => 0,
    "osaka.jp" => 0,
    "saga.jp" => 0,
    "saitama.jp" => 0,
    "shiga.jp" => 0,
    "shimane.jp" => 0,
    "shizuoka.jp" => 0,
    "tochigi.jp" => 0,
    "tokushima.jp" => 0,
    "tokyo.jp" => 0,
    "tottori.jp" => 0,
    "toyama.jp" => 0,
    "wakayama.jp" => 0,
    "yamagata.jp" => 0,
    "yamaguchi.jp" => 0,
    "yamanashi.jp" => 0,
    "kawasaki.jp" => -1,
    "kitakyushu.jp" => -1,
    "kobe.jp" => -1,
    "nagoya.jp" => -1,
    "sapporo.jp" => -1,
    "sendai.jp" => -1,
    "yokohama.jp" => -1,
    "city.kawasaki.jp" => 1,
    "city.kitakyushu.jp" => 1,
    "city.kobe.jp" => 1,
    "city.nagoya.jp" => 1,
    "city.sapporo.jp" => 1,
    "city.sendai.jp" => 1,
    "city.yokohama.jp" => 1,
    "aisai.aichi.jp" => 0,
    "ama.aichi.jp" => 0,
    "anjo.aichi.jp" => 0,
    "asuke.aichi.jp" => 0,
    "chiryu.aichi.jp" => 0,
    "chita.aichi.jp" => 0,
    "fuso.aichi.jp" => 0,
    "gamagori.aichi.jp" => 0,
    "handa.aichi.jp" => 0,
    "hazu.aichi.jp" => 0,
    "hekinan.aichi.jp" => 0,
    "higashiura.aichi.jp" => 0,
    "ichinomiya.aichi.jp" => 0,
    "inazawa.aichi.jp" => 0,
    "inuyama.aichi.jp" => 0,
    "isshiki.aichi.jp" => 0,
    "iwakura.aichi.jp" => 0,
    "kanie.aichi.jp" => 0,
    "kariya.aichi.jp" => 0,
    "kasugai.aichi.jp" => 0,
    "kira.aichi.jp" => 0,
    "kiyosu.aichi.jp" => 0,
    "komaki.aichi.jp" => 0,
    "konan.aichi.jp" => 0,
    "kota.aichi.jp" => 0,
    "mihama.aichi.jp" => 0,
    "miyoshi.aichi.jp" => 0,
    "nagakute.aichi.jp" => 0,
    "nishio.aichi.jp" => 0,
    "nisshin.aichi.jp" => 0,
    "obu.aichi.jp" => 0,
    "oguchi.aichi.jp" => 0,
    "oharu.aichi.jp" => 0,
    "okazaki.aichi.jp" => 0,
    "owariasahi.aichi.jp" => 0,
    "seto.aichi.jp" => 0,
    "shikatsu.aichi.jp" => 0,
    "shinshiro.aichi.jp" => 0,
    "shitara.aichi.jp" => 0,
    "tahara.aichi.jp" => 0,
    "takahama.aichi.jp" => 0,
    "tobishima.aichi.jp" => 0,
    "toei.aichi.jp" => 0,
    "togo.aichi.jp" => 0,
    "tokai.aichi.jp" => 0,
    "tokoname.aichi.jp" => 0,
    "toyoake.aichi.jp" => 0,
    "toyohashi.aichi.jp" => 0,
    "toyokawa.aichi.jp" => 0,
    "toyone.aichi.jp" => 0,
    "toyota.aichi.jp" => 0,
    "tsushima.aichi.jp" => 0,
    "yatomi.aichi.jp" => 0,
    "akita.akita.jp" => 0,
    "daisen.akita.jp" => 0,
    "fujisato.akita.jp" => 0,
    "gojome.akita.jp" => 0,
    "hachirogata.akita.jp" => 0,
    "happou.akita.jp" => 0,
    "higashinaruse.akita.jp" => 0,
    "honjo.akita.jp" => 0,
    "honjyo.akita.jp" => 0,
    "ikawa.akita.jp" => 0,
    "kamikoani.akita.jp" => 0,
    "kamioka.akita.jp" => 0,
    "katagami.akita.jp" => 0,
    "kazuno.akita.jp" => 0,
    "kitaakita.akita.jp" => 0,
    "kosaka.akita.jp" => 0,
    "kyowa.akita.jp" => 0,
    "misato.akita.jp" => 0,
    "mitane.akita.jp" => 0,
    "moriyoshi.akita.jp" => 0,
    "nikaho.akita.jp" => 0,
    "noshiro.akita.jp" => 0,
    "odate.akita.jp" => 0,
    "oga.akita.jp" => 0,
    "ogata.akita.jp" => 0,
    "semboku.akita.jp" => 0,
    "yokote.akita.jp" => 0,
    "yurihonjo.akita.jp" => 0,
    "aomori.aomori.jp" => 0,
    "gonohe.aomori.jp" => 0,
    "hachinohe.aomori.jp" => 0,
    "hashikami.aomori.jp" => 0,
    "hiranai.aomori.jp" => 0,
    "hirosaki.aomori.jp" => 0,
    "itayanagi.aomori.jp" => 0,
    "kuroishi.aomori.jp" => 0,
    "misawa.aomori.jp" => 0,
    "mutsu.aomori.jp" => 0,
    "nakadomari.aomori.jp" => 0,
    "noheji.aomori.jp" => 0,
    "oirase.aomori.jp" => 0,
    "owani.aomori.jp" => 0,
    "rokunohe.aomori.jp" => 0,
    "sannohe.aomori.jp" => 0,
    "shichinohe.aomori.jp" => 0,
    "shingo.aomori.jp" => 0,
    "takko.aomori.jp" => 0,
    "towada.aomori.jp" => 0,
    "tsugaru.aomori.jp" => 0,
    "tsuruta.aomori.jp" => 0,
    "abiko.chiba.jp" => 0,
    "asahi.chiba.jp" => 0,
    "chonan.chiba.jp" => 0,
    "chosei.chiba.jp" => 0,
    "choshi.chiba.jp" => 0,
    "chuo.chiba.jp" => 0,
    "funabashi.chiba.jp" => 0,
    "futtsu.chiba.jp" => 0,
    "hanamigawa.chiba.jp" => 0,
    "ichihara.chiba.jp" => 0,
    "ichikawa.chiba.jp" => 0,
    "ichinomiya.chiba.jp" => 0,
    "inzai.chiba.jp" => 0,
    "isumi.chiba.jp" => 0,
    "kamagaya.chiba.jp" => 0,
    "kamogawa.chiba.jp" => 0,
    "kashiwa.chiba.jp" => 0,
    "katori.chiba.jp" => 0,
    "katsuura.chiba.jp" => 0,
    "kimitsu.chiba.jp" => 0,
    "kisarazu.chiba.jp" => 0,
    "kozaki.chiba.jp" => 0,
    "kujukuri.chiba.jp" => 0,
    "kyonan.chiba.jp" => 0,
    "matsudo.chiba.jp" => 0,
    "midori.chiba.jp" => 0,
    "mihama.chiba.jp" => 0,
    "minamiboso.chiba.jp" => 0,
    "mobara.chiba.jp" => 0,
    "mutsuzawa.chiba.jp" => 0,
    "nagara.chiba.jp" => 0,
    "nagareyama.chiba.jp" => 0,
    "narashino.chiba.jp" => 0,
    "narita.chiba.jp" => 0,
    "noda.chiba.jp" => 0,
    "oamishirasato.chiba.jp" => 0,
    "omigawa.chiba.jp" => 0,
    "onjuku.chiba.jp" => 0,
    "otaki.chiba.jp" => 0,
    "sakae.chiba.jp" => 0,
    "sakura.chiba.jp" => 0,
    "shimofusa.chiba.jp" => 0,
    "shirako.chiba.jp" => 0,
    "shiroi.chiba.jp" => 0,
    "shisui.chiba.jp" => 0,
    "sodegaura.chiba.jp" => 0,
    "sosa.chiba.jp" => 0,
    "tako.chiba.jp" => 0,
    "tateyama.chiba.jp" => 0,
    "togane.chiba.jp" => 0,
    "tohnosho.chiba.jp" => 0,
    "tomisato.chiba.jp" => 0,
    "urayasu.chiba.jp" => 0,
    "yachimata.chiba.jp" => 0,
    "yachiyo.chiba.jp" => 0,
    "yokaichiba.chiba.jp" => 0,
    "yokoshibahikari.chiba.jp" => 0,
    "yotsukaido.chiba.jp" => 0,
    "ainan.ehime.jp" => 0,
    "honai.ehime.jp" => 0,
    "ikata.ehime.jp" => 0,
    "imabari.ehime.jp" => 0,
    "iyo.ehime.jp" => 0,
    "kamijima.ehime.jp" => 0,
    "kihoku.ehime.jp" => 0,
    "kumakogen.ehime.jp" => 0,
    "masaki.ehime.jp" => 0,
    "matsuno.ehime.jp" => 0,
    "matsuyama.ehime.jp" => 0,
    "namikata.ehime.jp" => 0,
    "niihama.ehime.jp" => 0,
    "ozu.ehime.jp" => 0,
    "saijo.ehime.jp" => 0,
    "seiyo.ehime.jp" => 0,
    "shikokuchuo.ehime.jp" => 0,
    "tobe.ehime.jp" => 0,
    "toon.ehime.jp" => 0,
    "uchiko.ehime.jp" => 0,
    "uwajima.ehime.jp" => 0,
    "yawatahama.ehime.jp" => 0,
    "echizen.fukui.jp" => 0,
    "eiheiji.fukui.jp" => 0,
    "fukui.fukui.jp" => 0,
    "ikeda.fukui.jp" => 0,
    "katsuyama.fukui.jp" => 0,
    "mihama.fukui.jp" => 0,
    "minamiechizen.fukui.jp" => 0,
    "obama.fukui.jp" => 0,
    "ohi.fukui.jp" => 0,
    "ono.fukui.jp" => 0,
    "sabae.fukui.jp" => 0,
    "sakai.fukui.jp" => 0,
    "takahama.fukui.jp" => 0,
    "tsuruga.fukui.jp" => 0,
    "wakasa.fukui.jp" => 0,
    "ashiya.fukuoka.jp" => 0,
    "buzen.fukuoka.jp" => 0,
    "chikugo.fukuoka.jp" => 0,
    "chikuho.fukuoka.jp" => 0,
    "chikujo.fukuoka.jp" => 0,
    "chikushino.fukuoka.jp" => 0,
    "chikuzen.fukuoka.jp" => 0,
    "chuo.fukuoka.jp" => 0,
    "dazaifu.fukuoka.jp" => 0,
    "fukuchi.fukuoka.jp" => 0,
    "hakata.fukuoka.jp" => 0,
    "higashi.fukuoka.jp" => 0,
    "hirokawa.fukuoka.jp" => 0,
    "hisayama.fukuoka.jp" => 0,
    "iizuka.fukuoka.jp" => 0,
    "inatsuki.fukuoka.jp" => 0,
    "kaho.fukuoka.jp" => 0,
    "kasuga.fukuoka.jp" => 0,
    "kasuya.fukuoka.jp" => 0,
    "kawara.fukuoka.jp" => 0,
    "keisen.fukuoka.jp" => 0,
    "koga.fukuoka.jp" => 0,
    "kurate.fukuoka.jp" => 0,
    "kurogi.fukuoka.jp" => 0,
    "kurume.fukuoka.jp" => 0,
    "minami.fukuoka.jp" => 0,
    "miyako.fukuoka.jp" => 0,
    "miyama.fukuoka.jp" => 0,
    "miyawaka.fukuoka.jp" => 0,
    "mizumaki.fukuoka.jp" => 0,
    "munakata.fukuoka.jp" => 0,
    "nakagawa.fukuoka.jp" => 0,
    "nakama.fukuoka.jp" => 0,
    "nishi.fukuoka.jp" => 0,
    "nogata.fukuoka.jp" => 0,
    "ogori.fukuoka.jp" => 0,
    "okagaki.fukuoka.jp" => 0,
    "okawa.fukuoka.jp" => 0,
    "oki.fukuoka.jp" => 0,
    "omuta.fukuoka.jp" => 0,
    "onga.fukuoka.jp" => 0,
    "onojo.fukuoka.jp" => 0,
    "oto.fukuoka.jp" => 0,
    "saigawa.fukuoka.jp" => 0,
    "sasaguri.fukuoka.jp" => 0,
    "shingu.fukuoka.jp" => 0,
    "shinyoshitomi.fukuoka.jp" => 0,
    "shonai.fukuoka.jp" => 0,
    "soeda.fukuoka.jp" => 0,
    "sue.fukuoka.jp" => 0,
    "tachiarai.fukuoka.jp" => 0,
    "tagawa.fukuoka.jp" => 0,
    "takata.fukuoka.jp" => 0,
    "toho.fukuoka.jp" => 0,
    "toyotsu.fukuoka.jp" => 0,
    "tsuiki.fukuoka.jp" => 0,
    "ukiha.fukuoka.jp" => 0,
    "umi.fukuoka.jp" => 0,
    "usui.fukuoka.jp" => 0,
    "yamada.fukuoka.jp" => 0,
    "yame.fukuoka.jp" => 0,
    "yanagawa.fukuoka.jp" => 0,
    "yukuhashi.fukuoka.jp" => 0,
    "aizubange.fukushima.jp" => 0,
    "aizumisato.fukushima.jp" => 0,
    "aizuwakamatsu.fukushima.jp" => 0,
    "asakawa.fukushima.jp" => 0,
    "bandai.fukushima.jp" => 0,
    "date.fukushima.jp" => 0,
    "fukushima.fukushima.jp" => 0,
    "furudono.fukushima.jp" => 0,
    "futaba.fukushima.jp" => 0,
    "hanawa.fukushima.jp" => 0,
    "higashi.fukushima.jp" => 0,
    "hirata.fukushima.jp" => 0,
    "hirono.fukushima.jp" => 0,
    "iitate.fukushima.jp" => 0,
    "inawashiro.fukushima.jp" => 0,
    "ishikawa.fukushima.jp" => 0,
    "iwaki.fukushima.jp" => 0,
    "izumizaki.fukushima.jp" => 0,
    "kagamiishi.fukushima.jp" => 0,
    "kaneyama.fukushima.jp" => 0,
    "kawamata.fukushima.jp" => 0,
    "kitakata.fukushima.jp" => 0,
    "kitashiobara.fukushima.jp" => 0,
    "koori.fukushima.jp" => 0,
    "koriyama.fukushima.jp" => 0,
    "kunimi.fukushima.jp" => 0,
    "miharu.fukushima.jp" => 0,
    "mishima.fukushima.jp" => 0,
    "namie.fukushima.jp" => 0,
    "nango.fukushima.jp" => 0,
    "nishiaizu.fukushima.jp" => 0,
    "nishigo.fukushima.jp" => 0,
    "okuma.fukushima.jp" => 0,
    "omotego.fukushima.jp" => 0,
    "ono.fukushima.jp" => 0,
    "otama.fukushima.jp" => 0,
    "samegawa.fukushima.jp" => 0,
    "shimogo.fukushima.jp" => 0,
    "shirakawa.fukushima.jp" => 0,
    "showa.fukushima.jp" => 0,
    "soma.fukushima.jp" => 0,
    "sukagawa.fukushima.jp" => 0,
    "taishin.fukushima.jp" => 0,
    "tamakawa.fukushima.jp" => 0,
    "tanagura.fukushima.jp" => 0,
    "tenei.fukushima.jp" => 0,
    "yabuki.fukushima.jp" => 0,
    "yamato.fukushima.jp" => 0,
    "yamatsuri.fukushima.jp" => 0,
    "yanaizu.fukushima.jp" => 0,
    "yugawa.fukushima.jp" => 0,
    "anpachi.gifu.jp" => 0,
    "ena.gifu.jp" => 0,
    "gifu.gifu.jp" => 0,
    "ginan.gifu.jp" => 0,
    "godo.gifu.jp" => 0,
    "gujo.gifu.jp" => 0,
    "hashima.gifu.jp" => 0,
    "hichiso.gifu.jp" => 0,
    "hida.gifu.jp" => 0,
    "higashishirakawa.gifu.jp" => 0,
    "ibigawa.gifu.jp" => 0,
    "ikeda.gifu.jp" => 0,
    "kakamigahara.gifu.jp" => 0,
    "kani.gifu.jp" => 0,
    "kasahara.gifu.jp" => 0,
    "kasamatsu.gifu.jp" => 0,
    "kawaue.gifu.jp" => 0,
    "kitagata.gifu.jp" => 0,
    "mino.gifu.jp" => 0,
    "minokamo.gifu.jp" => 0,
    "mitake.gifu.jp" => 0,
    "mizunami.gifu.jp" => 0,
    "motosu.gifu.jp" => 0,
    "nakatsugawa.gifu.jp" => 0,
    "ogaki.gifu.jp" => 0,
    "sakahogi.gifu.jp" => 0,
    "seki.gifu.jp" => 0,
    "sekigahara.gifu.jp" => 0,
    "shirakawa.gifu.jp" => 0,
    "tajimi.gifu.jp" => 0,
    "takayama.gifu.jp" => 0,
    "tarui.gifu.jp" => 0,
    "toki.gifu.jp" => 0,
    "tomika.gifu.jp" => 0,
    "wanouchi.gifu.jp" => 0,
    "yamagata.gifu.jp" => 0,
    "yaotsu.gifu.jp" => 0,
    "yoro.gifu.jp" => 0,
    "annaka.gunma.jp" => 0,
    "chiyoda.gunma.jp" => 0,
    "fujioka.gunma.jp" => 0,
    "higashiagatsuma.gunma.jp" => 0,
    "isesaki.gunma.jp" => 0,
    "itakura.gunma.jp" => 0,
    "kanna.gunma.jp" => 0,
    "kanra.gunma.jp" => 0,
    "katashina.gunma.jp" => 0,
    "kawaba.gunma.jp" => 0,
    "kiryu.gunma.jp" => 0,
    "kusatsu.gunma.jp" => 0,
    "maebashi.gunma.jp" => 0,
    "meiwa.gunma.jp" => 0,
    "midori.gunma.jp" => 0,
    "minakami.gunma.jp" => 0,
    "naganohara.gunma.jp" => 0,
    "nakanojo.gunma.jp" => 0,
    "nanmoku.gunma.jp" => 0,
    "numata.gunma.jp" => 0,
    "oizumi.gunma.jp" => 0,
    "ora.gunma.jp" => 0,
    "ota.gunma.jp" => 0,
    "shibukawa.gunma.jp" => 0,
    "shimonita.gunma.jp" => 0,
    "shinto.gunma.jp" => 0,
    "showa.gunma.jp" => 0,
    "takasaki.gunma.jp" => 0,
    "takayama.gunma.jp" => 0,
    "tamamura.gunma.jp" => 0,
    "tatebayashi.gunma.jp" => 0,
    "tomioka.gunma.jp" => 0,
    "tsukiyono.gunma.jp" => 0,
    "tsumagoi.gunma.jp" => 0,
    "ueno.gunma.jp" => 0,
    "yoshioka.gunma.jp" => 0,
    "asaminami.hiroshima.jp" => 0,
    "daiwa.hiroshima.jp" => 0,
    "etajima.hiroshima.jp" => 0,
    "fuchu.hiroshima.jp" => 0,
    "fukuyama.hiroshima.jp" => 0,
    "hatsukaichi.hiroshima.jp" => 0,
    "higashihiroshima.hiroshima.jp" => 0,
    "hongo.hiroshima.jp" => 0,
    "jinsekikogen.hiroshima.jp" => 0,
    "kaita.hiroshima.jp" => 0,
    "kui.hiroshima.jp" => 0,
    "kumano.hiroshima.jp" => 0,
    "kure.hiroshima.jp" => 0,
    "mihara.hiroshima.jp" => 0,
    "miyoshi.hiroshima.jp" => 0,
    "naka.hiroshima.jp" => 0,
    "onomichi.hiroshima.jp" => 0,
    "osakikamijima.hiroshima.jp" => 0,
    "otake.hiroshima.jp" => 0,
    "saka.hiroshima.jp" => 0,
    "sera.hiroshima.jp" => 0,
    "seranishi.hiroshima.jp" => 0,
    "shinichi.hiroshima.jp" => 0,
    "shobara.hiroshima.jp" => 0,
    "takehara.hiroshima.jp" => 0,
    "abashiri.hokkaido.jp" => 0,
    "abira.hokkaido.jp" => 0,
    "aibetsu.hokkaido.jp" => 0,
    "akabira.hokkaido.jp" => 0,
    "akkeshi.hokkaido.jp" => 0,
    "asahikawa.hokkaido.jp" => 0,
    "ashibetsu.hokkaido.jp" => 0,
    "ashoro.hokkaido.jp" => 0,
    "assabu.hokkaido.jp" => 0,
    "atsuma.hokkaido.jp" => 0,
    "bibai.hokkaido.jp" => 0,
    "biei.hokkaido.jp" => 0,
    "bifuka.hokkaido.jp" => 0,
    "bihoro.hokkaido.jp" => 0,
    "biratori.hokkaido.jp" => 0,
    "chippubetsu.hokkaido.jp" => 0,
    "chitose.hokkaido.jp" => 0,
    "date.hokkaido.jp" => 0,
    "ebetsu.hokkaido.jp" => 0,
    "embetsu.hokkaido.jp" => 0,
    "eniwa.hokkaido.jp" => 0,
    "erimo.hokkaido.jp" => 0,
    "esan.hokkaido.jp" => 0,
    "esashi.hokkaido.jp" => 0,
    "fukagawa.hokkaido.jp" => 0,
    "fukushima.hokkaido.jp" => 0,
    "furano.hokkaido.jp" => 0,
    "furubira.hokkaido.jp" => 0,
    "haboro.hokkaido.jp" => 0,
    "hakodate.hokkaido.jp" => 0,
    "hamatonbetsu.hokkaido.jp" => 0,
    "hidaka.hokkaido.jp" => 0,
    "higashikagura.hokkaido.jp" => 0,
    "higashikawa.hokkaido.jp" => 0,
    "hiroo.hokkaido.jp" => 0,
    "hokuryu.hokkaido.jp" => 0,
    "hokuto.hokkaido.jp" => 0,
    "honbetsu.hokkaido.jp" => 0,
    "horokanai.hokkaido.jp" => 0,
    "horonobe.hokkaido.jp" => 0,
    "ikeda.hokkaido.jp" => 0,
    "imakane.hokkaido.jp" => 0,
    "ishikari.hokkaido.jp" => 0,
    "iwamizawa.hokkaido.jp" => 0,
    "iwanai.hokkaido.jp" => 0,
    "kamifurano.hokkaido.jp" => 0,
    "kamikawa.hokkaido.jp" => 0,
    "kamishihoro.hokkaido.jp" => 0,
    "kamisunagawa.hokkaido.jp" => 0,
    "kamoenai.hokkaido.jp" => 0,
    "kayabe.hokkaido.jp" => 0,
    "kembuchi.hokkaido.jp" => 0,
    "kikonai.hokkaido.jp" => 0,
    "kimobetsu.hokkaido.jp" => 0,
    "kitahiroshima.hokkaido.jp" => 0,
    "kitami.hokkaido.jp" => 0,
    "kiyosato.hokkaido.jp" => 0,
    "koshimizu.hokkaido.jp" => 0,
    "kunneppu.hokkaido.jp" => 0,
    "kuriyama.hokkaido.jp" => 0,
    "kuromatsunai.hokkaido.jp" => 0,
    "kushiro.hokkaido.jp" => 0,
    "kutchan.hokkaido.jp" => 0,
    "kyowa.hokkaido.jp" => 0,
    "mashike.hokkaido.jp" => 0,
    "matsumae.hokkaido.jp" => 0,
    "mikasa.hokkaido.jp" => 0,
    "minamifurano.hokkaido.jp" => 0,
    "mombetsu.hokkaido.jp" => 0,
    "moseushi.hokkaido.jp" => 0,
    "mukawa.hokkaido.jp" => 0,
    "muroran.hokkaido.jp" => 0,
    "naie.hokkaido.jp" => 0,
    "nakagawa.hokkaido.jp" => 0,
    "nakasatsunai.hokkaido.jp" => 0,
    "nakatombetsu.hokkaido.jp" => 0,
    "nanae.hokkaido.jp" => 0,
    "nanporo.hokkaido.jp" => 0,
    "nayoro.hokkaido.jp" => 0,
    "nemuro.hokkaido.jp" => 0,
    "niikappu.hokkaido.jp" => 0,
    "niki.hokkaido.jp" => 0,
    "nishiokoppe.hokkaido.jp" => 0,
    "noboribetsu.hokkaido.jp" => 0,
    "numata.hokkaido.jp" => 0,
    "obihiro.hokkaido.jp" => 0,
    "obira.hokkaido.jp" => 0,
    "oketo.hokkaido.jp" => 0,
    "okoppe.hokkaido.jp" => 0,
    "otaru.hokkaido.jp" => 0,
    "otobe.hokkaido.jp" => 0,
    "otofuke.hokkaido.jp" => 0,
    "otoineppu.hokkaido.jp" => 0,
    "oumu.hokkaido.jp" => 0,
    "ozora.hokkaido.jp" => 0,
    "pippu.hokkaido.jp" => 0,
    "rankoshi.hokkaido.jp" => 0,
    "rebun.hokkaido.jp" => 0,
    "rikubetsu.hokkaido.jp" => 0,
    "rishiri.hokkaido.jp" => 0,
    "rishirifuji.hokkaido.jp" => 0,
    "saroma.hokkaido.jp" => 0,
    "sarufutsu.hokkaido.jp" => 0,
    "shakotan.hokkaido.jp" => 0,
    "shari.hokkaido.jp" => 0,
    "shibecha.hokkaido.jp" => 0,
    "shibetsu.hokkaido.jp" => 0,
    "shikabe.hokkaido.jp" => 0,
    "shikaoi.hokkaido.jp" => 0,
    "shimamaki.hokkaido.jp" => 0,
    "shimizu.hokkaido.jp" => 0,
    "shimokawa.hokkaido.jp" => 0,
    "shinshinotsu.hokkaido.jp" => 0,
    "shintoku.hokkaido.jp" => 0,
    "shiranuka.hokkaido.jp" => 0,
    "shiraoi.hokkaido.jp" => 0,
    "shiriuchi.hokkaido.jp" => 0,
    "sobetsu.hokkaido.jp" => 0,
    "sunagawa.hokkaido.jp" => 0,
    "taiki.hokkaido.jp" => 0,
    "takasu.hokkaido.jp" => 0,
    "takikawa.hokkaido.jp" => 0,
    "takinoue.hokkaido.jp" => 0,
    "teshikaga.hokkaido.jp" => 0,
    "tobetsu.hokkaido.jp" => 0,
    "tohma.hokkaido.jp" => 0,
    "tomakomai.hokkaido.jp" => 0,
    "tomari.hokkaido.jp" => 0,
    "toya.hokkaido.jp" => 0,
    "toyako.hokkaido.jp" => 0,
    "toyotomi.hokkaido.jp" => 0,
    "toyoura.hokkaido.jp" => 0,
    "tsubetsu.hokkaido.jp" => 0,
    "tsukigata.hokkaido.jp" => 0,
    "urakawa.hokkaido.jp" => 0,
    "urausu.hokkaido.jp" => 0,
    "uryu.hokkaido.jp" => 0,
    "utashinai.hokkaido.jp" => 0,
    "wakkanai.hokkaido.jp" => 0,
    "wassamu.hokkaido.jp" => 0,
    "yakumo.hokkaido.jp" => 0,
    "yoichi.hokkaido.jp" => 0,
    "aioi.hyogo.jp" => 0,
    "akashi.hyogo.jp" => 0,
    "ako.hyogo.jp" => 0,
    "amagasaki.hyogo.jp" => 0,
    "aogaki.hyogo.jp" => 0,
    "asago.hyogo.jp" => 0,
    "ashiya.hyogo.jp" => 0,
    "awaji.hyogo.jp" => 0,
    "fukusaki.hyogo.jp" => 0,
    "goshiki.hyogo.jp" => 0,
    "harima.hyogo.jp" => 0,
    "himeji.hyogo.jp" => 0,
    "ichikawa.hyogo.jp" => 0,
    "inagawa.hyogo.jp" => 0,
    "itami.hyogo.jp" => 0,
    "kakogawa.hyogo.jp" => 0,
    "kamigori.hyogo.jp" => 0,
    "kamikawa.hyogo.jp" => 0,
    "kasai.hyogo.jp" => 0,
    "kasuga.hyogo.jp" => 0,
    "kawanishi.hyogo.jp" => 0,
    "miki.hyogo.jp" => 0,
    "minamiawaji.hyogo.jp" => 0,
    "nishinomiya.hyogo.jp" => 0,
    "nishiwaki.hyogo.jp" => 0,
    "ono.hyogo.jp" => 0,
    "sanda.hyogo.jp" => 0,
    "sannan.hyogo.jp" => 0,
    "sasayama.hyogo.jp" => 0,
    "sayo.hyogo.jp" => 0,
    "shingu.hyogo.jp" => 0,
    "shinonsen.hyogo.jp" => 0,
    "shiso.hyogo.jp" => 0,
    "sumoto.hyogo.jp" => 0,
    "taishi.hyogo.jp" => 0,
    "taka.hyogo.jp" => 0,
    "takarazuka.hyogo.jp" => 0,
    "takasago.hyogo.jp" => 0,
    "takino.hyogo.jp" => 0,
    "tamba.hyogo.jp" => 0,
    "tatsuno.hyogo.jp" => 0,
    "toyooka.hyogo.jp" => 0,
    "yabu.hyogo.jp" => 0,
    "yashiro.hyogo.jp" => 0,
    "yoka.hyogo.jp" => 0,
    "yokawa.hyogo.jp" => 0,
    "ami.ibaraki.jp" => 0,
    "asahi.ibaraki.jp" => 0,
    "bando.ibaraki.jp" => 0,
    "chikusei.ibaraki.jp" => 0,
    "daigo.ibaraki.jp" => 0,
    "fujishiro.ibaraki.jp" => 0,
    "hitachi.ibaraki.jp" => 0,
    "hitachinaka.ibaraki.jp" => 0,
    "hitachiomiya.ibaraki.jp" => 0,
    "hitachiota.ibaraki.jp" => 0,
    "ibaraki.ibaraki.jp" => 0,
    "ina.ibaraki.jp" => 0,
    "inashiki.ibaraki.jp" => 0,
    "itako.ibaraki.jp" => 0,
    "iwama.ibaraki.jp" => 0,
    "joso.ibaraki.jp" => 0,
    "kamisu.ibaraki.jp" => 0,
    "kasama.ibaraki.jp" => 0,
    "kashima.ibaraki.jp" => 0,
    "kasumigaura.ibaraki.jp" => 0,
    "koga.ibaraki.jp" => 0,
    "miho.ibaraki.jp" => 0,
    "mito.ibaraki.jp" => 0,
    "moriya.ibaraki.jp" => 0,
    "naka.ibaraki.jp" => 0,
    "namegata.ibaraki.jp" => 0,
    "oarai.ibaraki.jp" => 0,
    "ogawa.ibaraki.jp" => 0,
    "omitama.ibaraki.jp" => 0,
    "ryugasaki.ibaraki.jp" => 0,
    "sakai.ibaraki.jp" => 0,
    "sakuragawa.ibaraki.jp" => 0,
    "shimodate.ibaraki.jp" => 0,
    "shimotsuma.ibaraki.jp" => 0,
    "shirosato.ibaraki.jp" => 0,
    "sowa.ibaraki.jp" => 0,
    "suifu.ibaraki.jp" => 0,
    "takahagi.ibaraki.jp" => 0,
    "tamatsukuri.ibaraki.jp" => 0,
    "tokai.ibaraki.jp" => 0,
    "tomobe.ibaraki.jp" => 0,
    "tone.ibaraki.jp" => 0,
    "toride.ibaraki.jp" => 0,
    "tsuchiura.ibaraki.jp" => 0,
    "tsukuba.ibaraki.jp" => 0,
    "uchihara.ibaraki.jp" => 0,
    "ushiku.ibaraki.jp" => 0,
    "yachiyo.ibaraki.jp" => 0,
    "yamagata.ibaraki.jp" => 0,
    "yawara.ibaraki.jp" => 0,
    "yuki.ibaraki.jp" => 0,
    "anamizu.ishikawa.jp" => 0,
    "hakui.ishikawa.jp" => 0,
    "hakusan.ishikawa.jp" => 0,
    "kaga.ishikawa.jp" => 0,
    "kahoku.ishikawa.jp" => 0,
    "kanazawa.ishikawa.jp" => 0,
    "kawakita.ishikawa.jp" => 0,
    "komatsu.ishikawa.jp" => 0,
    "nakanoto.ishikawa.jp" => 0,
    "nanao.ishikawa.jp" => 0,
    "nomi.ishikawa.jp" => 0,
    "nonoichi.ishikawa.jp" => 0,
    "noto.ishikawa.jp" => 0,
    "shika.ishikawa.jp" => 0,
    "suzu.ishikawa.jp" => 0,
    "tsubata.ishikawa.jp" => 0,
    "tsurugi.ishikawa.jp" => 0,
    "uchinada.ishikawa.jp" => 0,
    "wajima.ishikawa.jp" => 0,
    "fudai.iwate.jp" => 0,
    "fujisawa.iwate.jp" => 0,
    "hanamaki.iwate.jp" => 0,
    "hiraizumi.iwate.jp" => 0,
    "hirono.iwate.jp" => 0,
    "ichinohe.iwate.jp" => 0,
    "ichinoseki.iwate.jp" => 0,
    "iwaizumi.iwate.jp" => 0,
    "iwate.iwate.jp" => 0,
    "joboji.iwate.jp" => 0,
    "kamaishi.iwate.jp" => 0,
    "kanegasaki.iwate.jp" => 0,
    "karumai.iwate.jp" => 0,
    "kawai.iwate.jp" => 0,
    "kitakami.iwate.jp" => 0,
    "kuji.iwate.jp" => 0,
    "kunohe.iwate.jp" => 0,
    "kuzumaki.iwate.jp" => 0,
    "miyako.iwate.jp" => 0,
    "mizusawa.iwate.jp" => 0,
    "morioka.iwate.jp" => 0,
    "ninohe.iwate.jp" => 0,
    "noda.iwate.jp" => 0,
    "ofunato.iwate.jp" => 0,
    "oshu.iwate.jp" => 0,
    "otsuchi.iwate.jp" => 0,
    "rikuzentakata.iwate.jp" => 0,
    "shiwa.iwate.jp" => 0,
    "shizukuishi.iwate.jp" => 0,
    "sumita.iwate.jp" => 0,
    "takizawa.iwate.jp" => 0,
    "tanohata.iwate.jp" => 0,
    "tono.iwate.jp" => 0,
    "yahaba.iwate.jp" => 0,
    "yamada.iwate.jp" => 0,
    "ayagawa.kagawa.jp" => 0,
    "higashikagawa.kagawa.jp" => 0,
    "kanonji.kagawa.jp" => 0,
    "kotohira.kagawa.jp" => 0,
    "manno.kagawa.jp" => 0,
    "marugame.kagawa.jp" => 0,
    "mitoyo.kagawa.jp" => 0,
    "naoshima.kagawa.jp" => 0,
    "sanuki.kagawa.jp" => 0,
    "tadotsu.kagawa.jp" => 0,
    "takamatsu.kagawa.jp" => 0,
    "tonosho.kagawa.jp" => 0,
    "uchinomi.kagawa.jp" => 0,
    "utazu.kagawa.jp" => 0,
    "zentsuji.kagawa.jp" => 0,
    "akune.kagoshima.jp" => 0,
    "amami.kagoshima.jp" => 0,
    "hioki.kagoshima.jp" => 0,
    "isa.kagoshima.jp" => 0,
    "isen.kagoshima.jp" => 0,
    "izumi.kagoshima.jp" => 0,
    "kagoshima.kagoshima.jp" => 0,
    "kanoya.kagoshima.jp" => 0,
    "kawanabe.kagoshima.jp" => 0,
    "kinko.kagoshima.jp" => 0,
    "kouyama.kagoshima.jp" => 0,
    "makurazaki.kagoshima.jp" => 0,
    "matsumoto.kagoshima.jp" => 0,
    "minamitane.kagoshima.jp" => 0,
    "nakatane.kagoshima.jp" => 0,
    "nishinoomote.kagoshima.jp" => 0,
    "satsumasendai.kagoshima.jp" => 0,
    "soo.kagoshima.jp" => 0,
    "tarumizu.kagoshima.jp" => 0,
    "yusui.kagoshima.jp" => 0,
    "aikawa.kanagawa.jp" => 0,
    "atsugi.kanagawa.jp" => 0,
    "ayase.kanagawa.jp" => 0,
    "chigasaki.kanagawa.jp" => 0,
    "ebina.kanagawa.jp" => 0,
    "fujisawa.kanagawa.jp" => 0,
    "hadano.kanagawa.jp" => 0,
    "hakone.kanagawa.jp" => 0,
    "hiratsuka.kanagawa.jp" => 0,
    "isehara.kanagawa.jp" => 0,
    "kaisei.kanagawa.jp" => 0,
    "kamakura.kanagawa.jp" => 0,
    "kiyokawa.kanagawa.jp" => 0,
    "matsuda.kanagawa.jp" => 0,
    "minamiashigara.kanagawa.jp" => 0,
    "miura.kanagawa.jp" => 0,
    "nakai.kanagawa.jp" => 0,
    "ninomiya.kanagawa.jp" => 0,
    "odawara.kanagawa.jp" => 0,
    "oi.kanagawa.jp" => 0,
    "oiso.kanagawa.jp" => 0,
    "sagamihara.kanagawa.jp" => 0,
    "samukawa.kanagawa.jp" => 0,
    "tsukui.kanagawa.jp" => 0,
    "yamakita.kanagawa.jp" => 0,
    "yamato.kanagawa.jp" => 0,
    "yokosuka.kanagawa.jp" => 0,
    "yugawara.kanagawa.jp" => 0,
    "zama.kanagawa.jp" => 0,
    "zushi.kanagawa.jp" => 0,
    "aki.kochi.jp" => 0,
    "geisei.kochi.jp" => 0,
    "hidaka.kochi.jp" => 0,
    "higashitsuno.kochi.jp" => 0,
    "ino.kochi.jp" => 0,
    "kagami.kochi.jp" => 0,
    "kami.kochi.jp" => 0,
    "kitagawa.kochi.jp" => 0,
    "kochi.kochi.jp" => 0,
    "mihara.kochi.jp" => 0,
    "motoyama.kochi.jp" => 0,
    "muroto.kochi.jp" => 0,
    "nahari.kochi.jp" => 0,
    "nakamura.kochi.jp" => 0,
    "nankoku.kochi.jp" => 0,
    "nishitosa.kochi.jp" => 0,
    "niyodogawa.kochi.jp" => 0,
    "ochi.kochi.jp" => 0,
    "okawa.kochi.jp" => 0,
    "otoyo.kochi.jp" => 0,
    "otsuki.kochi.jp" => 0,
    "sakawa.kochi.jp" => 0,
    "sukumo.kochi.jp" => 0,
    "susaki.kochi.jp" => 0,
    "tosa.kochi.jp" => 0,
    "tosashimizu.kochi.jp" => 0,
    "toyo.kochi.jp" => 0,
    "tsuno.kochi.jp" => 0,
    "umaji.kochi.jp" => 0,
    "yasuda.kochi.jp" => 0,
    "yusuhara.kochi.jp" => 0,
    "amakusa.kumamoto.jp" => 0,
    "arao.kumamoto.jp" => 0,
    "aso.kumamoto.jp" => 0,
    "choyo.kumamoto.jp" => 0,
    "gyokuto.kumamoto.jp" => 0,
    "hitoyoshi.kumamoto.jp" => 0,
    "kamiamakusa.kumamoto.jp" => 0,
    "kashima.kumamoto.jp" => 0,
    "kikuchi.kumamoto.jp" => 0,
    "kosa.kumamoto.jp" => 0,
    "kumamoto.kumamoto.jp" => 0,
    "mashiki.kumamoto.jp" => 0,
    "mifune.kumamoto.jp" => 0,
    "minamata.kumamoto.jp" => 0,
    "minamioguni.kumamoto.jp" => 0,
    "nagasu.kumamoto.jp" => 0,
    "nishihara.kumamoto.jp" => 0,
    "oguni.kumamoto.jp" => 0,
    "ozu.kumamoto.jp" => 0,
    "sumoto.kumamoto.jp" => 0,
    "takamori.kumamoto.jp" => 0,
    "uki.kumamoto.jp" => 0,
    "uto.kumamoto.jp" => 0,
    "yamaga.kumamoto.jp" => 0,
    "yamato.kumamoto.jp" => 0,
    "yatsushiro.kumamoto.jp" => 0,
    "ayabe.kyoto.jp" => 0,
    "fukuchiyama.kyoto.jp" => 0,
    "higashiyama.kyoto.jp" => 0,
    "ide.kyoto.jp" => 0,
    "ine.kyoto.jp" => 0,
    "joyo.kyoto.jp" => 0,
    "kameoka.kyoto.jp" => 0,
    "kamo.kyoto.jp" => 0,
    "kita.kyoto.jp" => 0,
    "kizu.kyoto.jp" => 0,
    "kumiyama.kyoto.jp" => 0,
    "kyotamba.kyoto.jp" => 0,
    "kyotanabe.kyoto.jp" => 0,
    "kyotango.kyoto.jp" => 0,
    "maizuru.kyoto.jp" => 0,
    "minami.kyoto.jp" => 0,
    "minamiyamashiro.kyoto.jp" => 0,
    "miyazu.kyoto.jp" => 0,
    "muko.kyoto.jp" => 0,
    "nagaokakyo.kyoto.jp" => 0,
    "nakagyo.kyoto.jp" => 0,
    "nantan.kyoto.jp" => 0,
    "oyamazaki.kyoto.jp" => 0,
    "sakyo.kyoto.jp" => 0,
    "seika.kyoto.jp" => 0,
    "tanabe.kyoto.jp" => 0,
    "uji.kyoto.jp" => 0,
    "ujitawara.kyoto.jp" => 0,
    "wazuka.kyoto.jp" => 0,
    "yamashina.kyoto.jp" => 0,
    "yawata.kyoto.jp" => 0,
    "asahi.mie.jp" => 0,
    "inabe.mie.jp" => 0,
    "ise.mie.jp" => 0,
    "kameyama.mie.jp" => 0,
    "kawagoe.mie.jp" => 0,
    "kiho.mie.jp" => 0,
    "kisosaki.mie.jp" => 0,
    "kiwa.mie.jp" => 0,
    "komono.mie.jp" => 0,
    "kumano.mie.jp" => 0,
    "kuwana.mie.jp" => 0,
    "matsusaka.mie.jp" => 0,
    "meiwa.mie.jp" => 0,
    "mihama.mie.jp" => 0,
    "minamiise.mie.jp" => 0,
    "misugi.mie.jp" => 0,
    "miyama.mie.jp" => 0,
    "nabari.mie.jp" => 0,
    "shima.mie.jp" => 0,
    "suzuka.mie.jp" => 0,
    "tado.mie.jp" => 0,
    "taiki.mie.jp" => 0,
    "taki.mie.jp" => 0,
    "tamaki.mie.jp" => 0,
    "toba.mie.jp" => 0,
    "tsu.mie.jp" => 0,
    "udono.mie.jp" => 0,
    "ureshino.mie.jp" => 0,
    "watarai.mie.jp" => 0,
    "yokkaichi.mie.jp" => 0,
    "furukawa.miyagi.jp" => 0,
    "higashimatsushima.miyagi.jp" => 0,
    "ishinomaki.miyagi.jp" => 0,
    "iwanuma.miyagi.jp" => 0,
    "kakuda.miyagi.jp" => 0,
    "kami.miyagi.jp" => 0,
    "kawasaki.miyagi.jp" => 0,
    "kesennuma.miyagi.jp" => 0,
    "marumori.miyagi.jp" => 0,
    "matsushima.miyagi.jp" => 0,
    "minamisanriku.miyagi.jp" => 0,
    "misato.miyagi.jp" => 0,
    "murata.miyagi.jp" => 0,
    "natori.miyagi.jp" => 0,
    "ogawara.miyagi.jp" => 0,
    "ohira.miyagi.jp" => 0,
    "onagawa.miyagi.jp" => 0,
    "osaki.miyagi.jp" => 0,
    "rifu.miyagi.jp" => 0,
    "semine.miyagi.jp" => 0,
    "shibata.miyagi.jp" => 0,
    "shichikashuku.miyagi.jp" => 0,
    "shikama.miyagi.jp" => 0,
    "shiogama.miyagi.jp" => 0,
    "shiroishi.miyagi.jp" => 0,
    "tagajo.miyagi.jp" => 0,
    "taiwa.miyagi.jp" => 0,
    "tome.miyagi.jp" => 0,
    "tomiya.miyagi.jp" => 0,
    "wakuya.miyagi.jp" => 0,
    "watari.miyagi.jp" => 0,
    "yamamoto.miyagi.jp" => 0,
    "zao.miyagi.jp" => 0,
    "aya.miyazaki.jp" => 0,
    "ebino.miyazaki.jp" => 0,
    "gokase.miyazaki.jp" => 0,
    "hyuga.miyazaki.jp" => 0,
    "kadogawa.miyazaki.jp" => 0,
    "kawaminami.miyazaki.jp" => 0,
    "kijo.miyazaki.jp" => 0,
    "kitagawa.miyazaki.jp" => 0,
    "kitakata.miyazaki.jp" => 0,
    "kitaura.miyazaki.jp" => 0,
    "kobayashi.miyazaki.jp" => 0,
    "kunitomi.miyazaki.jp" => 0,
    "kushima.miyazaki.jp" => 0,
    "mimata.miyazaki.jp" => 0,
    "miyakonojo.miyazaki.jp" => 0,
    "miyazaki.miyazaki.jp" => 0,
    "morotsuka.miyazaki.jp" => 0,
    "nichinan.miyazaki.jp" => 0,
    "nishimera.miyazaki.jp" => 0,
    "nobeoka.miyazaki.jp" => 0,
    "saito.miyazaki.jp" => 0,
    "shiiba.miyazaki.jp" => 0,
    "shintomi.miyazaki.jp" => 0,
    "takaharu.miyazaki.jp" => 0,
    "takanabe.miyazaki.jp" => 0,
    "takazaki.miyazaki.jp" => 0,
    "tsuno.miyazaki.jp" => 0,
    "achi.nagano.jp" => 0,
    "agematsu.nagano.jp" => 0,
    "anan.nagano.jp" => 0,
    "aoki.nagano.jp" => 0,
    "asahi.nagano.jp" => 0,
    "azumino.nagano.jp" => 0,
    "chikuhoku.nagano.jp" => 0,
    "chikuma.nagano.jp" => 0,
    "chino.nagano.jp" => 0,
    "fujimi.nagano.jp" => 0,
    "hakuba.nagano.jp" => 0,
    "hara.nagano.jp" => 0,
    "hiraya.nagano.jp" => 0,
    "iida.nagano.jp" => 0,
    "iijima.nagano.jp" => 0,
    "iiyama.nagano.jp" => 0,
    "iizuna.nagano.jp" => 0,
    "ikeda.nagano.jp" => 0,
    "ikusaka.nagano.jp" => 0,
    "ina.nagano.jp" => 0,
    "karuizawa.nagano.jp" => 0,
    "kawakami.nagano.jp" => 0,
    "kiso.nagano.jp" => 0,
    "kisofukushima.nagano.jp" => 0,
    "kitaaiki.nagano.jp" => 0,
    "komagane.nagano.jp" => 0,
    "komoro.nagano.jp" => 0,
    "matsukawa.nagano.jp" => 0,
    "matsumoto.nagano.jp" => 0,
    "miasa.nagano.jp" => 0,
    "minamiaiki.nagano.jp" => 0,
    "minamimaki.nagano.jp" => 0,
    "minamiminowa.nagano.jp" => 0,
    "minowa.nagano.jp" => 0,
    "miyada.nagano.jp" => 0,
    "miyota.nagano.jp" => 0,
    "mochizuki.nagano.jp" => 0,
    "nagano.nagano.jp" => 0,
    "nagawa.nagano.jp" => 0,
    "nagiso.nagano.jp" => 0,
    "nakagawa.nagano.jp" => 0,
    "nakano.nagano.jp" => 0,
    "nozawaonsen.nagano.jp" => 0,
    "obuse.nagano.jp" => 0,
    "ogawa.nagano.jp" => 0,
    "okaya.nagano.jp" => 0,
    "omachi.nagano.jp" => 0,
    "omi.nagano.jp" => 0,
    "ookuwa.nagano.jp" => 0,
    "ooshika.nagano.jp" => 0,
    "otaki.nagano.jp" => 0,
    "otari.nagano.jp" => 0,
    "sakae.nagano.jp" => 0,
    "sakaki.nagano.jp" => 0,
    "saku.nagano.jp" => 0,
    "sakuho.nagano.jp" => 0,
    "shimosuwa.nagano.jp" => 0,
    "shinanomachi.nagano.jp" => 0,
    "shiojiri.nagano.jp" => 0,
    "suwa.nagano.jp" => 0,
    "suzaka.nagano.jp" => 0,
    "takagi.nagano.jp" => 0,
    "takamori.nagano.jp" => 0,
    "takayama.nagano.jp" => 0,
    "tateshina.nagano.jp" => 0,
    "tatsuno.nagano.jp" => 0,
    "togakushi.nagano.jp" => 0,
    "togura.nagano.jp" => 0,
    "tomi.nagano.jp" => 0,
    "ueda.nagano.jp" => 0,
    "wada.nagano.jp" => 0,
    "yamagata.nagano.jp" => 0,
    "yamanouchi.nagano.jp" => 0,
    "yasaka.nagano.jp" => 0,
    "yasuoka.nagano.jp" => 0,
    "chijiwa.nagasaki.jp" => 0,
    "futsu.nagasaki.jp" => 0,
    "goto.nagasaki.jp" => 0,
    "hasami.nagasaki.jp" => 0,
    "hirado.nagasaki.jp" => 0,
    "iki.nagasaki.jp" => 0,
    "isahaya.nagasaki.jp" => 0,
    "kawatana.nagasaki.jp" => 0,
    "kuchinotsu.nagasaki.jp" => 0,
    "matsuura.nagasaki.jp" => 0,
    "nagasaki.nagasaki.jp" => 0,
    "obama.nagasaki.jp" => 0,
    "omura.nagasaki.jp" => 0,
    "oseto.nagasaki.jp" => 0,
    "saikai.nagasaki.jp" => 0,
    "sasebo.nagasaki.jp" => 0,
    "seihi.nagasaki.jp" => 0,
    "shimabara.nagasaki.jp" => 0,
    "shinkamigoto.nagasaki.jp" => 0,
    "togitsu.nagasaki.jp" => 0,
    "tsushima.nagasaki.jp" => 0,
    "unzen.nagasaki.jp" => 0,
    "ando.nara.jp" => 0,
    "gose.nara.jp" => 0,
    "heguri.nara.jp" => 0,
    "higashiyoshino.nara.jp" => 0,
    "ikaruga.nara.jp" => 0,
    "ikoma.nara.jp" => 0,
    "kamikitayama.nara.jp" => 0,
    "kanmaki.nara.jp" => 0,
    "kashiba.nara.jp" => 0,
    "kashihara.nara.jp" => 0,
    "katsuragi.nara.jp" => 0,
    "kawai.nara.jp" => 0,
    "kawakami.nara.jp" => 0,
    "kawanishi.nara.jp" => 0,
    "koryo.nara.jp" => 0,
    "kurotaki.nara.jp" => 0,
    "mitsue.nara.jp" => 0,
    "miyake.nara.jp" => 0,
    "nara.nara.jp" => 0,
    "nosegawa.nara.jp" => 0,
    "oji.nara.jp" => 0,
    "ouda.nara.jp" => 0,
    "oyodo.nara.jp" => 0,
    "sakurai.nara.jp" => 0,
    "sango.nara.jp" => 0,
    "shimoichi.nara.jp" => 0,
    "shimokitayama.nara.jp" => 0,
    "shinjo.nara.jp" => 0,
    "soni.nara.jp" => 0,
    "takatori.nara.jp" => 0,
    "tawaramoto.nara.jp" => 0,
    "tenkawa.nara.jp" => 0,
    "tenri.nara.jp" => 0,
    "uda.nara.jp" => 0,
    "yamatokoriyama.nara.jp" => 0,
    "yamatotakada.nara.jp" => 0,
    "yamazoe.nara.jp" => 0,
    "yoshino.nara.jp" => 0,
    "aga.niigata.jp" => 0,
    "agano.niigata.jp" => 0,
    "gosen.niigata.jp" => 0,
    "itoigawa.niigata.jp" => 0,
    "izumozaki.niigata.jp" => 0,
    "joetsu.niigata.jp" => 0,
    "kamo.niigata.jp" => 0,
    "kariwa.niigata.jp" => 0,
    "kashiwazaki.niigata.jp" => 0,
    "minamiuonuma.niigata.jp" => 0,
    "mitsuke.niigata.jp" => 0,
    "muika.niigata.jp" => 0,
    "murakami.niigata.jp" => 0,
    "myoko.niigata.jp" => 0,
    "nagaoka.niigata.jp" => 0,
    "niigata.niigata.jp" => 0,
    "ojiya.niigata.jp" => 0,
    "omi.niigata.jp" => 0,
    "sado.niigata.jp" => 0,
    "sanjo.niigata.jp" => 0,
    "seiro.niigata.jp" => 0,
    "seirou.niigata.jp" => 0,
    "sekikawa.niigata.jp" => 0,
    "shibata.niigata.jp" => 0,
    "tagami.niigata.jp" => 0,
    "tainai.niigata.jp" => 0,
    "tochio.niigata.jp" => 0,
    "tokamachi.niigata.jp" => 0,
    "tsubame.niigata.jp" => 0,
    "tsunan.niigata.jp" => 0,
    "uonuma.niigata.jp" => 0,
    "yahiko.niigata.jp" => 0,
    "yoita.niigata.jp" => 0,
    "yuzawa.niigata.jp" => 0,
    "beppu.oita.jp" => 0,
    "bungoono.oita.jp" => 0,
    "bungotakada.oita.jp" => 0,
    "hasama.oita.jp" => 0,
    "hiji.oita.jp" => 0,
    "himeshima.oita.jp" => 0,
    "hita.oita.jp" => 0,
    "kamitsue.oita.jp" => 0,
    "kokonoe.oita.jp" => 0,
    "kuju.oita.jp" => 0,
    "kunisaki.oita.jp" => 0,
    "kusu.oita.jp" => 0,
    "oita.oita.jp" => 0,
    "saiki.oita.jp" => 0,
    "taketa.oita.jp" => 0,
    "tsukumi.oita.jp" => 0,
    "usa.oita.jp" => 0,
    "usuki.oita.jp" => 0,
    "yufu.oita.jp" => 0,
    "akaiwa.okayama.jp" => 0,
    "asakuchi.okayama.jp" => 0,
    "bizen.okayama.jp" => 0,
    "hayashima.okayama.jp" => 0,
    "ibara.okayama.jp" => 0,
    "kagamino.okayama.jp" => 0,
    "kasaoka.okayama.jp" => 0,
    "kibichuo.okayama.jp" => 0,
    "kumenan.okayama.jp" => 0,
    "kurashiki.okayama.jp" => 0,
    "maniwa.okayama.jp" => 0,
    "misaki.okayama.jp" => 0,
    "nagi.okayama.jp" => 0,
    "niimi.okayama.jp" => 0,
    "nishiawakura.okayama.jp" => 0,
    "okayama.okayama.jp" => 0,
    "satosho.okayama.jp" => 0,
    "setouchi.okayama.jp" => 0,
    "shinjo.okayama.jp" => 0,
    "shoo.okayama.jp" => 0,
    "soja.okayama.jp" => 0,
    "takahashi.okayama.jp" => 0,
    "tamano.okayama.jp" => 0,
    "tsuyama.okayama.jp" => 0,
    "wake.okayama.jp" => 0,
    "yakage.okayama.jp" => 0,
    "aguni.okinawa.jp" => 0,
    "ginowan.okinawa.jp" => 0,
    "ginoza.okinawa.jp" => 0,
    "gushikami.okinawa.jp" => 0,
    "haebaru.okinawa.jp" => 0,
    "higashi.okinawa.jp" => 0,
    "hirara.okinawa.jp" => 0,
    "iheya.okinawa.jp" => 0,
    "ishigaki.okinawa.jp" => 0,
    "ishikawa.okinawa.jp" => 0,
    "itoman.okinawa.jp" => 0,
    "izena.okinawa.jp" => 0,
    "kadena.okinawa.jp" => 0,
    "kin.okinawa.jp" => 0,
    "kitadaito.okinawa.jp" => 0,
    "kitanakagusuku.okinawa.jp" => 0,
    "kumejima.okinawa.jp" => 0,
    "kunigami.okinawa.jp" => 0,
    "minamidaito.okinawa.jp" => 0,
    "motobu.okinawa.jp" => 0,
    "nago.okinawa.jp" => 0,
    "naha.okinawa.jp" => 0,
    "nakagusuku.okinawa.jp" => 0,
    "nakijin.okinawa.jp" => 0,
    "nanjo.okinawa.jp" => 0,
    "nishihara.okinawa.jp" => 0,
    "ogimi.okinawa.jp" => 0,
    "okinawa.okinawa.jp" => 0,
    "onna.okinawa.jp" => 0,
    "shimoji.okinawa.jp" => 0,
    "taketomi.okinawa.jp" => 0,
    "tarama.okinawa.jp" => 0,
    "tokashiki.okinawa.jp" => 0,
    "tomigusuku.okinawa.jp" => 0,
    "tonaki.okinawa.jp" => 0,
    "urasoe.okinawa.jp" => 0,
    "uruma.okinawa.jp" => 0,
    "yaese.okinawa.jp" => 0,
    "yomitan.okinawa.jp" => 0,
    "yonabaru.okinawa.jp" => 0,
    "yonaguni.okinawa.jp" => 0,
    "zamami.okinawa.jp" => 0,
    "abeno.osaka.jp" => 0,
    "chihayaakasaka.osaka.jp" => 0,
    "chuo.osaka.jp" => 0,
    "daito.osaka.jp" => 0,
    "fujiidera.osaka.jp" => 0,
    "habikino.osaka.jp" => 0,
    "hannan.osaka.jp" => 0,
    "higashiosaka.osaka.jp" => 0,
    "higashisumiyoshi.osaka.jp" => 0,
    "higashiyodogawa.osaka.jp" => 0,
    "hirakata.osaka.jp" => 0,
    "ibaraki.osaka.jp" => 0,
    "ikeda.osaka.jp" => 0,
    "izumi.osaka.jp" => 0,
    "izumiotsu.osaka.jp" => 0,
    "izumisano.osaka.jp" => 0,
    "kadoma.osaka.jp" => 0,
    "kaizuka.osaka.jp" => 0,
    "kanan.osaka.jp" => 0,
    "kashiwara.osaka.jp" => 0,
    "katano.osaka.jp" => 0,
    "kawachinagano.osaka.jp" => 0,
    "kishiwada.osaka.jp" => 0,
    "kita.osaka.jp" => 0,
    "kumatori.osaka.jp" => 0,
    "matsubara.osaka.jp" => 0,
    "minato.osaka.jp" => 0,
    "minoh.osaka.jp" => 0,
    "misaki.osaka.jp" => 0,
    "moriguchi.osaka.jp" => 0,
    "neyagawa.osaka.jp" => 0,
    "nishi.osaka.jp" => 0,
    "nose.osaka.jp" => 0,
    "osakasayama.osaka.jp" => 0,
    "sakai.osaka.jp" => 0,
    "sayama.osaka.jp" => 0,
    "sennan.osaka.jp" => 0,
    "settsu.osaka.jp" => 0,
    "shijonawate.osaka.jp" => 0,
    "shimamoto.osaka.jp" => 0,
    "suita.osaka.jp" => 0,
    "tadaoka.osaka.jp" => 0,
    "taishi.osaka.jp" => 0,
    "tajiri.osaka.jp" => 0,
    "takaishi.osaka.jp" => 0,
    "takatsuki.osaka.jp" => 0,
    "tondabayashi.osaka.jp" => 0,
    "toyonaka.osaka.jp" => 0,
    "toyono.osaka.jp" => 0,
    "yao.osaka.jp" => 0,
    "ariake.saga.jp" => 0,
    "arita.saga.jp" => 0,
    "fukudomi.saga.jp" => 0,
    "genkai.saga.jp" => 0,
    "hamatama.saga.jp" => 0,
    "hizen.saga.jp" => 0,
    "imari.saga.jp" => 0,
    "kamimine.saga.jp" => 0,
    "kanzaki.saga.jp" => 0,
    "karatsu.saga.jp" => 0,
    "kashima.saga.jp" => 0,
    "kitagata.saga.jp" => 0,
    "kitahata.saga.jp" => 0,
    "kiyama.saga.jp" => 0,
    "kouhoku.saga.jp" => 0,
    "kyuragi.saga.jp" => 0,
    "nishiarita.saga.jp" => 0,
    "ogi.saga.jp" => 0,
    "omachi.saga.jp" => 0,
    "ouchi.saga.jp" => 0,
    "saga.saga.jp" => 0,
    "shiroishi.saga.jp" => 0,
    "taku.saga.jp" => 0,
    "tara.saga.jp" => 0,
    "tosu.saga.jp" => 0,
    "yoshinogari.saga.jp" => 0,
    "arakawa.saitama.jp" => 0,
    "asaka.saitama.jp" => 0,
    "chichibu.saitama.jp" => 0,
    "fujimi.saitama.jp" => 0,
    "fujimino.saitama.jp" => 0,
    "fukaya.saitama.jp" => 0,
    "hanno.saitama.jp" => 0,
    "hanyu.saitama.jp" => 0,
    "hasuda.saitama.jp" => 0,
    "hatogaya.saitama.jp" => 0,
    "hatoyama.saitama.jp" => 0,
    "hidaka.saitama.jp" => 0,
    "higashichichibu.saitama.jp" => 0,
    "higashimatsuyama.saitama.jp" => 0,
    "honjo.saitama.jp" => 0,
    "ina.saitama.jp" => 0,
    "iruma.saitama.jp" => 0,
    "iwatsuki.saitama.jp" => 0,
    "kamiizumi.saitama.jp" => 0,
    "kamikawa.saitama.jp" => 0,
    "kamisato.saitama.jp" => 0,
    "kasukabe.saitama.jp" => 0,
    "kawagoe.saitama.jp" => 0,
    "kawaguchi.saitama.jp" => 0,
    "kawajima.saitama.jp" => 0,
    "kazo.saitama.jp" => 0,
    "kitamoto.saitama.jp" => 0,
    "koshigaya.saitama.jp" => 0,
    "kounosu.saitama.jp" => 0,
    "kuki.saitama.jp" => 0,
    "kumagaya.saitama.jp" => 0,
    "matsubushi.saitama.jp" => 0,
    "minano.saitama.jp" => 0,
    "misato.saitama.jp" => 0,
    "miyashiro.saitama.jp" => 0,
    "miyoshi.saitama.jp" => 0,
    "moroyama.saitama.jp" => 0,
    "nagatoro.saitama.jp" => 0,
    "namegawa.saitama.jp" => 0,
    "niiza.saitama.jp" => 0,
    "ogano.saitama.jp" => 0,
    "ogawa.saitama.jp" => 0,
    "ogose.saitama.jp" => 0,
    "okegawa.saitama.jp" => 0,
    "omiya.saitama.jp" => 0,
    "otaki.saitama.jp" => 0,
    "ranzan.saitama.jp" => 0,
    "ryokami.saitama.jp" => 0,
    "saitama.saitama.jp" => 0,
    "sakado.saitama.jp" => 0,
    "satte.saitama.jp" => 0,
    "sayama.saitama.jp" => 0,
    "shiki.saitama.jp" => 0,
    "shiraoka.saitama.jp" => 0,
    "soka.saitama.jp" => 0,
    "sugito.saitama.jp" => 0,
    "toda.saitama.jp" => 0,
    "tokigawa.saitama.jp" => 0,
    "tokorozawa.saitama.jp" => 0,
    "tsurugashima.saitama.jp" => 0,
    "urawa.saitama.jp" => 0,
    "warabi.saitama.jp" => 0,
    "yashio.saitama.jp" => 0,
    "yokoze.saitama.jp" => 0,
    "yono.saitama.jp" => 0,
    "yorii.saitama.jp" => 0,
    "yoshida.saitama.jp" => 0,
    "yoshikawa.saitama.jp" => 0,
    "yoshimi.saitama.jp" => 0,
    "aisho.shiga.jp" => 0,
    "gamo.shiga.jp" => 0,
    "higashiomi.shiga.jp" => 0,
    "hikone.shiga.jp" => 0,
    "koka.shiga.jp" => 0,
    "konan.shiga.jp" => 0,
    "kosei.shiga.jp" => 0,
    "koto.shiga.jp" => 0,
    "kusatsu.shiga.jp" => 0,
    "maibara.shiga.jp" => 0,
    "moriyama.shiga.jp" => 0,
    "nagahama.shiga.jp" => 0,
    "nishiazai.shiga.jp" => 0,
    "notogawa.shiga.jp" => 0,
    "omihachiman.shiga.jp" => 0,
    "otsu.shiga.jp" => 0,
    "ritto.shiga.jp" => 0,
    "ryuoh.shiga.jp" => 0,
    "takashima.shiga.jp" => 0,
    "takatsuki.shiga.jp" => 0,
    "torahime.shiga.jp" => 0,
    "toyosato.shiga.jp" => 0,
    "yasu.shiga.jp" => 0,
    "akagi.shimane.jp" => 0,
    "ama.shimane.jp" => 0,
    "gotsu.shimane.jp" => 0,
    "hamada.shimane.jp" => 0,
    "higashiizumo.shimane.jp" => 0,
    "hikawa.shimane.jp" => 0,
    "hikimi.shimane.jp" => 0,
    "izumo.shimane.jp" => 0,
    "kakinoki.shimane.jp" => 0,
    "masuda.shimane.jp" => 0,
    "matsue.shimane.jp" => 0,
    "misato.shimane.jp" => 0,
    "nishinoshima.shimane.jp" => 0,
    "ohda.shimane.jp" => 0,
    "okinoshima.shimane.jp" => 0,
    "okuizumo.shimane.jp" => 0,
    "shimane.shimane.jp" => 0,
    "tamayu.shimane.jp" => 0,
    "tsuwano.shimane.jp" => 0,
    "unnan.shimane.jp" => 0,
    "yakumo.shimane.jp" => 0,
    "yasugi.shimane.jp" => 0,
    "yatsuka.shimane.jp" => 0,
    "arai.shizuoka.jp" => 0,
    "atami.shizuoka.jp" => 0,
    "fuji.shizuoka.jp" => 0,
    "fujieda.shizuoka.jp" => 0,
    "fujikawa.shizuoka.jp" => 0,
    "fujinomiya.shizuoka.jp" => 0,
    "fukuroi.shizuoka.jp" => 0,
    "gotemba.shizuoka.jp" => 0,
    "haibara.shizuoka.jp" => 0,
    "hamamatsu.shizuoka.jp" => 0,
    "higashiizu.shizuoka.jp" => 0,
    "ito.shizuoka.jp" => 0,
    "iwata.shizuoka.jp" => 0,
    "izu.shizuoka.jp" => 0,
    "izunokuni.shizuoka.jp" => 0,
    "kakegawa.shizuoka.jp" => 0,
    "kannami.shizuoka.jp" => 0,
    "kawanehon.shizuoka.jp" => 0,
    "kawazu.shizuoka.jp" => 0,
    "kikugawa.shizuoka.jp" => 0,
    "kosai.shizuoka.jp" => 0,
    "makinohara.shizuoka.jp" => 0,
    "matsuzaki.shizuoka.jp" => 0,
    "minamiizu.shizuoka.jp" => 0,
    "mishima.shizuoka.jp" => 0,
    "morimachi.shizuoka.jp" => 0,
    "nishiizu.shizuoka.jp" => 0,
    "numazu.shizuoka.jp" => 0,
    "omaezaki.shizuoka.jp" => 0,
    "shimada.shizuoka.jp" => 0,
    "shimizu.shizuoka.jp" => 0,
    "shimoda.shizuoka.jp" => 0,
    "shizuoka.shizuoka.jp" => 0,
    "susono.shizuoka.jp" => 0,
    "yaizu.shizuoka.jp" => 0,
    "yoshida.shizuoka.jp" => 0,
    "ashikaga.tochigi.jp" => 0,
    "bato.tochigi.jp" => 0,
    "haga.tochigi.jp" => 0,
    "ichikai.tochigi.jp" => 0,
    "iwafune.tochigi.jp" => 0,
    "kaminokawa.tochigi.jp" => 0,
    "kanuma.tochigi.jp" => 0,
    "karasuyama.tochigi.jp" => 0,
    "kuroiso.tochigi.jp" => 0,
    "mashiko.tochigi.jp" => 0,
    "mibu.tochigi.jp" => 0,
    "moka.tochigi.jp" => 0,
    "motegi.tochigi.jp" => 0,
    "nasu.tochigi.jp" => 0,
    "nasushiobara.tochigi.jp" => 0,
    "nikko.tochigi.jp" => 0,
    "nishikata.tochigi.jp" => 0,
    "nogi.tochigi.jp" => 0,
    "ohira.tochigi.jp" => 0,
    "ohtawara.tochigi.jp" => 0,
    "oyama.tochigi.jp" => 0,
    "sakura.tochigi.jp" => 0,
    "sano.tochigi.jp" => 0,
    "shimotsuke.tochigi.jp" => 0,
    "shioya.tochigi.jp" => 0,
    "takanezawa.tochigi.jp" => 0,
    "tochigi.tochigi.jp" => 0,
    "tsuga.tochigi.jp" => 0,
    "ujiie.tochigi.jp" => 0,
    "utsunomiya.tochigi.jp" => 0,
    "yaita.tochigi.jp" => 0,
    "aizumi.tokushima.jp" => 0,
    "anan.tokushima.jp" => 0,
    "ichiba.tokushima.jp" => 0,
    "itano.tokushima.jp" => 0,
    "kainan.tokushima.jp" => 0,
    "komatsushima.tokushima.jp" => 0,
    "matsushige.tokushima.jp" => 0,
    "mima.tokushima.jp" => 0,
    "minami.tokushima.jp" => 0,
    "miyoshi.tokushima.jp" => 0,
    "mugi.tokushima.jp" => 0,
    "nakagawa.tokushima.jp" => 0,
    "naruto.tokushima.jp" => 0,
    "sanagochi.tokushima.jp" => 0,
    "shishikui.tokushima.jp" => 0,
    "tokushima.tokushima.jp" => 0,
    "wajiki.tokushima.jp" => 0,
    "adachi.tokyo.jp" => 0,
    "akiruno.tokyo.jp" => 0,
    "akishima.tokyo.jp" => 0,
    "aogashima.tokyo.jp" => 0,
    "arakawa.tokyo.jp" => 0,
    "bunkyo.tokyo.jp" => 0,
    "chiyoda.tokyo.jp" => 0,
    "chofu.tokyo.jp" => 0,
    "chuo.tokyo.jp" => 0,
    "edogawa.tokyo.jp" => 0,
    "fuchu.tokyo.jp" => 0,
    "fussa.tokyo.jp" => 0,
    "hachijo.tokyo.jp" => 0,
    "hachioji.tokyo.jp" => 0,
    "hamura.tokyo.jp" => 0,
    "higashikurume.tokyo.jp" => 0,
    "higashimurayama.tokyo.jp" => 0,
    "higashiyamato.tokyo.jp" => 0,
    "hino.tokyo.jp" => 0,
    "hinode.tokyo.jp" => 0,
    "hinohara.tokyo.jp" => 0,
    "inagi.tokyo.jp" => 0,
    "itabashi.tokyo.jp" => 0,
    "katsushika.tokyo.jp" => 0,
    "kita.tokyo.jp" => 0,
    "kiyose.tokyo.jp" => 0,
    "kodaira.tokyo.jp" => 0,
    "koganei.tokyo.jp" => 0,
    "kokubunji.tokyo.jp" => 0,
    "komae.tokyo.jp" => 0,
    "koto.tokyo.jp" => 0,
    "kouzushima.tokyo.jp" => 0,
    "kunitachi.tokyo.jp" => 0,
    "machida.tokyo.jp" => 0,
    "meguro.tokyo.jp" => 0,
    "minato.tokyo.jp" => 0,
    "mitaka.tokyo.jp" => 0,
    "mizuho.tokyo.jp" => 0,
    "musashimurayama.tokyo.jp" => 0,
    "musashino.tokyo.jp" => 0,
    "nakano.tokyo.jp" => 0,
    "nerima.tokyo.jp" => 0,
    "ogasawara.tokyo.jp" => 0,
    "okutama.tokyo.jp" => 0,
    "ome.tokyo.jp" => 0,
    "oshima.tokyo.jp" => 0,
    "ota.tokyo.jp" => 0,
    "setagaya.tokyo.jp" => 0,
    "shibuya.tokyo.jp" => 0,
    "shinagawa.tokyo.jp" => 0,
    "shinjuku.tokyo.jp" => 0,
    "suginami.tokyo.jp" => 0,
    "sumida.tokyo.jp" => 0,
    "tachikawa.tokyo.jp" => 0,
    "taito.tokyo.jp" => 0,
    "tama.tokyo.jp" => 0,
    "toshima.tokyo.jp" => 0,
    "chizu.tottori.jp" => 0,
    "hino.tottori.jp" => 0,
    "kawahara.tottori.jp" => 0,
    "koge.tottori.jp" => 0,
    "kotoura.tottori.jp" => 0,
    "misasa.tottori.jp" => 0,
    "nanbu.tottori.jp" => 0,
    "nichinan.tottori.jp" => 0,
    "sakaiminato.tottori.jp" => 0,
    "tottori.tottori.jp" => 0,
    "wakasa.tottori.jp" => 0,
    "yazu.tottori.jp" => 0,
    "yonago.tottori.jp" => 0,
    "asahi.toyama.jp" => 0,
    "fuchu.toyama.jp" => 0,
    "fukumitsu.toyama.jp" => 0,
    "funahashi.toyama.jp" => 0,
    "himi.toyama.jp" => 0,
    "imizu.toyama.jp" => 0,
    "inami.toyama.jp" => 0,
    "johana.toyama.jp" => 0,
    "kamiichi.toyama.jp" => 0,
    "kurobe.toyama.jp" => 0,
    "nakaniikawa.toyama.jp" => 0,
    "namerikawa.toyama.jp" => 0,
    "nanto.toyama.jp" => 0,
    "nyuzen.toyama.jp" => 0,
    "oyabe.toyama.jp" => 0,
    "taira.toyama.jp" => 0,
    "takaoka.toyama.jp" => 0,
    "tateyama.toyama.jp" => 0,
    "toga.toyama.jp" => 0,
    "tonami.toyama.jp" => 0,
    "toyama.toyama.jp" => 0,
    "unazuki.toyama.jp" => 0,
    "uozu.toyama.jp" => 0,
    "yamada.toyama.jp" => 0,
    "arida.wakayama.jp" => 0,
    "aridagawa.wakayama.jp" => 0,
    "gobo.wakayama.jp" => 0,
    "hashimoto.wakayama.jp" => 0,
    "hidaka.wakayama.jp" => 0,
    "hirogawa.wakayama.jp" => 0,
    "inami.wakayama.jp" => 0,
    "iwade.wakayama.jp" => 0,
    "kainan.wakayama.jp" => 0,
    "kamitonda.wakayama.jp" => 0,
    "katsuragi.wakayama.jp" => 0,
    "kimino.wakayama.jp" => 0,
    "kinokawa.wakayama.jp" => 0,
    "kitayama.wakayama.jp" => 0,
    "koya.wakayama.jp" => 0,
    "koza.wakayama.jp" => 0,
    "kozagawa.wakayama.jp" => 0,
    "kudoyama.wakayama.jp" => 0,
    "kushimoto.wakayama.jp" => 0,
    "mihama.wakayama.jp" => 0,
    "misato.wakayama.jp" => 0,
    "nachikatsuura.wakayama.jp" => 0,
    "shingu.wakayama.jp" => 0,
    "shirahama.wakayama.jp" => 0,
    "taiji.wakayama.jp" => 0,
    "tanabe.wakayama.jp" => 0,
    "wakayama.wakayama.jp" => 0,
    "yuasa.wakayama.jp" => 0,
    "yura.wakayama.jp" => 0,
    "asahi.yamagata.jp" => 0,
    "funagata.yamagata.jp" => 0,
    "higashine.yamagata.jp" => 0,
    "iide.yamagata.jp" => 0,
    "kahoku.yamagata.jp" => 0,
    "kaminoyama.yamagata.jp" => 0,
    "kaneyama.yamagata.jp" => 0,
    "kawanishi.yamagata.jp" => 0,
    "mamurogawa.yamagata.jp" => 0,
    "mikawa.yamagata.jp" => 0,
    "murayama.yamagata.jp" => 0,
    "nagai.yamagata.jp" => 0,
    "nakayama.yamagata.jp" => 0,
    "nanyo.yamagata.jp" => 0,
    "nishikawa.yamagata.jp" => 0,
    "obanazawa.yamagata.jp" => 0,
    "oe.yamagata.jp" => 0,
    "oguni.yamagata.jp" => 0,
    "ohkura.yamagata.jp" => 0,
    "oishida.yamagata.jp" => 0,
    "sagae.yamagata.jp" => 0,
    "sakata.yamagata.jp" => 0,
    "sakegawa.yamagata.jp" => 0,
    "shinjo.yamagata.jp" => 0,
    "shirataka.yamagata.jp" => 0,
    "shonai.yamagata.jp" => 0,
    "takahata.yamagata.jp" => 0,
    "tendo.yamagata.jp" => 0,
    "tozawa.yamagata.jp" => 0,
    "tsuruoka.yamagata.jp" => 0,
    "yamagata.yamagata.jp" => 0,
    "yamanobe.yamagata.jp" => 0,
    "yonezawa.yamagata.jp" => 0,
    "yuza.yamagata.jp" => 0,
    "abu.yamaguchi.jp" => 0,
    "hagi.yamaguchi.jp" => 0,
    "hikari.yamaguchi.jp" => 0,
    "hofu.yamaguchi.jp" => 0,
    "iwakuni.yamaguchi.jp" => 0,
    "kudamatsu.yamaguchi.jp" => 0,
    "mitou.yamaguchi.jp" => 0,
    "nagato.yamaguchi.jp" => 0,
    "oshima.yamaguchi.jp" => 0,
    "shimonoseki.yamaguchi.jp" => 0,
    "shunan.yamaguchi.jp" => 0,
    "tabuse.yamaguchi.jp" => 0,
    "tokuyama.yamaguchi.jp" => 0,
    "toyota.yamaguchi.jp" => 0,
    "ube.yamaguchi.jp" => 0,
    "yuu.yamaguchi.jp" => 0,
    "chuo.yamanashi.jp" => 0,
    "doshi.yamanashi.jp" => 0,
    "fuefuki.yamanashi.jp" => 0,
    "fujikawa.yamanashi.jp" => 0,
    "fujikawaguchiko.yamanashi.jp" => 0,
    "fujiyoshida.yamanashi.jp" => 0,
    "hayakawa.yamanashi.jp" => 0,
    "hokuto.yamanashi.jp" => 0,
    "ichikawamisato.yamanashi.jp" => 0,
    "kai.yamanashi.jp" => 0,
    "kofu.yamanashi.jp" => 0,
    "koshu.yamanashi.jp" => 0,
    "kosuge.yamanashi.jp" => 0,
    "minami-alps.yamanashi.jp" => 0,
    "minobu.yamanashi.jp" => 0,
    "nakamichi.yamanashi.jp" => 0,
    "nanbu.yamanashi.jp" => 0,
    "narusawa.yamanashi.jp" => 0,
    "nirasaki.yamanashi.jp" => 0,
    "nishikatsura.yamanashi.jp" => 0,
    "oshino.yamanashi.jp" => 0,
    "otsuki.yamanashi.jp" => 0,
    "showa.yamanashi.jp" => 0,
    "tabayama.yamanashi.jp" => 0,
    "tsuru.yamanashi.jp" => 0,
    "uenohara.yamanashi.jp" => 0,
    "yamanakako.yamanashi.jp" => 0,
    "yamanashi.yamanashi.jp" => 0,
    "ke" => -1,
    "kg" => 0,
    "org.kg" => 0,
    "net.kg" => 0,
    "com.kg" => 0,
    "edu.kg" => 0,
    "gov.kg" => 0,
    "mil.kg" => 0,
    "kh" => -1,
    "ki" => 0,
    "edu.ki" => 0,
    "biz.ki" => 0,
    "net.ki" => 0,
    "org.ki" => 0,
    "gov.ki" => 0,
    "info.ki" => 0,
    "com.ki" => 0,
    "km" => 0,
    "org.km" => 0,
    "nom.km" => 0,
    "gov.km" => 0,
    "prd.km" => 0,
    "tm.km" => 0,
    "edu.km" => 0,
    "mil.km" => 0,
    "ass.km" => 0,
    "com.km" => 0,
    "coop.km" => 0,
    "asso.km" => 0,
    "presse.km" => 0,
    "medecin.km" => 0,
    "notaires.km" => 0,
    "pharmaciens.km" => 0,
    "veterinaire.km" => 0,
    "gouv.km" => 0,
    "kn" => 0,
    "net.kn" => 0,
    "org.kn" => 0,
    "edu.kn" => 0,
    "gov.kn" => 0,
    "kp" => 1,
    "com.kp" => 0,
    "edu.kp" => 0,
    "gov.kp" => 0,
    "org.kp" => 0,
    "rep.kp" => 0,
    "tra.kp" => 0,
    "kr" => 0,
    "ac.kr" => 0,
    "co.kr" => 0,
    "es.kr" => 0,
    "go.kr" => 0,
    "hs.kr" => 0,
    "kg.kr" => 0,
    "mil.kr" => 0,
    "ms.kr" => 0,
    "ne.kr" => 0,
    "or.kr" => 0,
    "pe.kr" => 0,
    "re.kr" => 0,
    "sc.kr" => 0,
    "busan.kr" => 0,
    "chungbuk.kr" => 0,
    "chungnam.kr" => 0,
    "daegu.kr" => 0,
    "daejeon.kr" => 0,
    "gangwon.kr" => 0,
    "gwangju.kr" => 0,
    "gyeongbuk.kr" => 0,
    "gyeonggi.kr" => 0,
    "gyeongnam.kr" => 0,
    "incheon.kr" => 0,
    "jeju.kr" => 0,
    "jeonbuk.kr" => 0,
    "jeonnam.kr" => 0,
    "seoul.kr" => 0,
    "ulsan.kr" => 0,
    "kw" => -1,
    "ky" => 0,
    "edu.ky" => 0,
    "gov.ky" => 0,
    "com.ky" => 0,
    "org.ky" => 0,
    "net.ky" => 0,
    "kz" => 0,
    "org.kz" => 0,
    "edu.kz" => 0,
    "net.kz" => 0,
    "gov.kz" => 0,
    "mil.kz" => 0,
    "com.kz" => 0,
    "la" => 0,
    "int.la" => 0,
    "net.la" => 0,
    "info.la" => 0,
    "edu.la" => 0,
    "gov.la" => 0,
    "per.la" => 0,
    "com.la" => 0,
    "org.la" => 0,
    "lb" => 1,
    "com.lb" => 0,
    "edu.lb" => 0,
    "gov.lb" => 0,
    "net.lb" => 0,
    "org.lb" => 0,
    "lc" => 0,
    "com.lc" => 0,
    "net.lc" => 0,
    "co.lc" => 0,
    "org.lc" => 0,
    "edu.lc" => 0,
    "gov.lc" => 0,
    "li" => 0,
    "lk" => 0,
    "gov.lk" => 0,
    "sch.lk" => 0,
    "net.lk" => 0,
    "int.lk" => 0,
    "com.lk" => 0,
    "org.lk" => 0,
    "edu.lk" => 0,
    "ngo.lk" => 0,
    "soc.lk" => 0,
    "web.lk" => 0,
    "ltd.lk" => 0,
    "assn.lk" => 0,
    "grp.lk" => 0,
    "hotel.lk" => 0,
    "lr" => 1,
    "com.lr" => 0,
    "edu.lr" => 0,
    "gov.lr" => 0,
    "org.lr" => 0,
    "net.lr" => 0,
    "ls" => 0,
    "co.ls" => 0,
    "org.ls" => 0,
    "lt" => 0,
    "gov.lt" => 0,
    "lu" => 0,
    "lv" => 0,
    "com.lv" => 0,
    "edu.lv" => 0,
    "gov.lv" => 0,
    "org.lv" => 0,
    "mil.lv" => 0,
    "id.lv" => 0,
    "net.lv" => 0,
    "asn.lv" => 0,
    "conf.lv" => 0,
    "ly" => 0,
    "com.ly" => 0,
    "net.ly" => 0,
    "gov.ly" => 0,
    "plc.ly" => 0,
    "edu.ly" => 0,
    "sch.ly" => 0,
    "med.ly" => 0,
    "org.ly" => 0,
    "id.ly" => 0,
    "ma" => 0,
    "co.ma" => 0,
    "net.ma" => 0,
    "gov.ma" => 0,
    "org.ma" => 0,
    "ac.ma" => 0,
    "press.ma" => 0,
    "mc" => 0,
    "tm.mc" => 0,
    "asso.mc" => 0,
    "md" => 0,
    "me" => 0,
    "co.me" => 0,
    "net.me" => 0,
    "org.me" => 0,
    "edu.me" => 0,
    "ac.me" => 0,
    "gov.me" => 0,
    "its.me" => 0,
    "priv.me" => 0,
    "mg" => 0,
    "org.mg" => 0,
    "nom.mg" => 0,
    "gov.mg" => 0,
    "prd.mg" => 0,
    "tm.mg" => 0,
    "edu.mg" => 0,
    "mil.mg" => 0,
    "com.mg" => 0,
    "mh" => 0,
    "mil" => 0,
    "mk" => 0,
    "com.mk" => 0,
    "org.mk" => 0,
    "net.mk" => 0,
    "edu.mk" => 0,
    "gov.mk" => 0,
    "inf.mk" => 0,
    "name.mk" => 0,
    "ml" => 0,
    "com.ml" => 0,
    "edu.ml" => 0,
    "gouv.ml" => 0,
    "gov.ml" => 0,
    "net.ml" => 0,
    "org.ml" => 0,
    "presse.ml" => 0,
    "mm" => -1,
    "mn" => 0,
    "gov.mn" => 0,
    "edu.mn" => 0,
    "org.mn" => 0,
    "mo" => 0,
    "com.mo" => 0,
    "net.mo" => 0,
    "org.mo" => 0,
    "edu.mo" => 0,
    "gov.mo" => 0,
    "mobi" => 0,
    "mp" => 0,
    "mq" => 0,
    "mr" => 0,
    "gov.mr" => 0,
    "ms" => 0,
    "mt" => -1,
    "mu" => 0,
    "com.mu" => 0,
    "net.mu" => 0,
    "org.mu" => 0,
    "gov.mu" => 0,
    "ac.mu" => 0,
    "co.mu" => 0,
    "or.mu" => 0,
    "museum" => 0,
    "academy.museum" => 0,
    "agriculture.museum" => 0,
    "air.museum" => 0,
    "airguard.museum" => 0,
    "alabama.museum" => 0,
    "alaska.museum" => 0,
    "amber.museum" => 0,
    "ambulance.museum" => 0,
    "american.museum" => 0,
    "americana.museum" => 0,
    "americanantiques.museum" => 0,
    "americanart.museum" => 0,
    "amsterdam.museum" => 0,
    "and.museum" => 0,
    "annefrank.museum" => 0,
    "anthro.museum" => 0,
    "anthropology.museum" => 0,
    "antiques.museum" => 0,
    "aquarium.museum" => 0,
    "arboretum.museum" => 0,
    "archaeological.museum" => 0,
    "archaeology.museum" => 0,
    "architecture.museum" => 0,
    "art.museum" => 0,
    "artanddesign.museum" => 0,
    "artcenter.museum" => 0,
    "artdeco.museum" => 0,
    "arteducation.museum" => 0,
    "artgallery.museum" => 0,
    "arts.museum" => 0,
    "artsandcrafts.museum" => 0,
    "asmatart.museum" => 0,
    "assassination.museum" => 0,
    "assisi.museum" => 0,
    "association.museum" => 0,
    "astronomy.museum" => 0,
    "atlanta.museum" => 0,
    "austin.museum" => 0,
    "australia.museum" => 0,
    "automotive.museum" => 0,
    "aviation.museum" => 0,
    "axis.museum" => 0,
    "badajoz.museum" => 0,
    "baghdad.museum" => 0,
    "bahn.museum" => 0,
    "bale.museum" => 0,
    "baltimore.museum" => 0,
    "barcelona.museum" => 0,
    "baseball.museum" => 0,
    "basel.museum" => 0,
    "baths.museum" => 0,
    "bauern.museum" => 0,
    "beauxarts.museum" => 0,
    "beeldengeluid.museum" => 0,
    "bellevue.museum" => 0,
    "bergbau.museum" => 0,
    "berkeley.museum" => 0,
    "berlin.museum" => 0,
    "bern.museum" => 0,
    "bible.museum" => 0,
    "bilbao.museum" => 0,
    "bill.museum" => 0,
    "birdart.museum" => 0,
    "birthplace.museum" => 0,
    "bonn.museum" => 0,
    "boston.museum" => 0,
    "botanical.museum" => 0,
    "botanicalgarden.museum" => 0,
    "botanicgarden.museum" => 0,
    "botany.museum" => 0,
    "brandywinevalley.museum" => 0,
    "brasil.museum" => 0,
    "bristol.museum" => 0,
    "british.museum" => 0,
    "britishcolumbia.museum" => 0,
    "broadcast.museum" => 0,
    "brunel.museum" => 0,
    "brussel.museum" => 0,
    "brussels.museum" => 0,
    "bruxelles.museum" => 0,
    "building.museum" => 0,
    "burghof.museum" => 0,
    "bus.museum" => 0,
    "bushey.museum" => 0,
    "cadaques.museum" => 0,
    "california.museum" => 0,
    "cambridge.museum" => 0,
    "can.museum" => 0,
    "canada.museum" => 0,
    "capebreton.museum" => 0,
    "carrier.museum" => 0,
    "cartoonart.museum" => 0,
    "casadelamoneda.museum" => 0,
    "castle.museum" => 0,
    "castres.museum" => 0,
    "celtic.museum" => 0,
    "center.museum" => 0,
    "chattanooga.museum" => 0,
    "cheltenham.museum" => 0,
    "chesapeakebay.museum" => 0,
    "chicago.museum" => 0,
    "children.museum" => 0,
    "childrens.museum" => 0,
    "childrensgarden.museum" => 0,
    "chiropractic.museum" => 0,
    "chocolate.museum" => 0,
    "christiansburg.museum" => 0,
    "cincinnati.museum" => 0,
    "cinema.museum" => 0,
    "circus.museum" => 0,
    "civilisation.museum" => 0,
    "civilization.museum" => 0,
    "civilwar.museum" => 0,
    "clinton.museum" => 0,
    "clock.museum" => 0,
    "coal.museum" => 0,
    "coastaldefence.museum" => 0,
    "cody.museum" => 0,
    "coldwar.museum" => 0,
    "collection.museum" => 0,
    "colonialwilliamsburg.museum" => 0,
    "coloradoplateau.museum" => 0,
    "columbia.museum" => 0,
    "columbus.museum" => 0,
    "communication.museum" => 0,
    "communications.museum" => 0,
    "community.museum" => 0,
    "computer.museum" => 0,
    "computerhistory.museum" => 0,
    "xn--comunicaes-v6a2o.museum" => 0,
    "contemporary.museum" => 0,
    "contemporaryart.museum" => 0,
    "convent.museum" => 0,
    "copenhagen.museum" => 0,
    "corporation.museum" => 0,
    "xn--correios-e-telecomunicaes-ghc29a.museum" => 0,
    "corvette.museum" => 0,
    "costume.museum" => 0,
    "countryestate.museum" => 0,
    "county.museum" => 0,
    "crafts.museum" => 0,
    "cranbrook.museum" => 0,
    "creation.museum" => 0,
    "cultural.museum" => 0,
    "culturalcenter.museum" => 0,
    "culture.museum" => 0,
    "cyber.museum" => 0,
    "cymru.museum" => 0,
    "dali.museum" => 0,
    "dallas.museum" => 0,
    "database.museum" => 0,
    "ddr.museum" => 0,
    "decorativearts.museum" => 0,
    "delaware.museum" => 0,
    "delmenhorst.museum" => 0,
    "denmark.museum" => 0,
    "depot.museum" => 0,
    "design.museum" => 0,
    "detroit.museum" => 0,
    "dinosaur.museum" => 0,
    "discovery.museum" => 0,
    "dolls.museum" => 0,
    "donostia.museum" => 0,
    "durham.museum" => 0,
    "eastafrica.museum" => 0,
    "eastcoast.museum" => 0,
    "education.museum" => 0,
    "educational.museum" => 0,
    "egyptian.museum" => 0,
    "eisenbahn.museum" => 0,
    "elburg.museum" => 0,
    "elvendrell.museum" => 0,
    "embroidery.museum" => 0,
    "encyclopedic.museum" => 0,
    "england.museum" => 0,
    "entomology.museum" => 0,
    "environment.museum" => 0,
    "environmentalconservation.museum" => 0,
    "epilepsy.museum" => 0,
    "essex.museum" => 0,
    "estate.museum" => 0,
    "ethnology.museum" => 0,
    "exeter.museum" => 0,
    "exhibition.museum" => 0,
    "family.museum" => 0,
    "farm.museum" => 0,
    "farmequipment.museum" => 0,
    "farmers.museum" => 0,
    "farmstead.museum" => 0,
    "field.museum" => 0,
    "figueres.museum" => 0,
    "filatelia.museum" => 0,
    "film.museum" => 0,
    "fineart.museum" => 0,
    "finearts.museum" => 0,
    "finland.museum" => 0,
    "flanders.museum" => 0,
    "florida.museum" => 0,
    "force.museum" => 0,
    "fortmissoula.museum" => 0,
    "fortworth.museum" => 0,
    "foundation.museum" => 0,
    "francaise.museum" => 0,
    "frankfurt.museum" => 0,
    "franziskaner.museum" => 0,
    "freemasonry.museum" => 0,
    "freiburg.museum" => 0,
    "fribourg.museum" => 0,
    "frog.museum" => 0,
    "fundacio.museum" => 0,
    "furniture.museum" => 0,
    "gallery.museum" => 0,
    "garden.museum" => 0,
    "gateway.museum" => 0,
    "geelvinck.museum" => 0,
    "gemological.museum" => 0,
    "geology.museum" => 0,
    "georgia.museum" => 0,
    "giessen.museum" => 0,
    "glas.museum" => 0,
    "glass.museum" => 0,
    "gorge.museum" => 0,
    "grandrapids.museum" => 0,
    "graz.museum" => 0,
    "guernsey.museum" => 0,
    "halloffame.museum" => 0,
    "hamburg.museum" => 0,
    "handson.museum" => 0,
    "harvestcelebration.museum" => 0,
    "hawaii.museum" => 0,
    "health.museum" => 0,
    "heimatunduhren.museum" => 0,
    "hellas.museum" => 0,
    "helsinki.museum" => 0,
    "hembygdsforbund.museum" => 0,
    "heritage.museum" => 0,
    "histoire.museum" => 0,
    "historical.museum" => 0,
    "historicalsociety.museum" => 0,
    "historichouses.museum" => 0,
    "historisch.museum" => 0,
    "historisches.museum" => 0,
    "history.museum" => 0,
    "historyofscience.museum" => 0,
    "horology.museum" => 0,
    "house.museum" => 0,
    "humanities.museum" => 0,
    "illustration.museum" => 0,
    "imageandsound.museum" => 0,
    "indian.museum" => 0,
    "indiana.museum" => 0,
    "indianapolis.museum" => 0,
    "indianmarket.museum" => 0,
    "intelligence.museum" => 0,
    "interactive.museum" => 0,
    "iraq.museum" => 0,
    "iron.museum" => 0,
    "isleofman.museum" => 0,
    "jamison.museum" => 0,
    "jefferson.museum" => 0,
    "jerusalem.museum" => 0,
    "jewelry.museum" => 0,
    "jewish.museum" => 0,
    "jewishart.museum" => 0,
    "jfk.museum" => 0,
    "journalism.museum" => 0,
    "judaica.museum" => 0,
    "judygarland.museum" => 0,
    "juedisches.museum" => 0,
    "juif.museum" => 0,
    "karate.museum" => 0,
    "karikatur.museum" => 0,
    "kids.museum" => 0,
    "koebenhavn.museum" => 0,
    "koeln.museum" => 0,
    "kunst.museum" => 0,
    "kunstsammlung.museum" => 0,
    "kunstunddesign.museum" => 0,
    "labor.museum" => 0,
    "labour.museum" => 0,
    "lajolla.museum" => 0,
    "lancashire.museum" => 0,
    "landes.museum" => 0,
    "lans.museum" => 0,
    "xn--lns-qla.museum" => 0,
    "larsson.museum" => 0,
    "lewismiller.museum" => 0,
    "lincoln.museum" => 0,
    "linz.museum" => 0,
    "living.museum" => 0,
    "livinghistory.museum" => 0,
    "localhistory.museum" => 0,
    "london.museum" => 0,
    "losangeles.museum" => 0,
    "louvre.museum" => 0,
    "loyalist.museum" => 0,
    "lucerne.museum" => 0,
    "luxembourg.museum" => 0,
    "luzern.museum" => 0,
    "mad.museum" => 0,
    "madrid.museum" => 0,
    "mallorca.museum" => 0,
    "manchester.museum" => 0,
    "mansion.museum" => 0,
    "mansions.museum" => 0,
    "manx.museum" => 0,
    "marburg.museum" => 0,
    "maritime.museum" => 0,
    "maritimo.museum" => 0,
    "maryland.museum" => 0,
    "marylhurst.museum" => 0,
    "media.museum" => 0,
    "medical.museum" => 0,
    "medizinhistorisches.museum" => 0,
    "meeres.museum" => 0,
    "memorial.museum" => 0,
    "mesaverde.museum" => 0,
    "michigan.museum" => 0,
    "midatlantic.museum" => 0,
    "military.museum" => 0,
    "mill.museum" => 0,
    "miners.museum" => 0,
    "mining.museum" => 0,
    "minnesota.museum" => 0,
    "missile.museum" => 0,
    "missoula.museum" => 0,
    "modern.museum" => 0,
    "moma.museum" => 0,
    "money.museum" => 0,
    "monmouth.museum" => 0,
    "monticello.museum" => 0,
    "montreal.museum" => 0,
    "moscow.museum" => 0,
    "motorcycle.museum" => 0,
    "muenchen.museum" => 0,
    "muenster.museum" => 0,
    "mulhouse.museum" => 0,
    "muncie.museum" => 0,
    "museet.museum" => 0,
    "museumcenter.museum" => 0,
    "museumvereniging.museum" => 0,
    "music.museum" => 0,
    "national.museum" => 0,
    "nationalfirearms.museum" => 0,
    "nationalheritage.museum" => 0,
    "nativeamerican.museum" => 0,
    "naturalhistory.museum" => 0,
    "naturalhistorymuseum.museum" => 0,
    "naturalsciences.museum" => 0,
    "nature.museum" => 0,
    "naturhistorisches.museum" => 0,
    "natuurwetenschappen.museum" => 0,
    "naumburg.museum" => 0,
    "naval.museum" => 0,
    "nebraska.museum" => 0,
    "neues.museum" => 0,
    "newhampshire.museum" => 0,
    "newjersey.museum" => 0,
    "newmexico.museum" => 0,
    "newport.museum" => 0,
    "newspaper.museum" => 0,
    "newyork.museum" => 0,
    "niepce.museum" => 0,
    "norfolk.museum" => 0,
    "north.museum" => 0,
    "nrw.museum" => 0,
    "nuernberg.museum" => 0,
    "nuremberg.museum" => 0,
    "nyc.museum" => 0,
    "nyny.museum" => 0,
    "oceanographic.museum" => 0,
    "oceanographique.museum" => 0,
    "omaha.museum" => 0,
    "online.museum" => 0,
    "ontario.museum" => 0,
    "openair.museum" => 0,
    "oregon.museum" => 0,
    "oregontrail.museum" => 0,
    "otago.museum" => 0,
    "oxford.museum" => 0,
    "pacific.museum" => 0,
    "paderborn.museum" => 0,
    "palace.museum" => 0,
    "paleo.museum" => 0,
    "palmsprings.museum" => 0,
    "panama.museum" => 0,
    "paris.museum" => 0,
    "pasadena.museum" => 0,
    "pharmacy.museum" => 0,
    "philadelphia.museum" => 0,
    "philadelphiaarea.museum" => 0,
    "philately.museum" => 0,
    "phoenix.museum" => 0,
    "photography.museum" => 0,
    "pilots.museum" => 0,
    "pittsburgh.museum" => 0,
    "planetarium.museum" => 0,
    "plantation.museum" => 0,
    "plants.museum" => 0,
    "plaza.museum" => 0,
    "portal.museum" => 0,
    "portland.museum" => 0,
    "portlligat.museum" => 0,
    "posts-and-telecommunications.museum" => 0,
    "preservation.museum" => 0,
    "presidio.museum" => 0,
    "press.museum" => 0,
    "project.museum" => 0,
    "public.museum" => 0,
    "pubol.museum" => 0,
    "quebec.museum" => 0,
    "railroad.museum" => 0,
    "railway.museum" => 0,
    "research.museum" => 0,
    "resistance.museum" => 0,
    "riodejaneiro.museum" => 0,
    "rochester.museum" => 0,
    "rockart.museum" => 0,
    "roma.museum" => 0,
    "russia.museum" => 0,
    "saintlouis.museum" => 0,
    "salem.museum" => 0,
    "salvadordali.museum" => 0,
    "salzburg.museum" => 0,
    "sandiego.museum" => 0,
    "sanfrancisco.museum" => 0,
    "santabarbara.museum" => 0,
    "santacruz.museum" => 0,
    "santafe.museum" => 0,
    "saskatchewan.museum" => 0,
    "satx.museum" => 0,
    "savannahga.museum" => 0,
    "schlesisches.museum" => 0,
    "schoenbrunn.museum" => 0,
    "schokoladen.museum" => 0,
    "school.museum" => 0,
    "schweiz.museum" => 0,
    "science.museum" => 0,
    "scienceandhistory.museum" => 0,
    "scienceandindustry.museum" => 0,
    "sciencecenter.museum" => 0,
    "sciencecenters.museum" => 0,
    "science-fiction.museum" => 0,
    "sciencehistory.museum" => 0,
    "sciences.museum" => 0,
    "sciencesnaturelles.museum" => 0,
    "scotland.museum" => 0,
    "seaport.museum" => 0,
    "settlement.museum" => 0,
    "settlers.museum" => 0,
    "shell.museum" => 0,
    "sherbrooke.museum" => 0,
    "sibenik.museum" => 0,
    "silk.museum" => 0,
    "ski.museum" => 0,
    "skole.museum" => 0,
    "society.museum" => 0,
    "sologne.museum" => 0,
    "soundandvision.museum" => 0,
    "southcarolina.museum" => 0,
    "southwest.museum" => 0,
    "space.museum" => 0,
    "spy.museum" => 0,
    "square.museum" => 0,
    "stadt.museum" => 0,
    "stalbans.museum" => 0,
    "starnberg.museum" => 0,
    "state.museum" => 0,
    "stateofdelaware.museum" => 0,
    "station.museum" => 0,
    "steam.museum" => 0,
    "steiermark.museum" => 0,
    "stjohn.museum" => 0,
    "stockholm.museum" => 0,
    "stpetersburg.museum" => 0,
    "stuttgart.museum" => 0,
    "suisse.museum" => 0,
    "surgeonshall.museum" => 0,
    "surrey.museum" => 0,
    "svizzera.museum" => 0,
    "sweden.museum" => 0,
    "sydney.museum" => 0,
    "tank.museum" => 0,
    "tcm.museum" => 0,
    "technology.museum" => 0,
    "telekommunikation.museum" => 0,
    "television.museum" => 0,
    "texas.museum" => 0,
    "textile.museum" => 0,
    "theater.museum" => 0,
    "time.museum" => 0,
    "timekeeping.museum" => 0,
    "topology.museum" => 0,
    "torino.museum" => 0,
    "touch.museum" => 0,
    "town.museum" => 0,
    "transport.museum" => 0,
    "tree.museum" => 0,
    "trolley.museum" => 0,
    "trust.museum" => 0,
    "trustee.museum" => 0,
    "uhren.museum" => 0,
    "ulm.museum" => 0,
    "undersea.museum" => 0,
    "university.museum" => 0,
    "usa.museum" => 0,
    "usantiques.museum" => 0,
    "usarts.museum" => 0,
    "uscountryestate.museum" => 0,
    "usculture.museum" => 0,
    "usdecorativearts.museum" => 0,
    "usgarden.museum" => 0,
    "ushistory.museum" => 0,
    "ushuaia.museum" => 0,
    "uslivinghistory.museum" => 0,
    "utah.museum" => 0,
    "uvic.museum" => 0,
    "valley.museum" => 0,
    "vantaa.museum" => 0,
    "versailles.museum" => 0,
    "viking.museum" => 0,
    "village.museum" => 0,
    "virginia.museum" => 0,
    "virtual.museum" => 0,
    "virtuel.museum" => 0,
    "vlaanderen.museum" => 0,
    "volkenkunde.museum" => 0,
    "wales.museum" => 0,
    "wallonie.museum" => 0,
    "war.museum" => 0,
    "washingtondc.museum" => 0,
    "watchandclock.museum" => 0,
    "watch-and-clock.museum" => 0,
    "western.museum" => 0,
    "westfalen.museum" => 0,
    "whaling.museum" => 0,
    "wildlife.museum" => 0,
    "williamsburg.museum" => 0,
    "windmill.museum" => 0,
    "workshop.museum" => 0,
    "york.museum" => 0,
    "yorkshire.museum" => 0,
    "yosemite.museum" => 0,
    "youth.museum" => 0,
    "zoological.museum" => 0,
    "zoology.museum" => 0,
    "xn--9dbhblg6di.museum" => 0,
    "xn--h1aegh.museum" => 0,
    "mv" => 0,
    "aero.mv" => 0,
    "biz.mv" => 0,
    "com.mv" => 0,
    "coop.mv" => 0,
    "edu.mv" => 0,
    "gov.mv" => 0,
    "info.mv" => 0,
    "int.mv" => 0,
    "mil.mv" => 0,
    "museum.mv" => 0,
    "name.mv" => 0,
    "net.mv" => 0,
    "org.mv" => 0,
    "pro.mv" => 0,
    "mw" => 0,
    "ac.mw" => 0,
    "biz.mw" => 0,
    "co.mw" => 0,
    "com.mw" => 0,
    "coop.mw" => 0,
    "edu.mw" => 0,
    "gov.mw" => 0,
    "int.mw" => 0,
    "museum.mw" => 0,
    "net.mw" => 0,
    "org.mw" => 0,
    "mx" => 0,
    "com.mx" => 0,
    "org.mx" => 0,
    "gob.mx" => 0,
    "edu.mx" => 0,
    "net.mx" => 0,
    "my" => 0,
    "com.my" => 0,
    "net.my" => 0,
    "org.my" => 0,
    "gov.my" => 0,
    "edu.my" => 0,
    "mil.my" => 0,
    "name.my" => 0,
    "mz" => -1,
    "teledata.mz" => 1,
    "na" => 0,
    "info.na" => 0,
    "pro.na" => 0,
    "name.na" => 0,
    "school.na" => 0,
    "or.na" => 0,
    "dr.na" => 0,
    "us.na" => 0,
    "mx.na" => 0,
    "ca.na" => 0,
    "in.na" => 0,
    "cc.na" => 0,
    "tv.na" => 0,
    "ws.na" => 0,
    "mobi.na" => 0,
    "co.na" => 0,
    "com.na" => 0,
    "org.na" => 0,
    "name" => 0,
    "nc" => 0,
    "asso.nc" => 0,
    "ne" => 0,
    "net" => 0,
    "nf" => 0,
    "com.nf" => 0,
    "net.nf" => 0,
    "per.nf" => 0,
    "rec.nf" => 0,
    "web.nf" => 0,
    "arts.nf" => 0,
    "firm.nf" => 0,
    "info.nf" => 0,
    "other.nf" => 0,
    "store.nf" => 0,
    "ng" => 1,
    "ac.ng" => 0,
    "com.ng" => 0,
    "edu.ng" => 0,
    "gov.ng" => 0,
    "net.ng" => 0,
    "org.ng" => 0,
    "ni" => -1,
    "nl" => 0,
    "bv.nl" => 0,
    "no" => 0,
    "fhs.no" => 0,
    "vgs.no" => 0,
    "fylkesbibl.no" => 0,
    "folkebibl.no" => 0,
    "museum.no" => 0,
    "idrett.no" => 0,
    "priv.no" => 0,
    "mil.no" => 0,
    "stat.no" => 0,
    "dep.no" => 0,
    "kommune.no" => 0,
    "herad.no" => 0,
    "aa.no" => 0,
    "ah.no" => 0,
    "bu.no" => 0,
    "fm.no" => 0,
    "hl.no" => 0,
    "hm.no" => 0,
    "jan-mayen.no" => 0,
    "mr.no" => 0,
    "nl.no" => 0,
    "nt.no" => 0,
    "of.no" => 0,
    "ol.no" => 0,
    "oslo.no" => 0,
    "rl.no" => 0,
    "sf.no" => 0,
    "st.no" => 0,
    "svalbard.no" => 0,
    "tm.no" => 0,
    "tr.no" => 0,
    "va.no" => 0,
    "vf.no" => 0,
    "gs.aa.no" => 0,
    "gs.ah.no" => 0,
    "gs.bu.no" => 0,
    "gs.fm.no" => 0,
    "gs.hl.no" => 0,
    "gs.hm.no" => 0,
    "gs.jan-mayen.no" => 0,
    "gs.mr.no" => 0,
    "gs.nl.no" => 0,
    "gs.nt.no" => 0,
    "gs.of.no" => 0,
    "gs.ol.no" => 0,
    "gs.oslo.no" => 0,
    "gs.rl.no" => 0,
    "gs.sf.no" => 0,
    "gs.st.no" => 0,
    "gs.svalbard.no" => 0,
    "gs.tm.no" => 0,
    "gs.tr.no" => 0,
    "gs.va.no" => 0,
    "gs.vf.no" => 0,
    "akrehamn.no" => 0,
    "xn--krehamn-dxa.no" => 0,
    "algard.no" => 0,
    "xn--lgrd-poac.no" => 0,
    "arna.no" => 0,
    "brumunddal.no" => 0,
    "bryne.no" => 0,
    "bronnoysund.no" => 0,
    "xn--brnnysund-m8ac.no" => 0,
    "drobak.no" => 0,
    "xn--drbak-wua.no" => 0,
    "egersund.no" => 0,
    "fetsund.no" => 0,
    "floro.no" => 0,
    "xn--flor-jra.no" => 0,
    "fredrikstad.no" => 0,
    "hokksund.no" => 0,
    "honefoss.no" => 0,
    "xn--hnefoss-q1a.no" => 0,
    "jessheim.no" => 0,
    "jorpeland.no" => 0,
    "xn--jrpeland-54a.no" => 0,
    "kirkenes.no" => 0,
    "kopervik.no" => 0,
    "krokstadelva.no" => 0,
    "langevag.no" => 0,
    "xn--langevg-jxa.no" => 0,
    "leirvik.no" => 0,
    "mjondalen.no" => 0,
    "xn--mjndalen-64a.no" => 0,
    "mo-i-rana.no" => 0,
    "mosjoen.no" => 0,
    "xn--mosjen-eya.no" => 0,
    "nesoddtangen.no" => 0,
    "orkanger.no" => 0,
    "osoyro.no" => 0,
    "xn--osyro-wua.no" => 0,
    "raholt.no" => 0,
    "xn--rholt-mra.no" => 0,
    "sandnessjoen.no" => 0,
    "xn--sandnessjen-ogb.no" => 0,
    "skedsmokorset.no" => 0,
    "slattum.no" => 0,
    "spjelkavik.no" => 0,
    "stathelle.no" => 0,
    "stavern.no" => 0,
    "stjordalshalsen.no" => 0,
    "xn--stjrdalshalsen-sqb.no" => 0,
    "tananger.no" => 0,
    "tranby.no" => 0,
    "vossevangen.no" => 0,
    "afjord.no" => 0,
    "xn--fjord-lra.no" => 0,
    "agdenes.no" => 0,
    "al.no" => 0,
    "xn--l-1fa.no" => 0,
    "alesund.no" => 0,
    "xn--lesund-hua.no" => 0,
    "alstahaug.no" => 0,
    "alta.no" => 0,
    "xn--lt-liac.no" => 0,
    "alaheadju.no" => 0,
    "xn--laheadju-7ya.no" => 0,
    "alvdal.no" => 0,
    "amli.no" => 0,
    "xn--mli-tla.no" => 0,
    "amot.no" => 0,
    "xn--mot-tla.no" => 0,
    "andebu.no" => 0,
    "andoy.no" => 0,
    "xn--andy-ira.no" => 0,
    "andasuolo.no" => 0,
    "ardal.no" => 0,
    "xn--rdal-poa.no" => 0,
    "aremark.no" => 0,
    "arendal.no" => 0,
    "xn--s-1fa.no" => 0,
    "aseral.no" => 0,
    "xn--seral-lra.no" => 0,
    "asker.no" => 0,
    "askim.no" => 0,
    "askvoll.no" => 0,
    "askoy.no" => 0,
    "xn--asky-ira.no" => 0,
    "asnes.no" => 0,
    "xn--snes-poa.no" => 0,
    "audnedaln.no" => 0,
    "aukra.no" => 0,
    "aure.no" => 0,
    "aurland.no" => 0,
    "aurskog-holand.no" => 0,
    "xn--aurskog-hland-jnb.no" => 0,
    "austevoll.no" => 0,
    "austrheim.no" => 0,
    "averoy.no" => 0,
    "xn--avery-yua.no" => 0,
    "balestrand.no" => 0,
    "ballangen.no" => 0,
    "balat.no" => 0,
    "xn--blt-elab.no" => 0,
    "balsfjord.no" => 0,
    "bahccavuotna.no" => 0,
    "xn--bhccavuotna-k7a.no" => 0,
    "bamble.no" => 0,
    "bardu.no" => 0,
    "beardu.no" => 0,
    "beiarn.no" => 0,
    "bajddar.no" => 0,
    "xn--bjddar-pta.no" => 0,
    "baidar.no" => 0,
    "xn--bidr-5nac.no" => 0,
    "berg.no" => 0,
    "bergen.no" => 0,
    "berlevag.no" => 0,
    "xn--berlevg-jxa.no" => 0,
    "bearalvahki.no" => 0,
    "xn--bearalvhki-y4a.no" => 0,
    "bindal.no" => 0,
    "birkenes.no" => 0,
    "bjarkoy.no" => 0,
    "xn--bjarky-fya.no" => 0,
    "bjerkreim.no" => 0,
    "bjugn.no" => 0,
    "bodo.no" => 0,
    "xn--bod-2na.no" => 0,
    "badaddja.no" => 0,
    "xn--bdddj-mrabd.no" => 0,
    "budejju.no" => 0,
    "bokn.no" => 0,
    "bremanger.no" => 0,
    "bronnoy.no" => 0,
    "xn--brnny-wuac.no" => 0,
    "bygland.no" => 0,
    "bykle.no" => 0,
    "barum.no" => 0,
    "xn--brum-voa.no" => 0,
    "bo.telemark.no" => 0,
    "xn--b-5ga.telemark.no" => 0,
    "bo.nordland.no" => 0,
    "xn--b-5ga.nordland.no" => 0,
    "bievat.no" => 0,
    "xn--bievt-0qa.no" => 0,
    "bomlo.no" => 0,
    "xn--bmlo-gra.no" => 0,
    "batsfjord.no" => 0,
    "xn--btsfjord-9za.no" => 0,
    "bahcavuotna.no" => 0,
    "xn--bhcavuotna-s4a.no" => 0,
    "dovre.no" => 0,
    "drammen.no" => 0,
    "drangedal.no" => 0,
    "dyroy.no" => 0,
    "xn--dyry-ira.no" => 0,
    "donna.no" => 0,
    "xn--dnna-gra.no" => 0,
    "eid.no" => 0,
    "eidfjord.no" => 0,
    "eidsberg.no" => 0,
    "eidskog.no" => 0,
    "eidsvoll.no" => 0,
    "eigersund.no" => 0,
    "elverum.no" => 0,
    "enebakk.no" => 0,
    "engerdal.no" => 0,
    "etne.no" => 0,
    "etnedal.no" => 0,
    "evenes.no" => 0,
    "evenassi.no" => 0,
    "xn--eveni-0qa01ga.no" => 0,
    "evje-og-hornnes.no" => 0,
    "farsund.no" => 0,
    "fauske.no" => 0,
    "fuossko.no" => 0,
    "fuoisku.no" => 0,
    "fedje.no" => 0,
    "fet.no" => 0,
    "finnoy.no" => 0,
    "xn--finny-yua.no" => 0,
    "fitjar.no" => 0,
    "fjaler.no" => 0,
    "fjell.no" => 0,
    "flakstad.no" => 0,
    "flatanger.no" => 0,
    "flekkefjord.no" => 0,
    "flesberg.no" => 0,
    "flora.no" => 0,
    "fla.no" => 0,
    "xn--fl-zia.no" => 0,
    "folldal.no" => 0,
    "forsand.no" => 0,
    "fosnes.no" => 0,
    "frei.no" => 0,
    "frogn.no" => 0,
    "froland.no" => 0,
    "frosta.no" => 0,
    "frana.no" => 0,
    "xn--frna-woa.no" => 0,
    "froya.no" => 0,
    "xn--frya-hra.no" => 0,
    "fusa.no" => 0,
    "fyresdal.no" => 0,
    "forde.no" => 0,
    "xn--frde-gra.no" => 0,
    "gamvik.no" => 0,
    "gangaviika.no" => 0,
    "xn--ggaviika-8ya47h.no" => 0,
    "gaular.no" => 0,
    "gausdal.no" => 0,
    "gildeskal.no" => 0,
    "xn--gildeskl-g0a.no" => 0,
    "giske.no" => 0,
    "gjemnes.no" => 0,
    "gjerdrum.no" => 0,
    "gjerstad.no" => 0,
    "gjesdal.no" => 0,
    "gjovik.no" => 0,
    "xn--gjvik-wua.no" => 0,
    "gloppen.no" => 0,
    "gol.no" => 0,
    "gran.no" => 0,
    "grane.no" => 0,
    "granvin.no" => 0,
    "gratangen.no" => 0,
    "grimstad.no" => 0,
    "grong.no" => 0,
    "kraanghke.no" => 0,
    "xn--kranghke-b0a.no" => 0,
    "grue.no" => 0,
    "gulen.no" => 0,
    "hadsel.no" => 0,
    "halden.no" => 0,
    "halsa.no" => 0,
    "hamar.no" => 0,
    "hamaroy.no" => 0,
    "habmer.no" => 0,
    "xn--hbmer-xqa.no" => 0,
    "hapmir.no" => 0,
    "xn--hpmir-xqa.no" => 0,
    "hammerfest.no" => 0,
    "hammarfeasta.no" => 0,
    "xn--hmmrfeasta-s4ac.no" => 0,
    "haram.no" => 0,
    "hareid.no" => 0,
    "harstad.no" => 0,
    "hasvik.no" => 0,
    "aknoluokta.no" => 0,
    "xn--koluokta-7ya57h.no" => 0,
    "hattfjelldal.no" => 0,
    "aarborte.no" => 0,
    "haugesund.no" => 0,
    "hemne.no" => 0,
    "hemnes.no" => 0,
    "hemsedal.no" => 0,
    "heroy.more-og-romsdal.no" => 0,
    "xn--hery-ira.xn--mre-og-romsdal-qqb.no" => 0,
    "heroy.nordland.no" => 0,
    "xn--hery-ira.nordland.no" => 0,
    "hitra.no" => 0,
    "hjartdal.no" => 0,
    "hjelmeland.no" => 0,
    "hobol.no" => 0,
    "xn--hobl-ira.no" => 0,
    "hof.no" => 0,
    "hol.no" => 0,
    "hole.no" => 0,
    "holmestrand.no" => 0,
    "holtalen.no" => 0,
    "xn--holtlen-hxa.no" => 0,
    "hornindal.no" => 0,
    "horten.no" => 0,
    "hurdal.no" => 0,
    "hurum.no" => 0,
    "hvaler.no" => 0,
    "hyllestad.no" => 0,
    "hagebostad.no" => 0,
    "xn--hgebostad-g3a.no" => 0,
    "hoyanger.no" => 0,
    "xn--hyanger-q1a.no" => 0,
    "hoylandet.no" => 0,
    "xn--hylandet-54a.no" => 0,
    "ha.no" => 0,
    "xn--h-2fa.no" => 0,
    "ibestad.no" => 0,
    "inderoy.no" => 0,
    "xn--indery-fya.no" => 0,
    "iveland.no" => 0,
    "jevnaker.no" => 0,
    "jondal.no" => 0,
    "jolster.no" => 0,
    "xn--jlster-bya.no" => 0,
    "karasjok.no" => 0,
    "karasjohka.no" => 0,
    "xn--krjohka-hwab49j.no" => 0,
    "karlsoy.no" => 0,
    "galsa.no" => 0,
    "xn--gls-elac.no" => 0,
    "karmoy.no" => 0,
    "xn--karmy-yua.no" => 0,
    "kautokeino.no" => 0,
    "guovdageaidnu.no" => 0,
    "klepp.no" => 0,
    "klabu.no" => 0,
    "xn--klbu-woa.no" => 0,
    "kongsberg.no" => 0,
    "kongsvinger.no" => 0,
    "kragero.no" => 0,
    "xn--krager-gya.no" => 0,
    "kristiansand.no" => 0,
    "kristiansund.no" => 0,
    "krodsherad.no" => 0,
    "xn--krdsherad-m8a.no" => 0,
    "kvalsund.no" => 0,
    "rahkkeravju.no" => 0,
    "xn--rhkkervju-01af.no" => 0,
    "kvam.no" => 0,
    "kvinesdal.no" => 0,
    "kvinnherad.no" => 0,
    "kviteseid.no" => 0,
    "kvitsoy.no" => 0,
    "xn--kvitsy-fya.no" => 0,
    "kvafjord.no" => 0,
    "xn--kvfjord-nxa.no" => 0,
    "giehtavuoatna.no" => 0,
    "kvanangen.no" => 0,
    "xn--kvnangen-k0a.no" => 0,
    "navuotna.no" => 0,
    "xn--nvuotna-hwa.no" => 0,
    "kafjord.no" => 0,
    "xn--kfjord-iua.no" => 0,
    "gaivuotna.no" => 0,
    "xn--givuotna-8ya.no" => 0,
    "larvik.no" => 0,
    "lavangen.no" => 0,
    "lavagis.no" => 0,
    "loabat.no" => 0,
    "xn--loabt-0qa.no" => 0,
    "lebesby.no" => 0,
    "davvesiida.no" => 0,
    "leikanger.no" => 0,
    "leirfjord.no" => 0,
    "leka.no" => 0,
    "leksvik.no" => 0,
    "lenvik.no" => 0,
    "leangaviika.no" => 0,
    "xn--leagaviika-52b.no" => 0,
    "lesja.no" => 0,
    "levanger.no" => 0,
    "lier.no" => 0,
    "lierne.no" => 0,
    "lillehammer.no" => 0,
    "lillesand.no" => 0,
    "lindesnes.no" => 0,
    "lindas.no" => 0,
    "xn--linds-pra.no" => 0,
    "lom.no" => 0,
    "loppa.no" => 0,
    "lahppi.no" => 0,
    "xn--lhppi-xqa.no" => 0,
    "lund.no" => 0,
    "lunner.no" => 0,
    "luroy.no" => 0,
    "xn--lury-ira.no" => 0,
    "luster.no" => 0,
    "lyngdal.no" => 0,
    "lyngen.no" => 0,
    "ivgu.no" => 0,
    "lardal.no" => 0,
    "lerdal.no" => 0,
    "xn--lrdal-sra.no" => 0,
    "lodingen.no" => 0,
    "xn--ldingen-q1a.no" => 0,
    "lorenskog.no" => 0,
    "xn--lrenskog-54a.no" => 0,
    "loten.no" => 0,
    "xn--lten-gra.no" => 0,
    "malvik.no" => 0,
    "masoy.no" => 0,
    "xn--msy-ula0h.no" => 0,
    "muosat.no" => 0,
    "xn--muost-0qa.no" => 0,
    "mandal.no" => 0,
    "marker.no" => 0,
    "marnardal.no" => 0,
    "masfjorden.no" => 0,
    "meland.no" => 0,
    "meldal.no" => 0,
    "melhus.no" => 0,
    "meloy.no" => 0,
    "xn--mely-ira.no" => 0,
    "meraker.no" => 0,
    "xn--merker-kua.no" => 0,
    "moareke.no" => 0,
    "xn--moreke-jua.no" => 0,
    "midsund.no" => 0,
    "midtre-gauldal.no" => 0,
    "modalen.no" => 0,
    "modum.no" => 0,
    "molde.no" => 0,
    "moskenes.no" => 0,
    "moss.no" => 0,
    "mosvik.no" => 0,
    "malselv.no" => 0,
    "xn--mlselv-iua.no" => 0,
    "malatvuopmi.no" => 0,
    "xn--mlatvuopmi-s4a.no" => 0,
    "namdalseid.no" => 0,
    "aejrie.no" => 0,
    "namsos.no" => 0,
    "namsskogan.no" => 0,
    "naamesjevuemie.no" => 0,
    "xn--nmesjevuemie-tcba.no" => 0,
    "laakesvuemie.no" => 0,
    "nannestad.no" => 0,
    "narvik.no" => 0,
    "narviika.no" => 0,
    "naustdal.no" => 0,
    "nedre-eiker.no" => 0,
    "nes.akershus.no" => 0,
    "nes.buskerud.no" => 0,
    "nesna.no" => 0,
    "nesodden.no" => 0,
    "nesseby.no" => 0,
    "unjarga.no" => 0,
    "xn--unjrga-rta.no" => 0,
    "nesset.no" => 0,
    "nissedal.no" => 0,
    "nittedal.no" => 0,
    "nord-aurdal.no" => 0,
    "nord-fron.no" => 0,
    "nord-odal.no" => 0,
    "norddal.no" => 0,
    "nordkapp.no" => 0,
    "davvenjarga.no" => 0,
    "xn--davvenjrga-y4a.no" => 0,
    "nordre-land.no" => 0,
    "nordreisa.no" => 0,
    "raisa.no" => 0,
    "xn--risa-5na.no" => 0,
    "nore-og-uvdal.no" => 0,
    "notodden.no" => 0,
    "naroy.no" => 0,
    "xn--nry-yla5g.no" => 0,
    "notteroy.no" => 0,
    "xn--nttery-byae.no" => 0,
    "odda.no" => 0,
    "oksnes.no" => 0,
    "xn--ksnes-uua.no" => 0,
    "oppdal.no" => 0,
    "oppegard.no" => 0,
    "xn--oppegrd-ixa.no" => 0,
    "orkdal.no" => 0,
    "orland.no" => 0,
    "xn--rland-uua.no" => 0,
    "orskog.no" => 0,
    "xn--rskog-uua.no" => 0,
    "orsta.no" => 0,
    "xn--rsta-fra.no" => 0,
    "os.hedmark.no" => 0,
    "os.hordaland.no" => 0,
    "osen.no" => 0,
    "osteroy.no" => 0,
    "xn--ostery-fya.no" => 0,
    "ostre-toten.no" => 0,
    "xn--stre-toten-zcb.no" => 0,
    "overhalla.no" => 0,
    "ovre-eiker.no" => 0,
    "xn--vre-eiker-k8a.no" => 0,
    "oyer.no" => 0,
    "xn--yer-zna.no" => 0,
    "oygarden.no" => 0,
    "xn--ygarden-p1a.no" => 0,
    "oystre-slidre.no" => 0,
    "xn--ystre-slidre-ujb.no" => 0,
    "porsanger.no" => 0,
    "porsangu.no" => 0,
    "xn--porsgu-sta26f.no" => 0,
    "porsgrunn.no" => 0,
    "radoy.no" => 0,
    "xn--rady-ira.no" => 0,
    "rakkestad.no" => 0,
    "rana.no" => 0,
    "ruovat.no" => 0,
    "randaberg.no" => 0,
    "rauma.no" => 0,
    "rendalen.no" => 0,
    "rennebu.no" => 0,
    "rennesoy.no" => 0,
    "xn--rennesy-v1a.no" => 0,
    "rindal.no" => 0,
    "ringebu.no" => 0,
    "ringerike.no" => 0,
    "ringsaker.no" => 0,
    "rissa.no" => 0,
    "risor.no" => 0,
    "xn--risr-ira.no" => 0,
    "roan.no" => 0,
    "rollag.no" => 0,
    "rygge.no" => 0,
    "ralingen.no" => 0,
    "xn--rlingen-mxa.no" => 0,
    "rodoy.no" => 0,
    "xn--rdy-0nab.no" => 0,
    "romskog.no" => 0,
    "xn--rmskog-bya.no" => 0,
    "roros.no" => 0,
    "xn--rros-gra.no" => 0,
    "rost.no" => 0,
    "xn--rst-0na.no" => 0,
    "royken.no" => 0,
    "xn--ryken-vua.no" => 0,
    "royrvik.no" => 0,
    "xn--ryrvik-bya.no" => 0,
    "rade.no" => 0,
    "xn--rde-ula.no" => 0,
    "salangen.no" => 0,
    "siellak.no" => 0,
    "saltdal.no" => 0,
    "salat.no" => 0,
    "xn--slt-elab.no" => 0,
    "xn--slat-5na.no" => 0,
    "samnanger.no" => 0,
    "sande.more-og-romsdal.no" => 0,
    "sande.xn--mre-og-romsdal-qqb.no" => 0,
    "sande.vestfold.no" => 0,
    "sandefjord.no" => 0,
    "sandnes.no" => 0,
    "sandoy.no" => 0,
    "xn--sandy-yua.no" => 0,
    "sarpsborg.no" => 0,
    "sauda.no" => 0,
    "sauherad.no" => 0,
    "sel.no" => 0,
    "selbu.no" => 0,
    "selje.no" => 0,
    "seljord.no" => 0,
    "sigdal.no" => 0,
    "siljan.no" => 0,
    "sirdal.no" => 0,
    "skaun.no" => 0,
    "skedsmo.no" => 0,
    "ski.no" => 0,
    "skien.no" => 0,
    "skiptvet.no" => 0,
    "skjervoy.no" => 0,
    "xn--skjervy-v1a.no" => 0,
    "skierva.no" => 0,
    "xn--skierv-uta.no" => 0,
    "skjak.no" => 0,
    "xn--skjk-soa.no" => 0,
    "skodje.no" => 0,
    "skanland.no" => 0,
    "xn--sknland-fxa.no" => 0,
    "skanit.no" => 0,
    "xn--sknit-yqa.no" => 0,
    "smola.no" => 0,
    "xn--smla-hra.no" => 0,
    "snillfjord.no" => 0,
    "snasa.no" => 0,
    "xn--snsa-roa.no" => 0,
    "snoasa.no" => 0,
    "snaase.no" => 0,
    "xn--snase-nra.no" => 0,
    "sogndal.no" => 0,
    "sokndal.no" => 0,
    "sola.no" => 0,
    "solund.no" => 0,
    "songdalen.no" => 0,
    "sortland.no" => 0,
    "spydeberg.no" => 0,
    "stange.no" => 0,
    "stavanger.no" => 0,
    "steigen.no" => 0,
    "steinkjer.no" => 0,
    "stjordal.no" => 0,
    "xn--stjrdal-s1a.no" => 0,
    "stokke.no" => 0,
    "stor-elvdal.no" => 0,
    "stord.no" => 0,
    "stordal.no" => 0,
    "storfjord.no" => 0,
    "omasvuotna.no" => 0,
    "strand.no" => 0,
    "stranda.no" => 0,
    "stryn.no" => 0,
    "sula.no" => 0,
    "suldal.no" => 0,
    "sund.no" => 0,
    "sunndal.no" => 0,
    "surnadal.no" => 0,
    "sveio.no" => 0,
    "svelvik.no" => 0,
    "sykkylven.no" => 0,
    "sogne.no" => 0,
    "xn--sgne-gra.no" => 0,
    "somna.no" => 0,
    "xn--smna-gra.no" => 0,
    "sondre-land.no" => 0,
    "xn--sndre-land-0cb.no" => 0,
    "sor-aurdal.no" => 0,
    "xn--sr-aurdal-l8a.no" => 0,
    "sor-fron.no" => 0,
    "xn--sr-fron-q1a.no" => 0,
    "sor-odal.no" => 0,
    "xn--sr-odal-q1a.no" => 0,
    "sor-varanger.no" => 0,
    "xn--sr-varanger-ggb.no" => 0,
    "matta-varjjat.no" => 0,
    "xn--mtta-vrjjat-k7af.no" => 0,
    "sorfold.no" => 0,
    "xn--srfold-bya.no" => 0,
    "sorreisa.no" => 0,
    "xn--srreisa-q1a.no" => 0,
    "sorum.no" => 0,
    "xn--srum-gra.no" => 0,
    "tana.no" => 0,
    "deatnu.no" => 0,
    "time.no" => 0,
    "tingvoll.no" => 0,
    "tinn.no" => 0,
    "tjeldsund.no" => 0,
    "dielddanuorri.no" => 0,
    "tjome.no" => 0,
    "xn--tjme-hra.no" => 0,
    "tokke.no" => 0,
    "tolga.no" => 0,
    "torsken.no" => 0,
    "tranoy.no" => 0,
    "xn--trany-yua.no" => 0,
    "tromso.no" => 0,
    "xn--troms-zua.no" => 0,
    "tromsa.no" => 0,
    "romsa.no" => 0,
    "trondheim.no" => 0,
    "troandin.no" => 0,
    "trysil.no" => 0,
    "trana.no" => 0,
    "xn--trna-woa.no" => 0,
    "trogstad.no" => 0,
    "xn--trgstad-r1a.no" => 0,
    "tvedestrand.no" => 0,
    "tydal.no" => 0,
    "tynset.no" => 0,
    "tysfjord.no" => 0,
    "divtasvuodna.no" => 0,
    "divttasvuotna.no" => 0,
    "tysnes.no" => 0,
    "tysvar.no" => 0,
    "xn--tysvr-vra.no" => 0,
    "tonsberg.no" => 0,
    "xn--tnsberg-q1a.no" => 0,
    "ullensaker.no" => 0,
    "ullensvang.no" => 0,
    "ulvik.no" => 0,
    "utsira.no" => 0,
    "vadso.no" => 0,
    "xn--vads-jra.no" => 0,
    "cahcesuolo.no" => 0,
    "xn--hcesuolo-7ya35b.no" => 0,
    "vaksdal.no" => 0,
    "valle.no" => 0,
    "vang.no" => 0,
    "vanylven.no" => 0,
    "vardo.no" => 0,
    "xn--vard-jra.no" => 0,
    "varggat.no" => 0,
    "xn--vrggt-xqad.no" => 0,
    "vefsn.no" => 0,
    "vaapste.no" => 0,
    "vega.no" => 0,
    "vegarshei.no" => 0,
    "xn--vegrshei-c0a.no" => 0,
    "vennesla.no" => 0,
    "verdal.no" => 0,
    "verran.no" => 0,
    "vestby.no" => 0,
    "vestnes.no" => 0,
    "vestre-slidre.no" => 0,
    "vestre-toten.no" => 0,
    "vestvagoy.no" => 0,
    "xn--vestvgy-ixa6o.no" => 0,
    "vevelstad.no" => 0,
    "vik.no" => 0,
    "vikna.no" => 0,
    "vindafjord.no" => 0,
    "volda.no" => 0,
    "voss.no" => 0,
    "varoy.no" => 0,
    "xn--vry-yla5g.no" => 0,
    "vagan.no" => 0,
    "xn--vgan-qoa.no" => 0,
    "voagat.no" => 0,
    "vagsoy.no" => 0,
    "xn--vgsy-qoa0j.no" => 0,
    "vaga.no" => 0,
    "xn--vg-yiab.no" => 0,
    "valer.ostfold.no" => 0,
    "xn--vler-qoa.xn--stfold-9xa.no" => 0,
    "valer.hedmark.no" => 0,
    "xn--vler-qoa.hedmark.no" => 0,
    "np" => -1,
    "nr" => 0,
    "biz.nr" => 0,
    "info.nr" => 0,
    "gov.nr" => 0,
    "edu.nr" => 0,
    "org.nr" => 0,
    "net.nr" => 0,
    "com.nr" => 0,
    "nu" => 0,
    "nz" => -1,
    "om" => -1,
    "mediaphone.om" => 1,
    "nawrastelecom.om" => 1,
    "nawras.om" => 1,
    "omanmobile.om" => 1,
    "omanpost.om" => 1,
    "omantel.om" => 1,
    "rakpetroleum.om" => 1,
    "siemens.om" => 1,
    "songfest.om" => 1,
    "statecouncil.om" => 1,
    "org" => 0,
    "pa" => 0,
    "ac.pa" => 0,
    "gob.pa" => 0,
    "com.pa" => 0,
    "org.pa" => 0,
    "sld.pa" => 0,
    "edu.pa" => 0,
    "net.pa" => 0,
    "ing.pa" => 0,
    "abo.pa" => 0,
    "med.pa" => 0,
    "nom.pa" => 0,
    "pe" => 0,
    "edu.pe" => 0,
    "gob.pe" => 0,
    "nom.pe" => 0,
    "mil.pe" => 0,
    "org.pe" => 0,
    "com.pe" => 0,
    "net.pe" => 0,
    "pf" => 0,
    "com.pf" => 0,
    "org.pf" => 0,
    "edu.pf" => 0,
    "pg" => -1,
    "ph" => 0,
    "com.ph" => 0,
    "net.ph" => 0,
    "org.ph" => 0,
    "gov.ph" => 0,
    "edu.ph" => 0,
    "ngo.ph" => 0,
    "mil.ph" => 0,
    "i.ph" => 0,
    "pk" => 0,
    "com.pk" => 0,
    "net.pk" => 0,
    "edu.pk" => 0,
    "org.pk" => 0,
    "fam.pk" => 0,
    "biz.pk" => 0,
    "web.pk" => 0,
    "gov.pk" => 0,
    "gob.pk" => 0,
    "gok.pk" => 0,
    "gon.pk" => 0,
    "gop.pk" => 0,
    "gos.pk" => 0,
    "info.pk" => 0,
    "pl" => 0,
    "aid.pl" => 0,
    "agro.pl" => 0,
    "atm.pl" => 0,
    "auto.pl" => 0,
    "biz.pl" => 0,
    "com.pl" => 0,
    "edu.pl" => 0,
    "gmina.pl" => 0,
    "gsm.pl" => 0,
    "info.pl" => 0,
    "mail.pl" => 0,
    "miasta.pl" => 0,
    "media.pl" => 0,
    "mil.pl" => 0,
    "net.pl" => 0,
    "nieruchomosci.pl" => 0,
    "nom.pl" => 0,
    "org.pl" => 0,
    "pc.pl" => 0,
    "powiat.pl" => 0,
    "priv.pl" => 0,
    "realestate.pl" => 0,
    "rel.pl" => 0,
    "sex.pl" => 0,
    "shop.pl" => 0,
    "sklep.pl" => 0,
    "sos.pl" => 0,
    "szkola.pl" => 0,
    "targi.pl" => 0,
    "tm.pl" => 0,
    "tourism.pl" => 0,
    "travel.pl" => 0,
    "turystyka.pl" => 0,
    "6bone.pl" => 0,
    "art.pl" => 0,
    "mbone.pl" => 0,
    "gov.pl" => 0,
    "uw.gov.pl" => 0,
    "um.gov.pl" => 0,
    "ug.gov.pl" => 0,
    "upow.gov.pl" => 0,
    "starostwo.gov.pl" => 0,
    "so.gov.pl" => 0,
    "sr.gov.pl" => 0,
    "po.gov.pl" => 0,
    "pa.gov.pl" => 0,
    "ngo.pl" => 0,
    "irc.pl" => 0,
    "usenet.pl" => 0,
    "augustow.pl" => 0,
    "babia-gora.pl" => 0,
    "bedzin.pl" => 0,
    "beskidy.pl" => 0,
    "bialowieza.pl" => 0,
    "bialystok.pl" => 0,
    "bielawa.pl" => 0,
    "bieszczady.pl" => 0,
    "boleslawiec.pl" => 0,
    "bydgoszcz.pl" => 0,
    "bytom.pl" => 0,
    "cieszyn.pl" => 0,
    "czeladz.pl" => 0,
    "czest.pl" => 0,
    "dlugoleka.pl" => 0,
    "elblag.pl" => 0,
    "elk.pl" => 0,
    "glogow.pl" => 0,
    "gniezno.pl" => 0,
    "gorlice.pl" => 0,
    "grajewo.pl" => 0,
    "ilawa.pl" => 0,
    "jaworzno.pl" => 0,
    "jelenia-gora.pl" => 0,
    "jgora.pl" => 0,
    "kalisz.pl" => 0,
    "kazimierz-dolny.pl" => 0,
    "karpacz.pl" => 0,
    "kartuzy.pl" => 0,
    "kaszuby.pl" => 0,
    "katowice.pl" => 0,
    "kepno.pl" => 0,
    "ketrzyn.pl" => 0,
    "klodzko.pl" => 0,
    "kobierzyce.pl" => 0,
    "kolobrzeg.pl" => 0,
    "konin.pl" => 0,
    "konskowola.pl" => 0,
    "kutno.pl" => 0,
    "lapy.pl" => 0,
    "lebork.pl" => 0,
    "legnica.pl" => 0,
    "lezajsk.pl" => 0,
    "limanowa.pl" => 0,
    "lomza.pl" => 0,
    "lowicz.pl" => 0,
    "lubin.pl" => 0,
    "lukow.pl" => 0,
    "malbork.pl" => 0,
    "malopolska.pl" => 0,
    "mazowsze.pl" => 0,
    "mazury.pl" => 0,
    "mielec.pl" => 0,
    "mielno.pl" => 0,
    "mragowo.pl" => 0,
    "naklo.pl" => 0,
    "nowaruda.pl" => 0,
    "nysa.pl" => 0,
    "olawa.pl" => 0,
    "olecko.pl" => 0,
    "olkusz.pl" => 0,
    "olsztyn.pl" => 0,
    "opoczno.pl" => 0,
    "opole.pl" => 0,
    "ostroda.pl" => 0,
    "ostroleka.pl" => 0,
    "ostrowiec.pl" => 0,
    "ostrowwlkp.pl" => 0,
    "pila.pl" => 0,
    "pisz.pl" => 0,
    "podhale.pl" => 0,
    "podlasie.pl" => 0,
    "polkowice.pl" => 0,
    "pomorze.pl" => 0,
    "pomorskie.pl" => 0,
    "prochowice.pl" => 0,
    "pruszkow.pl" => 0,
    "przeworsk.pl" => 0,
    "pulawy.pl" => 0,
    "radom.pl" => 0,
    "rawa-maz.pl" => 0,
    "rybnik.pl" => 0,
    "rzeszow.pl" => 0,
    "sanok.pl" => 0,
    "sejny.pl" => 0,
    "siedlce.pl" => 0,
    "slask.pl" => 0,
    "slupsk.pl" => 0,
    "sosnowiec.pl" => 0,
    "stalowa-wola.pl" => 0,
    "skoczow.pl" => 0,
    "starachowice.pl" => 0,
    "stargard.pl" => 0,
    "suwalki.pl" => 0,
    "swidnica.pl" => 0,
    "swiebodzin.pl" => 0,
    "swinoujscie.pl" => 0,
    "szczecin.pl" => 0,
    "szczytno.pl" => 0,
    "tarnobrzeg.pl" => 0,
    "tgory.pl" => 0,
    "turek.pl" => 0,
    "tychy.pl" => 0,
    "ustka.pl" => 0,
    "walbrzych.pl" => 0,
    "warmia.pl" => 0,
    "warszawa.pl" => 0,
    "waw.pl" => 0,
    "wegrow.pl" => 0,
    "wielun.pl" => 0,
    "wlocl.pl" => 0,
    "wloclawek.pl" => 0,
    "wodzislaw.pl" => 0,
    "wolomin.pl" => 0,
    "wroclaw.pl" => 0,
    "zachpomor.pl" => 0,
    "zagan.pl" => 0,
    "zarow.pl" => 0,
    "zgora.pl" => 0,
    "zgorzelec.pl" => 0,
    "gda.pl" => 0,
    "gdansk.pl" => 0,
    "gdynia.pl" => 0,
    "med.pl" => 0,
    "sopot.pl" => 0,
    "gliwice.pl" => 0,
    "krakow.pl" => 0,
    "poznan.pl" => 0,
    "wroc.pl" => 0,
    "zakopane.pl" => 0,
    "pm" => 0,
    "pn" => 0,
    "gov.pn" => 0,
    "co.pn" => 0,
    "org.pn" => 0,
    "edu.pn" => 0,
    "net.pn" => 0,
    "post" => 0,
    "pr" => 0,
    "com.pr" => 0,
    "net.pr" => 0,
    "org.pr" => 0,
    "gov.pr" => 0,
    "edu.pr" => 0,
    "isla.pr" => 0,
    "pro.pr" => 0,
    "biz.pr" => 0,
    "info.pr" => 0,
    "name.pr" => 0,
    "est.pr" => 0,
    "prof.pr" => 0,
    "ac.pr" => 0,
    "pro" => 0,
    "aca.pro" => 0,
    "bar.pro" => 0,
    "cpa.pro" => 0,
    "jur.pro" => 0,
    "law.pro" => 0,
    "med.pro" => 0,
    "eng.pro" => 0,
    "ps" => 0,
    "edu.ps" => 0,
    "gov.ps" => 0,
    "sec.ps" => 0,
    "plo.ps" => 0,
    "com.ps" => 0,
    "org.ps" => 0,
    "net.ps" => 0,
    "pt" => 0,
    "net.pt" => 0,
    "gov.pt" => 0,
    "org.pt" => 0,
    "edu.pt" => 0,
    "int.pt" => 0,
    "publ.pt" => 0,
    "com.pt" => 0,
    "nome.pt" => 0,
    "pw" => 0,
    "co.pw" => 0,
    "ne.pw" => 0,
    "or.pw" => 0,
    "ed.pw" => 0,
    "go.pw" => 0,
    "belau.pw" => 0,
    "py" => 0,
    "com.py" => 0,
    "coop.py" => 0,
    "edu.py" => 0,
    "gov.py" => 0,
    "mil.py" => 0,
    "net.py" => 0,
    "org.py" => 0,
    "qa" => 0,
    "com.qa" => 0,
    "edu.qa" => 0,
    "gov.qa" => 0,
    "mil.qa" => 0,
    "name.qa" => 0,
    "net.qa" => 0,
    "org.qa" => 0,
    "sch.qa" => 0,
    "re" => 0,
    "com.re" => 0,
    "asso.re" => 0,
    "nom.re" => 0,
    "ro" => 0,
    "com.ro" => 0,
    "org.ro" => 0,
    "tm.ro" => 0,
    "nt.ro" => 0,
    "nom.ro" => 0,
    "info.ro" => 0,
    "rec.ro" => 0,
    "arts.ro" => 0,
    "firm.ro" => 0,
    "store.ro" => 0,
    "www.ro" => 0,
    "rs" => 0,
    "co.rs" => 0,
    "org.rs" => 0,
    "edu.rs" => 0,
    "ac.rs" => 0,
    "gov.rs" => 0,
    "in.rs" => 0,
    "ru" => 0,
    "ac.ru" => 0,
    "com.ru" => 0,
    "edu.ru" => 0,
    "int.ru" => 0,
    "net.ru" => 0,
    "org.ru" => 0,
    "pp.ru" => 0,
    "adygeya.ru" => 0,
    "altai.ru" => 0,
    "amur.ru" => 0,
    "arkhangelsk.ru" => 0,
    "astrakhan.ru" => 0,
    "bashkiria.ru" => 0,
    "belgorod.ru" => 0,
    "bir.ru" => 0,
    "bryansk.ru" => 0,
    "buryatia.ru" => 0,
    "cbg.ru" => 0,
    "chel.ru" => 0,
    "chelyabinsk.ru" => 0,
    "chita.ru" => 0,
    "chukotka.ru" => 0,
    "chuvashia.ru" => 0,
    "dagestan.ru" => 0,
    "dudinka.ru" => 0,
    "e-burg.ru" => 0,
    "grozny.ru" => 0,
    "irkutsk.ru" => 0,
    "ivanovo.ru" => 0,
    "izhevsk.ru" => 0,
    "jar.ru" => 0,
    "joshkar-ola.ru" => 0,
    "kalmykia.ru" => 0,
    "kaluga.ru" => 0,
    "kamchatka.ru" => 0,
    "karelia.ru" => 0,
    "kazan.ru" => 0,
    "kchr.ru" => 0,
    "kemerovo.ru" => 0,
    "khabarovsk.ru" => 0,
    "khakassia.ru" => 0,
    "khv.ru" => 0,
    "kirov.ru" => 0,
    "koenig.ru" => 0,
    "komi.ru" => 0,
    "kostroma.ru" => 0,
    "krasnoyarsk.ru" => 0,
    "kuban.ru" => 0,
    "kurgan.ru" => 0,
    "kursk.ru" => 0,
    "lipetsk.ru" => 0,
    "magadan.ru" => 0,
    "mari.ru" => 0,
    "mari-el.ru" => 0,
    "marine.ru" => 0,
    "mordovia.ru" => 0,
    "mosreg.ru" => 0,
    "msk.ru" => 0,
    "murmansk.ru" => 0,
    "nalchik.ru" => 0,
    "nnov.ru" => 0,
    "nov.ru" => 0,
    "novosibirsk.ru" => 0,
    "nsk.ru" => 0,
    "omsk.ru" => 0,
    "orenburg.ru" => 0,
    "oryol.ru" => 0,
    "palana.ru" => 0,
    "penza.ru" => 0,
    "perm.ru" => 0,
    "pskov.ru" => 0,
    "ptz.ru" => 0,
    "rnd.ru" => 0,
    "ryazan.ru" => 0,
    "sakhalin.ru" => 0,
    "samara.ru" => 0,
    "saratov.ru" => 0,
    "simbirsk.ru" => 0,
    "smolensk.ru" => 0,
    "spb.ru" => 0,
    "stavropol.ru" => 0,
    "stv.ru" => 0,
    "surgut.ru" => 0,
    "tambov.ru" => 0,
    "tatarstan.ru" => 0,
    "tom.ru" => 0,
    "tomsk.ru" => 0,
    "tsaritsyn.ru" => 0,
    "tsk.ru" => 0,
    "tula.ru" => 0,
    "tuva.ru" => 0,
    "tver.ru" => 0,
    "tyumen.ru" => 0,
    "udm.ru" => 0,
    "udmurtia.ru" => 0,
    "ulan-ude.ru" => 0,
    "vladikavkaz.ru" => 0,
    "vladimir.ru" => 0,
    "vladivostok.ru" => 0,
    "volgograd.ru" => 0,
    "vologda.ru" => 0,
    "voronezh.ru" => 0,
    "vrn.ru" => 0,
    "vyatka.ru" => 0,
    "yakutia.ru" => 0,
    "yamal.ru" => 0,
    "yaroslavl.ru" => 0,
    "yekaterinburg.ru" => 0,
    "yuzhno-sakhalinsk.ru" => 0,
    "amursk.ru" => 0,
    "baikal.ru" => 0,
    "cmw.ru" => 0,
    "fareast.ru" => 0,
    "jamal.ru" => 0,
    "kms.ru" => 0,
    "k-uralsk.ru" => 0,
    "kustanai.ru" => 0,
    "kuzbass.ru" => 0,
    "magnitka.ru" => 0,
    "mytis.ru" => 0,
    "nakhodka.ru" => 0,
    "nkz.ru" => 0,
    "norilsk.ru" => 0,
    "oskol.ru" => 0,
    "pyatigorsk.ru" => 0,
    "rubtsovsk.ru" => 0,
    "snz.ru" => 0,
    "syzran.ru" => 0,
    "vdonsk.ru" => 0,
    "zgrad.ru" => 0,
    "gov.ru" => 0,
    "mil.ru" => 0,
    "test.ru" => 0,
    "rw" => 0,
    "gov.rw" => 0,
    "net.rw" => 0,
    "edu.rw" => 0,
    "ac.rw" => 0,
    "com.rw" => 0,
    "co.rw" => 0,
    "int.rw" => 0,
    "mil.rw" => 0,
    "gouv.rw" => 0,
    "sa" => 0,
    "com.sa" => 0,
    "net.sa" => 0,
    "org.sa" => 0,
    "gov.sa" => 0,
    "med.sa" => 0,
    "pub.sa" => 0,
    "edu.sa" => 0,
    "sch.sa" => 0,
    "sb" => 0,
    "com.sb" => 0,
    "edu.sb" => 0,
    "gov.sb" => 0,
    "net.sb" => 0,
    "org.sb" => 0,
    "sc" => 0,
    "com.sc" => 0,
    "gov.sc" => 0,
    "net.sc" => 0,
    "org.sc" => 0,
    "edu.sc" => 0,
    "sd" => 0,
    "com.sd" => 0,
    "net.sd" => 0,
    "org.sd" => 0,
    "edu.sd" => 0,
    "med.sd" => 0,
    "tv.sd" => 0,
    "gov.sd" => 0,
    "info.sd" => 0,
    "se" => 0,
    "a.se" => 0,
    "ac.se" => 0,
    "b.se" => 0,
    "bd.se" => 0,
    "brand.se" => 0,
    "c.se" => 0,
    "d.se" => 0,
    "e.se" => 0,
    "f.se" => 0,
    "fh.se" => 0,
    "fhsk.se" => 0,
    "fhv.se" => 0,
    "g.se" => 0,
    "h.se" => 0,
    "i.se" => 0,
    "k.se" => 0,
    "komforb.se" => 0,
    "kommunalforbund.se" => 0,
    "komvux.se" => 0,
    "l.se" => 0,
    "lanbib.se" => 0,
    "m.se" => 0,
    "n.se" => 0,
    "naturbruksgymn.se" => 0,
    "o.se" => 0,
    "org.se" => 0,
    "p.se" => 0,
    "parti.se" => 0,
    "pp.se" => 0,
    "press.se" => 0,
    "r.se" => 0,
    "s.se" => 0,
    "sshn.se" => 0,
    "t.se" => 0,
    "tm.se" => 0,
    "u.se" => 0,
    "w.se" => 0,
    "x.se" => 0,
    "y.se" => 0,
    "z.se" => 0,
    "sg" => 0,
    "com.sg" => 0,
    "net.sg" => 0,
    "org.sg" => 0,
    "gov.sg" => 0,
    "edu.sg" => 0,
    "per.sg" => 0,
    "sh" => 0,
    "com.sh" => 0,
    "net.sh" => 0,
    "gov.sh" => 0,
    "org.sh" => 0,
    "mil.sh" => 0,
    "si" => 0,
    "sk" => 0,
    "sl" => 0,
    "com.sl" => 0,
    "net.sl" => 0,
    "edu.sl" => 0,
    "gov.sl" => 0,
    "org.sl" => 0,
    "sm" => 0,
    "sn" => 0,
    "art.sn" => 0,
    "com.sn" => 0,
    "edu.sn" => 0,
    "gouv.sn" => 0,
    "org.sn" => 0,
    "perso.sn" => 0,
    "univ.sn" => 0,
    "so" => 0,
    "com.so" => 0,
    "net.so" => 0,
    "org.so" => 0,
    "sr" => 0,
    "st" => 0,
    "co.st" => 0,
    "com.st" => 0,
    "consulado.st" => 0,
    "edu.st" => 0,
    "embaixada.st" => 0,
    "gov.st" => 0,
    "mil.st" => 0,
    "net.st" => 0,
    "org.st" => 0,
    "principe.st" => 0,
    "saotome.st" => 0,
    "store.st" => 0,
    "su" => 0,
    "sv" => -1,
    "sx" => 0,
    "gov.sx" => 0,
    "sy" => 0,
    "edu.sy" => 0,
    "gov.sy" => 0,
    "net.sy" => 0,
    "mil.sy" => 0,
    "com.sy" => 0,
    "org.sy" => 0,
    "sz" => 0,
    "co.sz" => 0,
    "ac.sz" => 0,
    "org.sz" => 0,
    "tc" => 0,
    "td" => 0,
    "tel" => 0,
    "tf" => 0,
    "tg" => 0,
    "th" => 0,
    "ac.th" => 0,
    "co.th" => 0,
    "go.th" => 0,
    "in.th" => 0,
    "mi.th" => 0,
    "net.th" => 0,
    "or.th" => 0,
    "tj" => 0,
    "ac.tj" => 0,
    "biz.tj" => 0,
    "co.tj" => 0,
    "com.tj" => 0,
    "edu.tj" => 0,
    "go.tj" => 0,
    "gov.tj" => 0,
    "int.tj" => 0,
    "mil.tj" => 0,
    "name.tj" => 0,
    "net.tj" => 0,
    "nic.tj" => 0,
    "org.tj" => 0,
    "test.tj" => 0,
    "web.tj" => 0,
    "tk" => 0,
    "tl" => 0,
    "gov.tl" => 0,
    "tm" => 0,
    "com.tm" => 0,
    "co.tm" => 0,
    "org.tm" => 0,
    "net.tm" => 0,
    "nom.tm" => 0,
    "gov.tm" => 0,
    "mil.tm" => 0,
    "edu.tm" => 0,
    "tn" => 0,
    "com.tn" => 0,
    "ens.tn" => 0,
    "fin.tn" => 0,
    "gov.tn" => 0,
    "ind.tn" => 0,
    "intl.tn" => 0,
    "nat.tn" => 0,
    "net.tn" => 0,
    "org.tn" => 0,
    "info.tn" => 0,
    "perso.tn" => 0,
    "tourism.tn" => 0,
    "edunet.tn" => 0,
    "rnrt.tn" => 0,
    "rns.tn" => 0,
    "rnu.tn" => 0,
    "mincom.tn" => 0,
    "agrinet.tn" => 0,
    "defense.tn" => 0,
    "turen.tn" => 0,
    "to" => 0,
    "com.to" => 0,
    "gov.to" => 0,
    "net.to" => 0,
    "org.to" => 0,
    "edu.to" => 0,
    "mil.to" => 0,
    "tr" => -1,
    "nic.tr" => 1,
    "gov.nc.tr" => 0,
    "travel" => 0,
    "tt" => 0,
    "co.tt" => 0,
    "com.tt" => 0,
    "org.tt" => 0,
    "net.tt" => 0,
    "biz.tt" => 0,
    "info.tt" => 0,
    "pro.tt" => 0,
    "int.tt" => 0,
    "coop.tt" => 0,
    "jobs.tt" => 0,
    "mobi.tt" => 0,
    "travel.tt" => 0,
    "museum.tt" => 0,
    "aero.tt" => 0,
    "name.tt" => 0,
    "gov.tt" => 0,
    "edu.tt" => 0,
    "tv" => 0,
    "tw" => 0,
    "edu.tw" => 0,
    "gov.tw" => 0,
    "mil.tw" => 0,
    "com.tw" => 0,
    "net.tw" => 0,
    "org.tw" => 0,
    "idv.tw" => 0,
    "game.tw" => 0,
    "ebiz.tw" => 0,
    "club.tw" => 0,
    "xn--zf0ao64a.tw" => 0,
    "xn--uc0atv.tw" => 0,
    "xn--czrw28b.tw" => 0,
    "tz" => 1,
    "ac.tz" => 0,
    "co.tz" => 0,
    "go.tz" => 0,
    "hotel.tz" => 0,
    "info.tz" => 0,
    "me.tz" => 0,
    "mil.tz" => 0,
    "mobi.tz" => 0,
    "ne.tz" => 0,
    "or.tz" => 0,
    "sc.tz" => 0,
    "tv.tz" => 0,
    "ua" => 0,
    "com.ua" => 0,
    "edu.ua" => 0,
    "gov.ua" => 0,
    "in.ua" => 0,
    "net.ua" => 0,
    "org.ua" => 0,
    "cherkassy.ua" => 0,
    "cherkasy.ua" => 0,
    "chernigov.ua" => 0,
    "chernihiv.ua" => 0,
    "chernivtsi.ua" => 0,
    "chernovtsy.ua" => 0,
    "ck.ua" => 0,
    "cn.ua" => 0,
    "cr.ua" => 0,
    "crimea.ua" => 0,
    "cv.ua" => 0,
    "dn.ua" => 0,
    "dnepropetrovsk.ua" => 0,
    "dnipropetrovsk.ua" => 0,
    "dominic.ua" => 0,
    "donetsk.ua" => 0,
    "dp.ua" => 0,
    "if.ua" => 0,
    "ivano-frankivsk.ua" => 0,
    "kh.ua" => 0,
    "kharkiv.ua" => 0,
    "kharkov.ua" => 0,
    "kherson.ua" => 0,
    "khmelnitskiy.ua" => 0,
    "khmelnytskyi.ua" => 0,
    "kiev.ua" => 0,
    "kirovograd.ua" => 0,
    "km.ua" => 0,
    "kr.ua" => 0,
    "krym.ua" => 0,
    "ks.ua" => 0,
    "kv.ua" => 0,
    "kyiv.ua" => 0,
    "lg.ua" => 0,
    "lt.ua" => 0,
    "lugansk.ua" => 0,
    "lutsk.ua" => 0,
    "lv.ua" => 0,
    "lviv.ua" => 0,
    "mk.ua" => 0,
    "mykolaiv.ua" => 0,
    "nikolaev.ua" => 0,
    "od.ua" => 0,
    "odesa.ua" => 0,
    "odessa.ua" => 0,
    "pl.ua" => 0,
    "poltava.ua" => 0,
    "rivne.ua" => 0,
    "rovno.ua" => 0,
    "rv.ua" => 0,
    "sb.ua" => 0,
    "sebastopol.ua" => 0,
    "sevastopol.ua" => 0,
    "sm.ua" => 0,
    "sumy.ua" => 0,
    "te.ua" => 0,
    "ternopil.ua" => 0,
    "uz.ua" => 0,
    "uzhgorod.ua" => 0,
    "vinnica.ua" => 0,
    "vinnytsia.ua" => 0,
    "vn.ua" => 0,
    "volyn.ua" => 0,
    "yalta.ua" => 0,
    "zaporizhzhe.ua" => 0,
    "zaporizhzhia.ua" => 0,
    "zhitomir.ua" => 0,
    "zhytomyr.ua" => 0,
    "zp.ua" => 0,
    "zt.ua" => 0,
    "co.ua" => 0,
    "pp.ua" => 0,
    "ug" => 0,
    "co.ug" => 0,
    "or.ug" => 0,
    "ac.ug" => 0,
    "sc.ug" => 0,
    "go.ug" => 0,
    "ne.ug" => 0,
    "com.ug" => 0,
    "org.ug" => 0,
    "uk" => -1,
    "sch.uk" => -1,
    "bl.uk" => 1,
    "british-library.uk" => 1,
    "jet.uk" => 1,
    "mod.uk" => 1,
    "national-library-scotland.uk" => 1,
    "nel.uk" => 1,
    "nic.uk" => 1,
    "nls.uk" => 1,
    "parliament.uk" => 1,
    "us" => 0,
    "dni.us" => 0,
    "fed.us" => 0,
    "isa.us" => 0,
    "kids.us" => 0,
    "nsn.us" => 0,
    "ak.us" => 0,
    "al.us" => 0,
    "ar.us" => 0,
    "as.us" => 0,
    "az.us" => 0,
    "ca.us" => 0,
    "co.us" => 0,
    "ct.us" => 0,
    "dc.us" => 0,
    "de.us" => 0,
    "fl.us" => 0,
    "ga.us" => 0,
    "gu.us" => 0,
    "hi.us" => 0,
    "ia.us" => 0,
    "id.us" => 0,
    "il.us" => 0,
    "in.us" => 0,
    "ks.us" => 0,
    "ky.us" => 0,
    "la.us" => 0,
    "ma.us" => 0,
    "md.us" => 0,
    "me.us" => 0,
    "mi.us" => 0,
    "mn.us" => 0,
    "mo.us" => 0,
    "ms.us" => 0,
    "mt.us" => 0,
    "nc.us" => 0,
    "nd.us" => 0,
    "ne.us" => 0,
    "nh.us" => 0,
    "nj.us" => 0,
    "nm.us" => 0,
    "nv.us" => 0,
    "ny.us" => 0,
    "oh.us" => 0,
    "ok.us" => 0,
    "or.us" => 0,
    "pa.us" => 0,
    "pr.us" => 0,
    "ri.us" => 0,
    "sc.us" => 0,
    "sd.us" => 0,
    "tn.us" => 0,
    "tx.us" => 0,
    "ut.us" => 0,
    "vi.us" => 0,
    "vt.us" => 0,
    "va.us" => 0,
    "wa.us" => 0,
    "wi.us" => 0,
    "wv.us" => 0,
    "wy.us" => 0,
    "k12.ak.us" => 0,
    "k12.al.us" => 0,
    "k12.ar.us" => 0,
    "k12.as.us" => 0,
    "k12.az.us" => 0,
    "k12.ca.us" => 0,
    "k12.co.us" => 0,
    "k12.ct.us" => 0,
    "k12.dc.us" => 0,
    "k12.de.us" => 0,
    "k12.fl.us" => 0,
    "k12.ga.us" => 0,
    "k12.gu.us" => 0,
    "k12.ia.us" => 0,
    "k12.id.us" => 0,
    "k12.il.us" => 0,
    "k12.in.us" => 0,
    "k12.ks.us" => 0,
    "k12.ky.us" => 0,
    "k12.la.us" => 0,
    "k12.ma.us" => 0,
    "k12.md.us" => 0,
    "k12.me.us" => 0,
    "k12.mi.us" => 0,
    "k12.mn.us" => 0,
    "k12.mo.us" => 0,
    "k12.ms.us" => 0,
    "k12.mt.us" => 0,
    "k12.nc.us" => 0,
    "k12.nd.us" => 0,
    "k12.ne.us" => 0,
    "k12.nh.us" => 0,
    "k12.nj.us" => 0,
    "k12.nm.us" => 0,
    "k12.nv.us" => 0,
    "k12.ny.us" => 0,
    "k12.oh.us" => 0,
    "k12.ok.us" => 0,
    "k12.or.us" => 0,
    "k12.pa.us" => 0,
    "k12.pr.us" => 0,
    "k12.ri.us" => 0,
    "k12.sc.us" => 0,
    "k12.sd.us" => 0,
    "k12.tn.us" => 0,
    "k12.tx.us" => 0,
    "k12.ut.us" => 0,
    "k12.vi.us" => 0,
    "k12.vt.us" => 0,
    "k12.va.us" => 0,
    "k12.wa.us" => 0,
    "k12.wi.us" => 0,
    "k12.wv.us" => 0,
    "k12.wy.us" => 0,
    "cc.ak.us" => 0,
    "cc.al.us" => 0,
    "cc.ar.us" => 0,
    "cc.as.us" => 0,
    "cc.az.us" => 0,
    "cc.ca.us" => 0,
    "cc.co.us" => 0,
    "cc.ct.us" => 0,
    "cc.dc.us" => 0,
    "cc.de.us" => 0,
    "cc.fl.us" => 0,
    "cc.ga.us" => 0,
    "cc.gu.us" => 0,
    "cc.hi.us" => 0,
    "cc.ia.us" => 0,
    "cc.id.us" => 0,
    "cc.il.us" => 0,
    "cc.in.us" => 0,
    "cc.ks.us" => 0,
    "cc.ky.us" => 0,
    "cc.la.us" => 0,
    "cc.ma.us" => 0,
    "cc.md.us" => 0,
    "cc.me.us" => 0,
    "cc.mi.us" => 0,
    "cc.mn.us" => 0,
    "cc.mo.us" => 0,
    "cc.ms.us" => 0,
    "cc.mt.us" => 0,
    "cc.nc.us" => 0,
    "cc.nd.us" => 0,
    "cc.ne.us" => 0,
    "cc.nh.us" => 0,
    "cc.nj.us" => 0,
    "cc.nm.us" => 0,
    "cc.nv.us" => 0,
    "cc.ny.us" => 0,
    "cc.oh.us" => 0,
    "cc.ok.us" => 0,
    "cc.or.us" => 0,
    "cc.pa.us" => 0,
    "cc.pr.us" => 0,
    "cc.ri.us" => 0,
    "cc.sc.us" => 0,
    "cc.sd.us" => 0,
    "cc.tn.us" => 0,
    "cc.tx.us" => 0,
    "cc.ut.us" => 0,
    "cc.vi.us" => 0,
    "cc.vt.us" => 0,
    "cc.va.us" => 0,
    "cc.wa.us" => 0,
    "cc.wi.us" => 0,
    "cc.wv.us" => 0,
    "cc.wy.us" => 0,
    "lib.ak.us" => 0,
    "lib.al.us" => 0,
    "lib.ar.us" => 0,
    "lib.as.us" => 0,
    "lib.az.us" => 0,
    "lib.ca.us" => 0,
    "lib.co.us" => 0,
    "lib.ct.us" => 0,
    "lib.dc.us" => 0,
    "lib.de.us" => 0,
    "lib.fl.us" => 0,
    "lib.ga.us" => 0,
    "lib.gu.us" => 0,
    "lib.hi.us" => 0,
    "lib.ia.us" => 0,
    "lib.id.us" => 0,
    "lib.il.us" => 0,
    "lib.in.us" => 0,
    "lib.ks.us" => 0,
    "lib.ky.us" => 0,
    "lib.la.us" => 0,
    "lib.ma.us" => 0,
    "lib.md.us" => 0,
    "lib.me.us" => 0,
    "lib.mi.us" => 0,
    "lib.mn.us" => 0,
    "lib.mo.us" => 0,
    "lib.ms.us" => 0,
    "lib.mt.us" => 0,
    "lib.nc.us" => 0,
    "lib.nd.us" => 0,
    "lib.ne.us" => 0,
    "lib.nh.us" => 0,
    "lib.nj.us" => 0,
    "lib.nm.us" => 0,
    "lib.nv.us" => 0,
    "lib.ny.us" => 0,
    "lib.oh.us" => 0,
    "lib.ok.us" => 0,
    "lib.or.us" => 0,
    "lib.pa.us" => 0,
    "lib.pr.us" => 0,
    "lib.ri.us" => 0,
    "lib.sc.us" => 0,
    "lib.sd.us" => 0,
    "lib.tn.us" => 0,
    "lib.tx.us" => 0,
    "lib.ut.us" => 0,
    "lib.vi.us" => 0,
    "lib.vt.us" => 0,
    "lib.va.us" => 0,
    "lib.wa.us" => 0,
    "lib.wi.us" => 0,
    "lib.wv.us" => 0,
    "lib.wy.us" => 0,
    "pvt.k12.ma.us" => 0,
    "chtr.k12.ma.us" => 0,
    "paroch.k12.ma.us" => 0,
    "uy" => 0,
    "com.uy" => 0,
    "edu.uy" => 0,
    "gub.uy" => 0,
    "mil.uy" => 0,
    "net.uy" => 0,
    "org.uy" => 0,
    "uz" => 0,
    "co.uz" => 0,
    "com.uz" => 0,
    "net.uz" => 0,
    "org.uz" => 0,
    "va" => 0,
    "vc" => 0,
    "com.vc" => 0,
    "net.vc" => 0,
    "org.vc" => 0,
    "gov.vc" => 0,
    "mil.vc" => 0,
    "edu.vc" => 0,
    "ve" => 0,
    "co.ve" => 0,
    "com.ve" => 0,
    "e12.ve" => 0,
    "edu.ve" => 0,
    "gov.ve" => 0,
    "info.ve" => 0,
    "mil.ve" => 0,
    "net.ve" => 0,
    "org.ve" => 0,
    "web.ve" => 0,
    "vg" => 0,
    "vi" => 0,
    "co.vi" => 0,
    "com.vi" => 0,
    "k12.vi" => 0,
    "net.vi" => 0,
    "org.vi" => 0,
    "vn" => 0,
    "com.vn" => 0,
    "net.vn" => 0,
    "org.vn" => 0,
    "edu.vn" => 0,
    "gov.vn" => 0,
    "int.vn" => 0,
    "ac.vn" => 0,
    "biz.vn" => 0,
    "info.vn" => 0,
    "name.vn" => 0,
    "pro.vn" => 0,
    "health.vn" => 0,
    "vu" => 0,
    "wf" => 0,
    "ws" => 0,
    "com.ws" => 0,
    "net.ws" => 0,
    "org.ws" => 0,
    "gov.ws" => 0,
    "edu.ws" => 0,
    "yt" => 0,
    "xn--mgbaam7a8h" => 0,
    "xn--54b7fta0cc" => 0,
    "xn--fiqs8s" => 0,
    "xn--fiqz9s" => 0,
    "xn--lgbbat1ad8j" => 0,
    "xn--wgbh1c" => 0,
    "xn--node" => 0,
    "xn--j6w193g" => 0,
    "xn--h2brj9c" => 0,
    "xn--mgbbh1a71e" => 0,
    "xn--fpcrj9c3d" => 0,
    "xn--gecrj9c" => 0,
    "xn--s9brj9c" => 0,
    "xn--45brj9c" => 0,
    "xn--xkc2dl3a5ee0h" => 0,
    "xn--mgba3a4f16a" => 0,
    "xn--mgba3a4fra" => 0,
    "xn--mgbayh7gpa" => 0,
    "xn--3e0b707e" => 0,
    "xn--fzc2c9e2c" => 0,
    "xn--xkc2al3hye2a" => 0,
    "xn--mgbc0a9azcg" => 0,
    "xn--mgb9awbf" => 0,
    "xn--ygbi2ammx" => 0,
    "xn--90a3ac" => 0,
    "xn--p1ai" => 0,
    "xn--wgbl6a" => 0,
    "xn--mgberp4a5d4ar" => 0,
    "xn--mgberp4a5d4a87g" => 0,
    "xn--mgbqly7c0a67fbc" => 0,
    "xn--mgbqly7cvafr" => 0,
    "xn--ogbpf8fl" => 0,
    "xn--mgbtf8fl" => 0,
    "xn--yfro4i67o" => 0,
    "xn--clchc0ea0b2g2a9gcd" => 0,
    "xn--o3cw4h" => 0,
    "xn--pgbs0dh" => 0,
    "xn--kpry57d" => 0,
    "xn--kprw13d" => 0,
    "xn--nnx388a" => 0,
    "xn--j1amh" => 0,
    "xn--mgb2ddes" => 0,
    "xxx" => 0,
    "ye" => -1,
    "za" => -1,
    "zm" => -1,
    "zw" => -1,
    "cloudfront.net" => 0,
    "compute.amazonaws.com" => 0,
    "us-east-1.amazonaws.com" => 0,
    "compute-1.amazonaws.com" => 0,
    "z-1.compute-1.amazonaws.com" => 0,
    "z-2.compute-1.amazonaws.com" => 0,
    "ap-northeast-1.compute.amazonaws.com" => 0,
    "ap-southeast-1.compute.amazonaws.com" => 0,
    "ap-southeast-2.compute.amazonaws.com" => 0,
    "eu-west-1.compute.amazonaws.com" => 0,
    "sa-east-1.compute.amazonaws.com" => 0,
    "us-gov-west-1.compute.amazonaws.com" => 0,
    "us-west-1.compute.amazonaws.com" => 0,
    "us-west-2.compute.amazonaws.com" => 0,
    "elasticbeanstalk.com" => 0,
    "elb.amazonaws.com" => 0,
    "s3.amazonaws.com" => 0,
    "s3-us-west-2.amazonaws.com" => 0,
    "s3-us-west-1.amazonaws.com" => 0,
    "s3-eu-west-1.amazonaws.com" => 0,
    "s3-ap-southeast-1.amazonaws.com" => 0,
    "s3-ap-southeast-2.amazonaws.com" => 0,
    "s3-ap-northeast-1.amazonaws.com" => 0,
    "s3-sa-east-1.amazonaws.com" => 0,
    "s3-us-gov-west-1.amazonaws.com" => 0,
    "s3-fips-us-gov-west-1.amazonaws.com" => 0,
    "s3-website-us-east-1.amazonaws.com" => 0,
    "s3-website-us-west-2.amazonaws.com" => 0,
    "s3-website-us-west-1.amazonaws.com" => 0,
    "s3-website-eu-west-1.amazonaws.com" => 0,
    "s3-website-ap-southeast-1.amazonaws.com" => 0,
    "s3-website-ap-southeast-2.amazonaws.com" => 0,
    "s3-website-ap-northeast-1.amazonaws.com" => 0,
    "s3-website-sa-east-1.amazonaws.com" => 0,
    "s3-website-us-gov-west-1.amazonaws.com" => 0,
    "betainabox.com" => 0,
    "ae.org" => 0,
    "ar.com" => 0,
    "br.com" => 0,
    "cn.com" => 0,
    "com.de" => 0,
    "de.com" => 0,
    "eu.com" => 0,
    "gb.com" => 0,
    "gb.net" => 0,
    "gr.com" => 0,
    "hu.com" => 0,
    "hu.net" => 0,
    "jp.net" => 0,
    "jpn.com" => 0,
    "kr.com" => 0,
    "no.com" => 0,
    "qc.com" => 0,
    "ru.com" => 0,
    "sa.com" => 0,
    "se.com" => 0,
    "se.net" => 0,
    "uk.com" => 0,
    "uk.net" => 0,
    "us.com" => 0,
    "us.org" => 0,
    "uy.com" => 0,
    "za.com" => 0,
    "c.la" => 0,
    "co.ca" => 0,
    "co.nl" => 0,
    "co.no" => 0,
    "dreamhosters.com" => 0,
    "dyndns-at-home.com" => 0,
    "dyndns-at-work.com" => 0,
    "dyndns-blog.com" => 0,
    "dyndns-free.com" => 0,
    "dyndns-home.com" => 0,
    "dyndns-ip.com" => 0,
    "dyndns-mail.com" => 0,
    "dyndns-office.com" => 0,
    "dyndns-pics.com" => 0,
    "dyndns-remote.com" => 0,
    "dyndns-server.com" => 0,
    "dyndns-web.com" => 0,
    "dyndns-wiki.com" => 0,
    "dyndns-work.com" => 0,
    "dyndns.biz" => 0,
    "dyndns.info" => 0,
    "dyndns.org" => 0,
    "dyndns.tv" => 0,
    "at-band-camp.net" => 0,
    "ath.cx" => 0,
    "barrel-of-knowledge.info" => 0,
    "barrell-of-knowledge.info" => 0,
    "better-than.tv" => 0,
    "blogdns.com" => 0,
    "blogdns.net" => 0,
    "blogdns.org" => 0,
    "blogsite.org" => 0,
    "boldlygoingnowhere.org" => 0,
    "broke-it.net" => 0,
    "buyshouses.net" => 0,
    "cechire.com" => 0,
    "dnsalias.com" => 0,
    "dnsalias.net" => 0,
    "dnsalias.org" => 0,
    "dnsdojo.com" => 0,
    "dnsdojo.net" => 0,
    "dnsdojo.org" => 0,
    "does-it.net" => 0,
    "doesntexist.com" => 0,
    "doesntexist.org" => 0,
    "dontexist.com" => 0,
    "dontexist.net" => 0,
    "dontexist.org" => 0,
    "doomdns.com" => 0,
    "doomdns.org" => 0,
    "dvrdns.org" => 0,
    "dyn-o-saur.com" => 0,
    "dynalias.com" => 0,
    "dynalias.net" => 0,
    "dynalias.org" => 0,
    "dynathome.net" => 0,
    "dyndns.ws" => 0,
    "endofinternet.net" => 0,
    "endofinternet.org" => 0,
    "endoftheinternet.org" => 0,
    "est-a-la-maison.com" => 0,
    "est-a-la-masion.com" => 0,
    "est-le-patron.com" => 0,
    "est-mon-blogueur.com" => 0,
    "for-better.biz" => 0,
    "for-more.biz" => 0,
    "for-our.info" => 0,
    "for-some.biz" => 0,
    "for-the.biz" => 0,
    "forgot.her.name" => 0,
    "forgot.his.name" => 0,
    "from-ak.com" => 0,
    "from-al.com" => 0,
    "from-ar.com" => 0,
    "from-az.net" => 0,
    "from-ca.com" => 0,
    "from-co.net" => 0,
    "from-ct.com" => 0,
    "from-dc.com" => 0,
    "from-de.com" => 0,
    "from-fl.com" => 0,
    "from-ga.com" => 0,
    "from-hi.com" => 0,
    "from-ia.com" => 0,
    "from-id.com" => 0,
    "from-il.com" => 0,
    "from-in.com" => 0,
    "from-ks.com" => 0,
    "from-ky.com" => 0,
    "from-la.net" => 0,
    "from-ma.com" => 0,
    "from-md.com" => 0,
    "from-me.org" => 0,
    "from-mi.com" => 0,
    "from-mn.com" => 0,
    "from-mo.com" => 0,
    "from-ms.com" => 0,
    "from-mt.com" => 0,
    "from-nc.com" => 0,
    "from-nd.com" => 0,
    "from-ne.com" => 0,
    "from-nh.com" => 0,
    "from-nj.com" => 0,
    "from-nm.com" => 0,
    "from-nv.com" => 0,
    "from-ny.net" => 0,
    "from-oh.com" => 0,
    "from-ok.com" => 0,
    "from-or.com" => 0,
    "from-pa.com" => 0,
    "from-pr.com" => 0,
    "from-ri.com" => 0,
    "from-sc.com" => 0,
    "from-sd.com" => 0,
    "from-tn.com" => 0,
    "from-tx.com" => 0,
    "from-ut.com" => 0,
    "from-va.com" => 0,
    "from-vt.com" => 0,
    "from-wa.com" => 0,
    "from-wi.com" => 0,
    "from-wv.com" => 0,
    "from-wy.com" => 0,
    "ftpaccess.cc" => 0,
    "fuettertdasnetz.de" => 0,
    "game-host.org" => 0,
    "game-server.cc" => 0,
    "getmyip.com" => 0,
    "gets-it.net" => 0,
    "go.dyndns.org" => 0,
    "gotdns.com" => 0,
    "gotdns.org" => 0,
    "groks-the.info" => 0,
    "groks-this.info" => 0,
    "ham-radio-op.net" => 0,
    "here-for-more.info" => 0,
    "hobby-site.com" => 0,
    "hobby-site.org" => 0,
    "home.dyndns.org" => 0,
    "homedns.org" => 0,
    "homeftp.net" => 0,
    "homeftp.org" => 0,
    "homeip.net" => 0,
    "homelinux.com" => 0,
    "homelinux.net" => 0,
    "homelinux.org" => 0,
    "homeunix.com" => 0,
    "homeunix.net" => 0,
    "homeunix.org" => 0,
    "iamallama.com" => 0,
    "in-the-band.net" => 0,
    "is-a-anarchist.com" => 0,
    "is-a-blogger.com" => 0,
    "is-a-bookkeeper.com" => 0,
    "is-a-bruinsfan.org" => 0,
    "is-a-bulls-fan.com" => 0,
    "is-a-candidate.org" => 0,
    "is-a-caterer.com" => 0,
    "is-a-celticsfan.org" => 0,
    "is-a-chef.com" => 0,
    "is-a-chef.net" => 0,
    "is-a-chef.org" => 0,
    "is-a-conservative.com" => 0,
    "is-a-cpa.com" => 0,
    "is-a-cubicle-slave.com" => 0,
    "is-a-democrat.com" => 0,
    "is-a-designer.com" => 0,
    "is-a-doctor.com" => 0,
    "is-a-financialadvisor.com" => 0,
    "is-a-geek.com" => 0,
    "is-a-geek.net" => 0,
    "is-a-geek.org" => 0,
    "is-a-green.com" => 0,
    "is-a-guru.com" => 0,
    "is-a-hard-worker.com" => 0,
    "is-a-hunter.com" => 0,
    "is-a-knight.org" => 0,
    "is-a-landscaper.com" => 0,
    "is-a-lawyer.com" => 0,
    "is-a-liberal.com" => 0,
    "is-a-libertarian.com" => 0,
    "is-a-linux-user.org" => 0,
    "is-a-llama.com" => 0,
    "is-a-musician.com" => 0,
    "is-a-nascarfan.com" => 0,
    "is-a-nurse.com" => 0,
    "is-a-painter.com" => 0,
    "is-a-patsfan.org" => 0,
    "is-a-personaltrainer.com" => 0,
    "is-a-photographer.com" => 0,
    "is-a-player.com" => 0,
    "is-a-republican.com" => 0,
    "is-a-rockstar.com" => 0,
    "is-a-socialist.com" => 0,
    "is-a-soxfan.org" => 0,
    "is-a-student.com" => 0,
    "is-a-teacher.com" => 0,
    "is-a-techie.com" => 0,
    "is-a-therapist.com" => 0,
    "is-an-accountant.com" => 0,
    "is-an-actor.com" => 0,
    "is-an-actress.com" => 0,
    "is-an-anarchist.com" => 0,
    "is-an-artist.com" => 0,
    "is-an-engineer.com" => 0,
    "is-an-entertainer.com" => 0,
    "is-by.us" => 0,
    "is-certified.com" => 0,
    "is-found.org" => 0,
    "is-gone.com" => 0,
    "is-into-anime.com" => 0,
    "is-into-cars.com" => 0,
    "is-into-cartoons.com" => 0,
    "is-into-games.com" => 0,
    "is-leet.com" => 0,
    "is-lost.org" => 0,
    "is-not-certified.com" => 0,
    "is-saved.org" => 0,
    "is-slick.com" => 0,
    "is-uberleet.com" => 0,
    "is-very-bad.org" => 0,
    "is-very-evil.org" => 0,
    "is-very-good.org" => 0,
    "is-very-nice.org" => 0,
    "is-very-sweet.org" => 0,
    "is-with-theband.com" => 0,
    "isa-geek.com" => 0,
    "isa-geek.net" => 0,
    "isa-geek.org" => 0,
    "isa-hockeynut.com" => 0,
    "issmarterthanyou.com" => 0,
    "isteingeek.de" => 0,
    "istmein.de" => 0,
    "kicks-ass.net" => 0,
    "kicks-ass.org" => 0,
    "knowsitall.info" => 0,
    "land-4-sale.us" => 0,
    "lebtimnetz.de" => 0,
    "leitungsen.de" => 0,
    "likes-pie.com" => 0,
    "likescandy.com" => 0,
    "merseine.nu" => 0,
    "mine.nu" => 0,
    "misconfused.org" => 0,
    "mypets.ws" => 0,
    "myphotos.cc" => 0,
    "neat-url.com" => 0,
    "office-on-the.net" => 0,
    "on-the-web.tv" => 0,
    "podzone.net" => 0,
    "podzone.org" => 0,
    "readmyblog.org" => 0,
    "saves-the-whales.com" => 0,
    "scrapper-site.net" => 0,
    "scrapping.cc" => 0,
    "selfip.biz" => 0,
    "selfip.com" => 0,
    "selfip.info" => 0,
    "selfip.net" => 0,
    "selfip.org" => 0,
    "sells-for-less.com" => 0,
    "sells-for-u.com" => 0,
    "sells-it.net" => 0,
    "sellsyourhome.org" => 0,
    "servebbs.com" => 0,
    "servebbs.net" => 0,
    "servebbs.org" => 0,
    "serveftp.net" => 0,
    "serveftp.org" => 0,
    "servegame.org" => 0,
    "shacknet.nu" => 0,
    "simple-url.com" => 0,
    "space-to-rent.com" => 0,
    "stuff-4-sale.org" => 0,
    "stuff-4-sale.us" => 0,
    "teaches-yoga.com" => 0,
    "thruhere.net" => 0,
    "traeumtgerade.de" => 0,
    "webhop.biz" => 0,
    "webhop.info" => 0,
    "webhop.net" => 0,
    "webhop.org" => 0,
    "worse-than.tv" => 0,
    "writesthisblog.com" => 0,
    "github.io" => 0,
    "appspot.com" => 0,
    "blogspot.be" => 0,
    "blogspot.bj" => 0,
    "blogspot.ca" => 0,
    "blogspot.cf" => 0,
    "blogspot.ch" => 0,
    "blogspot.co.at" => 0,
    "blogspot.co.il" => 0,
    "blogspot.co.nz" => 0,
    "blogspot.co.uk" => 0,
    "blogspot.com" => 0,
    "blogspot.com.ar" => 0,
    "blogspot.com.au" => 0,
    "blogspot.com.br" => 0,
    "blogspot.com.es" => 0,
    "blogspot.cv" => 0,
    "blogspot.cz" => 0,
    "blogspot.de" => 0,
    "blogspot.dk" => 0,
    "blogspot.fi" => 0,
    "blogspot.fr" => 0,
    "blogspot.gr" => 0,
    "blogspot.hk" => 0,
    "blogspot.hu" => 0,
    "blogspot.ie" => 0,
    "blogspot.in" => 0,
    "blogspot.it" => 0,
    "blogspot.jp" => 0,
    "blogspot.kr" => 0,
    "blogspot.mr" => 0,
    "blogspot.mx" => 0,
    "blogspot.nl" => 0,
    "blogspot.no" => 0,
    "blogspot.pt" => 0,
    "blogspot.re" => 0,
    "blogspot.ro" => 0,
    "blogspot.se" => 0,
    "blogspot.sg" => 0,
    "blogspot.sk" => 0,
    "blogspot.td" => 0,
    "blogspot.tw" => 0,
    "codespot.com" => 0,
    "googleapis.com" => 0,
    "googlecode.com" => 0,
    "herokuapp.com" => 0,
    "herokussl.com" => 0,
    "iki.fi" => 0,
    "biz.at" => 0,
    "info.at" => 0,
    "co.pl" => 0,
    "nyc.mn" => 0,
    "operaunite.com" => 0,
    "rhcloud.com" => 0,
    "priv.at" => 0,
    "za.net" => 0,
    "za.org" => 0,
  }

  def self.etld_data
    ETLD_DATA
  end
end
